# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_nodes_in_radius.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rtabmap_msgs/srv/get_nodes_in_radius.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"f\n\x17GetNodesInRadiusRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\t\n\x01z\x18\x04 \x01(\x02\x12\x0e\n\x06radius\x18\x05 \x01(\x02\x12\t\n\x01k\x18\x06 \x01(\x05\"}\n\x18GetNodesInRadiusResponse\x12\x0b\n\x03ids\x18\x01 \x03(\x05\x12\x41\n\x05poses\x18\x02 \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x11\n\tdists_sqr\x18\x03 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.get_nodes_in_radius_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETNODESINRADIUSREQUEST']._serialized_start=175
  _globals['_GETNODESINRADIUSREQUEST']._serialized_end=277
  _globals['_GETNODESINRADIUSRESPONSE']._serialized_start=279
  _globals['_GETNODESINRADIUSRESPONSE']._serialized_end=404
# @@protoc_insertion_point(module_scope)
