# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ur_msgs/msg/masterboard_data_msg.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/humble/ur_msgs/msg/masterboard_data_msg.proto\x12\'make87_messages_ros2.humble.ur_msgs.msg\x1a!make87_messages/core/header.proto\"\xf8\x03\n\x12MasterboardDataMsg\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x1a\n\x12\x64igital_input_bits\x18\x02 \x01(\r\x12\x1b\n\x13\x64igital_output_bits\x18\x03 \x01(\r\x12\x1b\n\x13\x61nalog_input_range0\x18\x04 \x01(\x05\x12\x1b\n\x13\x61nalog_input_range1\x18\x05 \x01(\x05\x12\x15\n\ranalog_input0\x18\x06 \x01(\x01\x12\x15\n\ranalog_input1\x18\x07 \x01(\x01\x12\x1d\n\x15\x61nalog_output_domain0\x18\x08 \x01(\x05\x12\x1d\n\x15\x61nalog_output_domain1\x18\t \x01(\x05\x12\x16\n\x0e\x61nalog_output0\x18\n \x01(\x01\x12\x16\n\x0e\x61nalog_output1\x18\x0b \x01(\x01\x12\x1f\n\x17masterboard_temperature\x18\x0c \x01(\x02\x12\x19\n\x11robot_voltage_48v\x18\r \x01(\x02\x12\x15\n\rrobot_current\x18\x0e \x01(\x02\x12\x19\n\x11master_io_current\x18\x0f \x01(\x02\x12\x1b\n\x13master_safety_state\x18\x10 \x01(\r\x12\x1a\n\x12master_onoff_state\x18\x11 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ur_msgs.msg.masterboard_data_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MASTERBOARDDATAMSG']._serialized_start=147
  _globals['_MASTERBOARDDATAMSG']._serialized_end=651
# @@protoc_insertion_point(module_scope)
