# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import histogram_bucket_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_histogram__bucket__pb2
from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import metric_label_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_metric__label__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric.proto\x12\x34make87_messages_ros2.jazzy.cartographer_ros_msgs.msg\x1aKmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/histogram_bucket.proto\x1aGmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric_label.proto\"\xd9\x01\n\x06Metric\x12\x0c\n\x04type\x18\x01 \x01(\r\x12Q\n\x06labels\x18\x02 \x03(\x0b\x32\x41.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.MetricLabel\x12\r\n\x05value\x18\x03 \x01(\x01\x12_\n\x10\x63ounts_by_bucket\x18\x04 \x03(\x0b\x32\x45.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.HistogramBucketb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_METRIC']._serialized_start=274
  _globals['_METRIC']._serialized_end=491
# @@protoc_insertion_point(module_scope)
