# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/cartesian_trajectory_point.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import cartesian_point_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_cartesian__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/moveit_msgs/msg/cartesian_trajectory_point.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1a\x42make87_messages_ros2/rolling/moveit_msgs/msg/cartesian_point.proto\"\xbf\x01\n\x18\x43\x61rtesianTrajectoryPoint\x12K\n\x05point\x18\x01 \x01(\x0b\x32<.make87_messages_ros2.rolling.moveit_msgs.msg.CartesianPoint\x12V\n\x0ftime_from_start\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.cartesian_trajectory_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CARTESIANTRAJECTORYPOINT']._serialized_start=264
  _globals['_CARTESIANTRAJECTORYPOINT']._serialized_end=455
# @@protoc_insertion_point(module_scope)
