# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_sensing_msgs/msg/gnss_ins_orientation.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_quaternion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/autoware_sensing_msgs/msg/gnss_ins_orientation.proto\x12\x36make87_messages_ros2.rolling.autoware_sensing_msgs.msg\x1a?make87_messages_ros2/rolling/geometry_msgs/msg/quaternion.proto\"\xb0\x01\n\x12GnssInsOrientation\x12O\n\x0borientation\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.rolling.geometry_msgs.msg.Quaternion\x12\x17\n\x0frmse_rotation_x\x18\x02 \x01(\x02\x12\x17\n\x0frmse_rotation_y\x18\x03 \x01(\x02\x12\x17\n\x0frmse_rotation_z\x18\x04 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_sensing_msgs.msg.gnss_ins_orientation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GNSSINSORIENTATION']._serialized_start=207
  _globals['_GNSSINSORIENTATION']._serialized_end=383
# @@protoc_insertion_point(module_scope)
