# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/map_msgs/srv/projected_maps_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.map_msgs.msg import projected_map_info_pb2 as make87__messages__ros2_dot_jazzy_dot_map__msgs_dot_msg_dot_projected__map__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/map_msgs/srv/projected_maps_info.proto\x12\'make87_messages_ros2.jazzy.map_msgs.srv\x1a@make87_messages_ros2/jazzy/map_msgs/msg/projected_map_info.proto\"r\n\x18ProjectedMapsInfoRequest\x12V\n\x13projected_maps_info\x18\x01 \x03(\x0b\x32\x39.make87_messages_ros2.jazzy.map_msgs.msg.ProjectedMapInfo\"\x1b\n\x19ProjectedMapsInfoResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.map_msgs.srv.projected_maps_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PROJECTEDMAPSINFOREQUEST']._serialized_start=176
  _globals['_PROJECTEDMAPSINFOREQUEST']._serialized_end=290
  _globals['_PROJECTEDMAPSINFORESPONSE']._serialized_start=292
  _globals['_PROJECTEDMAPSINFORESPONSE']._serialized_end=319
# @@protoc_insertion_point(module_scope)
