# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ibeo_msgs/msg/scan_data2204.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import scan_point2204_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_scan__point2204__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import scanner_info2204_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_scanner__info2204__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/ibeo_msgs/msg/scan_data2204.proto\x12)make87_messages_ros2.humble.ibeo_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/ibeo_msgs/msg/ibeo_data_header.proto\x1a>make87_messages_ros2/humble/ibeo_msgs/msg/scan_point2204.proto\x1a@make87_messages_ros2/humble/ibeo_msgs/msg/scanner_info2204.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x87\x05\n\x0cScanData2204\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12N\n\x0bibeo_header\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.humble.ibeo_msgs.msg.IbeoDataHeader\x12\x17\n\x0fscan_start_time\x18\x04 \x01(\x04\x12\x1c\n\x14scan_end_time_offset\x18\x05 \x01(\r\x12\x16\n\x0eground_labeled\x18\x06 \x01(\x08\x12\x14\n\x0c\x64irt_labeled\x18\x07 \x01(\x08\x12\x14\n\x0crain_labeled\x18\x08 \x01(\x08\x12\x12\n\nfused_scan\x18\t \x01(\x08\x12\x13\n\x0bmirror_side\x18\n \x01(\r\x12\x19\n\x11\x63oordinate_system\x18\x0b \x01(\r\x12\x13\n\x0bscan_number\x18\x0c \x01(\r\x12\x13\n\x0bscan_points\x18\r \x01(\r\x12\x1f\n\x17number_of_scanner_infos\x18\x0e \x01(\r\x12U\n\x11scanner_info_list\x18\x0f \x03(\x0b\x32:.make87_messages_ros2.humble.ibeo_msgs.msg.ScannerInfo2204\x12Q\n\x0fscan_point_list\x18\x10 \x03(\x0b\x32\x38.make87_messages_ros2.humble.ibeo_msgs.msg.ScanPoint2204b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ibeo_msgs.msg.scan_data2204_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SCANDATA2204']._serialized_start=395
  _globals['_SCANDATA2204']._serialized_end=1042
# @@protoc_insertion_point(module_scope)
