# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/srv/get_node_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import node_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/rtabmap_msgs/srv/get_node_data.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x37make87_messages_ros2/humble/rtabmap_msgs/msg/node.proto\"\x8e\x01\n\x12GetNodeDataRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0b\n\x03ids\x18\x02 \x03(\x05\x12\x0e\n\x06images\x18\x03 \x01(\x08\x12\x0c\n\x04scan\x18\x04 \x01(\x08\x12\x0c\n\x04grid\x18\x05 \x01(\x08\x12\x11\n\tuser_data\x18\x06 \x01(\x08\"\x85\x01\n\x13GetNodeDataResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12@\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x32.make87_messages_ros2.humble.rtabmap_msgs.msg.Nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.srv.get_node_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETNODEDATAREQUEST']._serialized_start=207
  _globals['_GETNODEDATAREQUEST']._serialized_end=349
  _globals['_GETNODEDATARESPONSE']._serialized_start=352
  _globals['_GETNODEDATARESPONSE']._serialized_end=485
# @@protoc_insertion_point(module_scope)
