# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_task_msgs/msg/task_description.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import clean_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_clean__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import delivery_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_delivery__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import loop_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_loop__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import priority_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_priority__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import station_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_station__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import task_type_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_task__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rmf_task_msgs/msg/task_description.proto\x12.make87_messages_ros2.rolling.rmf_task_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a:make87_messages_ros2/rolling/rmf_task_msgs/msg/clean.proto\x1a=make87_messages_ros2/rolling/rmf_task_msgs/msg/delivery.proto\x1a\x39make87_messages_ros2/rolling/rmf_task_msgs/msg/loop.proto\x1a=make87_messages_ros2/rolling/rmf_task_msgs/msg/priority.proto\x1a<make87_messages_ros2/rolling/rmf_task_msgs/msg/station.proto\x1a>make87_messages_ros2/rolling/rmf_task_msgs/msg/task_type.proto\"\x99\x04\n\x0fTaskDescription\x12M\n\nstart_time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12J\n\x08priority\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.Priority\x12K\n\ttask_type\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.TaskType\x12H\n\x07station\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.rmf_task_msgs.msg.Station\x12\x42\n\x04loop\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.rmf_task_msgs.msg.Loop\x12J\n\x08\x64\x65livery\x18\x06 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.Delivery\x12\x44\n\x05\x63lean\x18\x07 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.rmf_task_msgs.msg.Cleanb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_task_msgs.msg.task_description_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TASKDESCRIPTION']._serialized_start=557
  _globals['_TASKDESCRIPTION']._serialized_end=1094
# @@protoc_insertion_point(module_scope)
