# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_perception_msgs/msg/object_classification.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/rolling/autoware_perception_msgs/msg/object_classification.proto\x12\x39make87_messages_ros2.rolling.autoware_perception_msgs.msg\":\n\x14ObjectClassification\x12\r\n\x05label\x18\x01 \x01(\r\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_perception_msgs.msg.object_classification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBJECTCLASSIFICATION']._serialized_start=148
  _globals['_OBJECTCLASSIFICATION']._serialized_end=206
# @@protoc_insertion_point(module_scope)
