# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/delphi_esr_msgs/msg/esr_vehicle5.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/delphi_esr_msgs/msg/esr_vehicle5.proto\x12\x30make87_messages_ros2.rolling.delphi_esr_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xc7\x02\n\x0b\x45srVehicle5\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x1c\n\x14oversteer_understeer\x18\x02 \x01(\x05\x12\x1b\n\x13yaw_rate_bias_shift\x18\x03 \x01(\x08\x12\x16\n\x0e\x62\x65\x61mwidth_vert\x18\x04 \x01(\x02\x12\x1a\n\x12\x66unnel_offset_left\x18\x05 \x01(\x02\x12\x1b\n\x13\x66unnel_offset_right\x18\x06 \x01(\x02\x12\x1d\n\x15\x63w_blockage_threshold\x18\x07 \x01(\x02\x12\x1a\n\x12\x64istance_rear_axle\x18\x08 \x01(\r\x12\x11\n\twheelbase\x18\t \x01(\r\x12\x1b\n\x13steering_gear_ratio\x18\n \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.delphi_esr_msgs.msg.esr_vehicle5_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESRVEHICLE5']._serialized_start=178
  _globals['_ESRVEHICLE5']._serialized_end=505
# @@protoc_insertion_point(module_scope)
