# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ros_gz_interfaces/msg/light.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.humble.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/ros_gz_interfaces/msg/light.proto\x12\x31make87_messages_ros2.humble.ros_gz_interfaces.msg\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\x1a\x39make87_messages_ros2/humble/std_msgs/msg/color_rgba.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xad\x05\n\x05Light\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\r\x12\x41\n\x04pose\x18\x05 \x01(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x44\n\x07\x64iffuse\x18\x06 \x01(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBA\x12\x45\n\x08specular\x18\x07 \x01(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBA\x12\x1c\n\x14\x61ttenuation_constant\x18\x08 \x01(\x02\x12\x1a\n\x12\x61ttenuation_linear\x18\t \x01(\x02\x12\x1d\n\x15\x61ttenuation_quadratic\x18\n \x01(\x02\x12I\n\tdirection\x18\x0b \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\r\n\x05range\x18\x0c \x01(\x02\x12\x14\n\x0c\x63\x61st_shadows\x18\r \x01(\x08\x12\x18\n\x10spot_inner_angle\x18\x0e \x01(\x02\x12\x18\n\x10spot_outer_angle\x18\x0f \x01(\x02\x12\x14\n\x0cspot_falloff\x18\x10 \x01(\x02\x12\n\n\x02id\x18\x11 \x01(\r\x12\x11\n\tparent_id\x18\x12 \x01(\r\x12\x11\n\tintensity\x18\x13 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ros_gz_interfaces.msg.light_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LIGHT']._serialized_start=385
  _globals['_LIGHT']._serialized_end=1070
# @@protoc_insertion_point(module_scope)
