# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_scan_xd/srv/field_set_read_srv.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/sick_scan_xd/srv/field_set_read_srv.proto\x12+make87_messages_ros2.jazzy.sick_scan_xd.srv\"\x18\n\x16\x46ieldSetReadSrvRequest\"h\n\x17\x46ieldSetReadSrvResponse\x12\"\n\x1a\x66ield_set_selection_method\x18\x01 \x01(\x05\x12\x18\n\x10\x61\x63tive_field_set\x18\x02 \x01(\x05\x12\x0f\n\x07success\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_scan_xd.srv.field_set_read_srv_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FIELDSETREADSRVREQUEST']._serialized_start=117
  _globals['_FIELDSETREADSRVREQUEST']._serialized_end=141
  _globals['_FIELDSETREADSRVRESPONSE']._serialized_start=143
  _globals['_FIELDSETREADSRVRESPONSE']._serialized_end=247
# @@protoc_insertion_point(module_scope)
