# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/apply_planning_scene.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import planning_scene_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_planning__scene__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/moveit_msgs/srv/apply_planning_scene.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/moveit_msgs/msg/planning_scene.proto\"\x94\x01\n\x19\x41pplyPlanningSceneRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12I\n\x05scene\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.humble.moveit_msgs.msg.PlanningScene\"[\n\x1a\x41pplyPlanningSceneResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.apply_planning_scene_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_APPLYPLANNINGSCENEREQUEST']._serialized_start=221
  _globals['_APPLYPLANNINGSCENEREQUEST']._serialized_end=369
  _globals['_APPLYPLANNINGSCENERESPONSE']._serialized_start=371
  _globals['_APPLYPLANNINGSCENERESPONSE']._serialized_end=462
# @@protoc_insertion_point(module_scope)
