# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_task_msgs/msg/delivery.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_dispenser_msgs.msg import dispenser_request_item_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__dispenser__msgs_dot_msg_dot_dispenser__request__item__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import behavior_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/rmf_task_msgs/msg/delivery.proto\x12.make87_messages_ros2.rolling.rmf_task_msgs.msg\x1aPmake87_messages_ros2/rolling/rmf_dispenser_msgs/msg/dispenser_request_item.proto\x1a=make87_messages_ros2/rolling/rmf_task_msgs/msg/behavior.proto\"\x87\x03\n\x08\x44\x65livery\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12X\n\x05items\x18\x02 \x03(\x0b\x32I.make87_messages_ros2.rolling.rmf_dispenser_msgs.msg.DispenserRequestItem\x12\x19\n\x11pickup_place_name\x18\x03 \x01(\t\x12\x18\n\x10pickup_dispenser\x18\x04 \x01(\t\x12Q\n\x0fpickup_behavior\x18\x05 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.Behavior\x12\x1a\n\x12\x64ropoff_place_name\x18\x06 \x01(\t\x12\x18\n\x10\x64ropoff_ingestor\x18\x07 \x01(\t\x12R\n\x10\x64ropoff_behavior\x18\x08 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.Behaviorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_task_msgs.msg.delivery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DELIVERY']._serialized_start=259
  _globals['_DELIVERY']._serialized_end=650
# @@protoc_insertion_point(module_scope)
