# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_rate.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_rate.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"@\n\x07\x43\x66gRATE\x12\x11\n\tmeas_rate\x18\x01 \x01(\r\x12\x10\n\x08nav_rate\x18\x02 \x01(\r\x12\x10\n\x08time_ref\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.cfg_rate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CFGRATE']._serialized_start=103
  _globals['_CFGRATE']._serialized_end=167
# @@protoc_insertion_point(module_scope)
