# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/webots_ros2_msgs/msg/camera_recognition_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.humble.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.humble.vision_msgs.msg import bounding_box2_d_pb2 as make87__messages__ros2_dot_humble_dot_vision__msgs_dot_msg_dot_bounding__box2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/webots_ros2_msgs/msg/camera_recognition_object.proto\x12\x30make87_messages_ros2.humble.webots_ros2_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/geometry_msgs/msg/pose_stamped.proto\x1a\x39make87_messages_ros2/humble/std_msgs/msg/color_rgba.proto\x1a\x41make87_messages_ros2/humble/vision_msgs/msg/bounding_box2_d.proto\"\xbb\x02\n\x17\x43\x61meraRecognitionObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\x05\x12H\n\x04pose\x18\x03 \x01(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12H\n\x04\x62\x62ox\x18\x04 \x01(\x0b\x32:.make87_messages_ros2.humble.vision_msgs.msg.BoundingBox2D\x12\x43\n\x06\x63olors\x18\x05 \x03(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBA\x12\r\n\x05model\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.webots_ros2_msgs.msg.camera_recognition_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CAMERARECOGNITIONOBJECT']._serialized_start=362
  _globals['_CAMERARECOGNITIONOBJECT']._serialized_end=677
# @@protoc_insertion_point(module_scope)
