# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcl_interfaces/srv/list_parameters.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rcl_interfaces.msg import list_parameters_result_pb2 as make87__messages__ros2_dot_rolling_dot_rcl__interfaces_dot_msg_dot_list__parameters__result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rcl_interfaces/srv/list_parameters.proto\x12/make87_messages_ros2.rolling.rcl_interfaces.srv\x1aLmake87_messages_ros2/rolling/rcl_interfaces/msg/list_parameters_result.proto\"8\n\x15ListParametersRequest\x12\x10\n\x08prefixes\x18\x01 \x03(\t\x12\r\n\x05\x64\x65pth\x18\x02 \x01(\x04\"o\n\x16ListParametersResponse\x12U\n\x06result\x18\x01 \x01(\x0b\x32\x45.make87_messages_ros2.rolling.rcl_interfaces.msg.ListParametersResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcl_interfaces.srv.list_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LISTPARAMETERSREQUEST']._serialized_start=200
  _globals['_LISTPARAMETERSREQUEST']._serialized_end=256
  _globals['_LISTPARAMETERSRESPONSE']._serialized_start=258
  _globals['_LISTPARAMETERSRESPONSE']._serialized_end=369
# @@protoc_insertion_point(module_scope)
