# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/motion_sequence_item.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import motion_plan_request_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_motion__plan__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/moveit_msgs/msg/motion_sequence_item.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/motion_plan_request.proto\"v\n\x12MotionSequenceItem\x12J\n\x03req\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.moveit_msgs.msg.MotionPlanRequest\x12\x14\n\x0c\x62lend_radius\x18\x02 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.motion_sequence_item_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MOTIONSEQUENCEITEM']._serialized_start=187
  _globals['_MOTIONSEQUENCEITEM']._serialized_end=305
# @@protoc_insertion_point(module_scope)
