# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_quaternion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x12,make87_messages_ros2.jazzy.geometry_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a=make87_messages_ros2/jazzy/geometry_msgs/msg/quaternion.proto\"\x9c\x01\n\x04Pose\x12\x45\n\x08position\x18\x01 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12M\n\x0borientation\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.geometry_msgs.msg.Quaternionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.geometry_msgs.msg.pose_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POSE']._serialized_start=227
  _globals['_POSE']._serialized_end=383
# @@protoc_insertion_point(module_scope)
