# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/pipeline_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import motion_plan_request_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_motion__plan__request__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import motion_plan_response_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_motion__plan__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/moveit_msgs/msg/pipeline_state.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x46make87_messages_ros2/rolling/moveit_msgs/msg/motion_plan_request.proto\x1aGmake87_messages_ros2/rolling/moveit_msgs/msg/motion_plan_response.proto\"\xcd\x01\n\rPipelineState\x12P\n\x07request\x18\x01 \x01(\x0b\x32?.make87_messages_ros2.rolling.moveit_msgs.msg.MotionPlanRequest\x12R\n\x08response\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.rolling.moveit_msgs.msg.MotionPlanResponse\x12\x16\n\x0epipeline_stage\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.pipeline_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PIPELINESTATE']._serialized_start=261
  _globals['_PIPELINESTATE']._serialized_end=466
# @@protoc_insertion_point(module_scope)
