# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/mount_configure.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/mavros_msgs/srv/mount_configure.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xec\x01\n\x15MountConfigureRequest\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x0c\n\x04mode\x18\x02 \x01(\r\x12\x16\n\x0estabilize_roll\x18\x03 \x01(\x08\x12\x17\n\x0fstabilize_pitch\x18\x04 \x01(\x08\x12\x15\n\rstabilize_yaw\x18\x05 \x01(\x08\x12\x12\n\nroll_input\x18\x06 \x01(\r\x12\x13\n\x0bpitch_input\x18\x07 \x01(\r\x12\x11\n\tyaw_input\x18\x08 \x01(\r\"9\n\x16MountConfigureResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.mount_configure_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MOUNTCONFIGUREREQUEST']._serialized_start=173
  _globals['_MOUNTCONFIGUREREQUEST']._serialized_end=409
  _globals['_MOUNTCONFIGURERESPONSE']._serialized_start=411
  _globals['_MOUNTCONFIGURERESPONSE']._serialized_end=468
# @@protoc_insertion_point(module_scope)
