# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_fleet_msgs/srv/lift_clearance.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/rmf_fleet_msgs/srv/lift_clearance.proto\x12-make87_messages_ros2.jazzy.rmf_fleet_msgs.srv\"=\n\x14LiftClearanceRequest\x12\x12\n\nrobot_name\x18\x01 \x01(\t\x12\x11\n\tlift_name\x18\x02 \x01(\t\")\n\x15LiftClearanceResponse\x12\x10\n\x08\x64\x65\x63ision\x18\x01 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_fleet_msgs.srv.lift_clearance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LIFTCLEARANCEREQUEST']._serialized_start=117
  _globals['_LIFTCLEARANCEREQUEST']._serialized_end=178
  _globals['_LIFTCLEARANCERESPONSE']._serialized_start=180
  _globals['_LIFTCLEARANCERESPONSE']._serialized_end=221
# @@protoc_insertion_point(module_scope)
