# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/file_write.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/mavros_msgs/srv/file_write.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"C\n\x10\x46ileWriteRequest\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\r\"5\n\x11\x46ileWriteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07r_errno\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.file_write_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FILEWRITEREQUEST']._serialized_start=111
  _globals['_FILEWRITEREQUEST']._serialized_end=178
  _globals['_FILEWRITERESPONSE']._serialized_start=180
  _globals['_FILEWRITERESPONSE']._serialized_end=233
# @@protoc_insertion_point(module_scope)
