# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/udp_msgs/srv/udp_socket.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/udp_msgs/srv/udp_socket.proto\x12)make87_messages_ros2.rolling.udp_msgs.srv\"\x80\x01\n\x10UdpSocketRequest\x12\x15\n\rlocal_address\x18\x01 \x01(\t\x12\x12\n\nlocal_port\x18\x02 \x01(\r\x12\x16\n\x0eremote_address\x18\x03 \x01(\t\x12\x13\n\x0bremote_port\x18\x04 \x01(\r\x12\x14\n\x0cis_broadcast\x18\x05 \x01(\x08\"+\n\x11UdpSocketResponse\x12\x16\n\x0esocket_created\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.udp_msgs.srv.udp_socket_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UDPSOCKETREQUEST']._serialized_start=106
  _globals['_UDPSOCKETREQUEST']._serialized_end=234
  _globals['_UDPSOCKETRESPONSE']._serialized_start=236
  _globals['_UDPSOCKETRESPONSE']._serialized_end=279
# @@protoc_insertion_point(module_scope)
