# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/example_interfaces/msg/multi_array_layout.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.example_interfaces.msg import multi_array_dimension_pb2 as make87__messages__ros2_dot_jazzy_dot_example__interfaces_dot_msg_dot_multi__array__dimension__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/example_interfaces/msg/multi_array_layout.proto\x12\x31make87_messages_ros2.jazzy.example_interfaces.msg\x1aMmake87_messages_ros2/jazzy/example_interfaces/msg/multi_array_dimension.proto\"|\n\x10MultiArrayLayout\x12S\n\x03\x64im\x18\x01 \x03(\x0b\x32\x46.make87_messages_ros2.jazzy.example_interfaces.msg.MultiArrayDimension\x12\x13\n\x0b\x64\x61ta_offset\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.example_interfaces.msg.multi_array_layout_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MULTIARRAYLAYOUT']._serialized_start=208
  _globals['_MULTIARRAYLAYOUT']._serialized_end=332
# @@protoc_insertion_point(module_scope)
