# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/nav_sbassv.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/rolling/ublox_msgs/msg/nav_sbassv.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\x99\x01\n\tNavSBASSV\x12\x0c\n\x04svid\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\x0c\n\x04udre\x18\x03 \x01(\r\x12\x0e\n\x06sv_sys\x18\x04 \x01(\r\x12\x12\n\nsv_service\x18\x05 \x01(\r\x12\x11\n\treserved1\x18\x06 \x01(\r\x12\x0b\n\x03prc\x18\x07 \x01(\x05\x12\x11\n\treserved2\x18\x08 \x01(\r\x12\n\n\x02ic\x18\t \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.nav_sbassv_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NAVSBASSV']._serialized_start=110
  _globals['_NAVSBASSV']._serialized_end=263
# @@protoc_insertion_point(module_scope)
