# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_obstacle_msgs/msg/bounding_box3_d.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/rmf_obstacle_msgs/msg/bounding_box3_d.proto\x12\x32make87_messages_ros2.rolling.rmf_obstacle_msgs.msg\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/vector3.proto\"\x9c\x01\n\rBoundingBox3D\x12\x44\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x45\n\x04size\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_obstacle_msgs.msg.bounding_box3_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BOUNDINGBOX3D']._serialized_start=250
  _globals['_BOUNDINGBOX3D']._serialized_end=406
# @@protoc_insertion_point(module_scope)
