# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/webots_ros2_msgs/msg/urdf_robot.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/webots_ros2_msgs/msg/urdf_robot.proto\x12\x31make87_messages_ros2.rolling.webots_ros2_msgs.msg\"\xc5\x01\n\tUrdfRobot\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\turdf_path\x18\x02 \x01(\t\x12\x19\n\x11robot_description\x18\x03 \x01(\t\x12\x1c\n\x14relative_path_prefix\x18\x04 \x01(\t\x12\x13\n\x0btranslation\x18\x05 \x01(\t\x12\x10\n\x08rotation\x18\x06 \x01(\t\x12\x0e\n\x06normal\x18\x07 \x01(\x08\x12\x15\n\rbox_collision\x18\x08 \x01(\x08\x12\x10\n\x08init_pos\x18\t \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.webots_ros2_msgs.msg.urdf_robot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_URDFROBOT']._serialized_start=122
  _globals['_URDFROBOT']._serialized_end=319
# @@protoc_insertion_point(module_scope)
