# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/kobuki_ros_interfaces/msg/button_event.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/kobuki_ros_interfaces/msg/button_event.proto\x12\x36make87_messages_ros2.rolling.kobuki_ros_interfaces.msg\",\n\x0b\x42uttonEvent\x12\x0e\n\x06\x62utton\x18\x01 \x01(\r\x12\r\n\x05state\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.kobuki_ros_interfaces.msg.button_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BUTTONEVENT']._serialized_start=133
  _globals['_BUTTONEVENT']._serialized_end=177
# @@protoc_insertion_point(module_scope)
