# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/esf_ins.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/ublox_msgs/msg/esf_ins.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\xac\x01\n\x06\x45sfINS\x12\x11\n\tbitfield0\x18\x01 \x01(\r\x12\x11\n\treserved1\x18\x02 \x03(\r\x12\r\n\x05i_tow\x18\x03 \x01(\r\x12\x12\n\nx_ang_rate\x18\x04 \x01(\x05\x12\x12\n\ny_ang_rate\x18\x05 \x01(\x05\x12\x12\n\nz_ang_rate\x18\x06 \x01(\x05\x12\x0f\n\x07x_accel\x18\x07 \x01(\x05\x12\x0f\n\x07y_accel\x18\x08 \x01(\x05\x12\x0f\n\x07z_accel\x18\t \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.esf_ins_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESFINS']._serialized_start=107
  _globals['_ESFINS']._serialized_end=279
# @@protoc_insertion_point(module_scope)
