# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/swri_roscpp/msg/test_topic_service_response.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.marti_common_msgs.msg import service_header_pb2 as make87__messages__ros2_dot_humble_dot_marti__common__msgs_dot_msg_dot_service__header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/swri_roscpp/msg/test_topic_service_response.proto\x12+make87_messages_ros2.humble.swri_roscpp.msg\x1a!make87_messages/core/header.proto\x1a\x46make87_messages_ros2/humble/marti_common_msgs/msg/service_header.proto\"\xb6\x01\n\x18TestTopicServiceResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12T\n\nsrv_header\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.humble.marti_common_msgs.msg.ServiceHeader\x12\x16\n\x0eresponse_value\x18\x03 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.swri_roscpp.msg.test_topic_service_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TESTTOPICSERVICERESPONSE']._serialized_start=234
  _globals['_TESTTOPICSERVICERESPONSE']._serialized_end=416
# @@protoc_insertion_point(module_scope)
