# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/object_data2270.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import object2270_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_object2270__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/ibeo_msgs/msg/object_data2270.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a?make87_messages_ros2/jazzy/ibeo_msgs/msg/ibeo_data_header.proto\x1a\x39make87_messages_ros2/jazzy/ibeo_msgs/msg/object2270.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf9\x02\n\x0eObjectData2270\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12M\n\x0bibeo_header\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.ibeo_msgs.msg.IbeoDataHeader\x12U\n\x14start_scan_timestamp\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x1a\n\x12object_list_number\x18\x04 \x01(\r\x12\x19\n\x11number_of_objects\x18\x05 \x01(\r\x12I\n\x0bobject_list\x18\x06 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.ibeo_msgs.msg.Object2270b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.object_data2270_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBJECTDATA2270']._serialized_start=349
  _globals['_OBJECTDATA2270']._serialized_end=726
# @@protoc_insertion_point(module_scope)
