from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as _twist_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VelocityStamped(_message.Message):
    __slots__ = ("header", "body_frame_id", "reference_frame_id", "velocity")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    body_frame_id: str
    reference_frame_id: str
    velocity: _twist_pb2.Twist
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., body_frame_id: _Optional[str] = ..., reference_frame_id: _Optional[str] = ..., velocity: _Optional[_Union[_twist_pb2.Twist, _Mapping]] = ...) -> None: ...
