from make87_messages_ros2.jazzy.actuator_msgs.msg import actuators_angular_position_pb2 as _actuators_angular_position_pb2
from make87_messages_ros2.jazzy.actuator_msgs.msg import actuators_linear_position_pb2 as _actuators_linear_position_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActuatorsPosition(_message.Message):
    __slots__ = ("header", "angular", "linear")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_FIELD_NUMBER: _ClassVar[int]
    LINEAR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    angular: _actuators_angular_position_pb2.ActuatorsAngularPosition
    linear: _actuators_linear_position_pb2.ActuatorsLinearPosition
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., angular: _Optional[_Union[_actuators_angular_position_pb2.ActuatorsAngularPosition, _Mapping]] = ..., linear: _Optional[_Union[_actuators_linear_position_pb2.ActuatorsLinearPosition, _Mapping]] = ...) -> None: ...
