# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marker_msgs/msg/fiducial.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/marker_msgs/msg/fiducial.proto\x12,make87_messages_ros2.rolling.marker_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/point.proto\"\xca\x01\n\x08\x46iducial\x12\x0b\n\x03ids\x18\x01 \x03(\x05\x12\x16\n\x0eids_confidence\x18\x02 \x03(\x01\x12L\n\robject_points\x18\x03 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12K\n\x0cimage_points\x18\x04 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marker_msgs.msg.fiducial_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FIDUCIAL']._serialized_start=170
  _globals['_FIDUCIAL']._serialized_end=372
# @@protoc_insertion_point(module_scope)
