# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_msgs/msg/esf_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ublox_msgs.msg import esf_status_sens_pb2 as make87__messages__ros2_dot_humble_dot_ublox__msgs_dot_msg_dot_esf__status__sens__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/humble/ublox_msgs/msg/esf_status.proto\x12*make87_messages_ros2.humble.ublox_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/ublox_msgs/msg/esf_status_sens.proto\"\xef\x01\n\tEsfSTATUS\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05i_tow\x18\x02 \x01(\r\x12\x0f\n\x07version\x18\x03 \x01(\r\x12\x11\n\treserved1\x18\x04 \x03(\r\x12\x13\n\x0b\x66usion_mode\x18\x05 \x01(\r\x12\x11\n\treserved2\x18\x06 \x03(\r\x12\x10\n\x08num_sens\x18\x07 \x01(\r\x12G\n\x04sens\x18\x08 \x03(\x0b\x32\x39.make87_messages_ros2.humble.ublox_msgs.msg.EsfSTATUSSensb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_msgs.msg.esf_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESFSTATUS']._serialized_start=209
  _globals['_ESFSTATUS']._serialized_end=448
# @@protoc_insertion_point(module_scope)
