from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TopicsAndRawTypesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TopicsAndRawTypesResponse(_message.Message):
    __slots__ = ("topics", "types", "typedefs_full_text")
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    TYPES_FIELD_NUMBER: _ClassVar[int]
    TYPEDEFS_FULL_TEXT_FIELD_NUMBER: _ClassVar[int]
    topics: _containers.RepeatedScalarFieldContainer[str]
    types: _containers.RepeatedScalarFieldContainer[str]
    typedefs_full_text: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, topics: _Optional[_Iterable[str]] = ..., types: _Optional[_Iterable[str]] = ..., typedefs_full_text: _Optional[_Iterable[str]] = ...) -> None: ...
