# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_interfaces/srv/warm_start.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/ublox_ubx_interfaces/srv/warm_start.proto\x12\x35make87_messages_ros2.rolling.ublox_ubx_interfaces.srv\"&\n\x10WarmStartRequest\x12\x12\n\nreset_type\x18\x01 \x01(\r\"\x13\n\x11WarmStartResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_interfaces.srv.warm_start_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_WARMSTARTREQUEST']._serialized_start=129
  _globals['_WARMSTARTREQUEST']._serialized_end=167
  _globals['_WARMSTARTRESPONSE']._serialized_start=169
  _globals['_WARMSTARTRESPONSE']._serialized_end=188
# @@protoc_insertion_point(module_scope)
