# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/unitree_ros/msg/bms_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/humble/unitree_ros/msg/bms_state.proto\x12+make87_messages_ros2.humble.unitree_ros.msg\x1a!make87_messages/core/header.proto\"\xd2\x01\n\x08\x42msState\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tversion_h\x18\x02 \x01(\r\x12\x11\n\tversion_l\x18\x03 \x01(\r\x12\x12\n\nbms_status\x18\x04 \x01(\r\x12\x0b\n\x03soc\x18\x05 \x01(\r\x12\x0f\n\x07\x63urrent\x18\x06 \x01(\x05\x12\r\n\x05\x63ycle\x18\x07 \x01(\r\x12\x0e\n\x06\x62q_ntc\x18\x08 \x03(\x05\x12\x0f\n\x07mcu_ntc\x18\t \x03(\x05\x12\x10\n\x08\x63\x65ll_vol\x18\n \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.unitree_ros.msg.bms_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BMSSTATE']._serialized_start=144
  _globals['_BMSSTATE']._serialized_end=354
# @@protoc_insertion_point(module_scope)
