# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/waypoint.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/mavros_msgs/msg/waypoint.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\"\xc2\x01\n\x08Waypoint\x12\r\n\x05\x66rame\x18\x01 \x01(\r\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\r\x12\x12\n\nis_current\x18\x03 \x01(\x08\x12\x14\n\x0c\x61utocontinue\x18\x04 \x01(\x08\x12\x0e\n\x06param1\x18\x05 \x01(\x02\x12\x0e\n\x06param2\x18\x06 \x01(\x02\x12\x0e\n\x06param3\x18\x07 \x01(\x02\x12\x0e\n\x06param4\x18\x08 \x01(\x02\x12\r\n\x05x_lat\x18\t \x01(\x01\x12\x0e\n\x06y_long\x18\n \x01(\x01\x12\r\n\x05z_alt\x18\x0b \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.waypoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_WAYPOINT']._serialized_start=106
  _globals['_WAYPOINT']._serialized_end=300
# @@protoc_insertion_point(module_scope)
