# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_planning_msgs/msg/path.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_planning_msgs.msg import path_point_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__planning__msgs_dot_msg_dot_path__point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/autoware_planning_msgs/msg/path.proto\x12\x35make87_messages_ros2.jazzy.autoware_planning_msgs.msg\x1a\x46make87_messages_ros2/jazzy/autoware_planning_msgs/msg/path_point.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xac\x02\n\x04Path\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12P\n\x06points\x18\x02 \x03(\x0b\x32@.make87_messages_ros2.jazzy.autoware_planning_msgs.msg.PathPoint\x12G\n\nleft_bound\x18\x03 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12H\n\x0bright_bound\x18\x04 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_planning_msgs.msg.path_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PATH']._serialized_start=308
  _globals['_PATH']._serialized_end=608
# @@protoc_insertion_point(module_scope)
