# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/host_vehicle_state2806.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/ibeo_msgs/msg/host_vehicle_state2806.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xac\x05\n\x14HostVehicleState2806\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12L\n\ttimestamp\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x12\n\ndistance_x\x18\x04 \x01(\x05\x12\x12\n\ndistance_y\x18\x05 \x01(\x05\x12\x14\n\x0c\x63ourse_angle\x18\x06 \x01(\x02\x12\x1d\n\x15longitudinal_velocity\x18\x07 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x08 \x01(\x02\x12\x1c\n\x14steering_wheel_angle\x18\t \x01(\x02\x12\x1a\n\x12\x63ross_acceleration\x18\n \x01(\x02\x12\x19\n\x11\x66ront_wheel_angle\x18\x0b \x01(\x02\x12\x15\n\rvehicle_width\x18\x0c \x01(\x02\x12#\n\x1bvehicle_front_to_front_axle\x18\r \x01(\x02\x12\x1f\n\x17rear_axle_to_front_axle\x18\x0e \x01(\x02\x12!\n\x19rear_axle_to_vehicle_rear\x18\x0f \x01(\x02\x12\x1a\n\x12steer_ratio_poly_0\x18\x10 \x01(\x02\x12\x1a\n\x12steer_ratio_poly_1\x18\x11 \x01(\x02\x12\x1a\n\x12steer_ratio_poly_2\x18\x12 \x01(\x02\x12\x1a\n\x12steer_ratio_poly_3\x18\x13 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.host_vehicle_state2806_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HOSTVEHICLESTATE2806']._serialized_start=307
  _globals['_HOSTVEHICLESTATE2806']._serialized_end=991
# @@protoc_insertion_point(module_scope)
