# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_ack.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import negotiation_participant_ack_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_negotiation__participant__ack__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_ack.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.msg\x1aQmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_participant_ack.proto\"\x8f\x01\n\x0eNegotiationAck\x12\x18\n\x10\x63onflict_version\x18\x01 \x01(\x04\x12\x63\n\x0f\x61\x63knowledgments\x18\x02 \x03(\x0b\x32J.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.NegotiationParticipantAckb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.negotiation_ack_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NEGOTIATIONACK']._serialized_start=206
  _globals['_NEGOTIATIONACK']._serialized_end=349
# @@protoc_insertion_point(module_scope)
