# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/ubx_esf_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import esf_sensor_status_pb2 as make87__messages__ros2_dot_rolling_dot_ublox__ubx__msgs_dot_msg_dot_esf__sensor__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/ublox_ubx_msgs/msg/ubx_esf_status.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1aGmake87_messages_ros2/rolling/ublox_ubx_msgs/msg/esf_sensor_status.proto\"\xd4\x02\n\x0cUBXEsfStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x0c\n\x04itow\x18\x02 \x01(\r\x12\x0f\n\x07version\x18\x03 \x01(\r\x12\x16\n\x0ewt_init_status\x18\x04 \x01(\r\x12\x16\n\x0emnt_alg_status\x18\x05 \x01(\r\x12\x17\n\x0fins_init_status\x18\x06 \x01(\r\x12\x17\n\x0fimu_init_status\x18\x07 \x01(\r\x12\x13\n\x0b\x66usion_mode\x18\x08 \x01(\r\x12\x10\n\x08num_sens\x18\t \x01(\r\x12Y\n\x0fsensor_statuses\x18\n \x03(\x0b\x32@.make87_messages_ros2.rolling.ublox_ubx_msgs.msg.ESFSensorStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.ubx_esf_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UBXESFSTATUS']._serialized_start=251
  _globals['_UBXESFSTATUS']._serialized_end=591
# @@protoc_insertion_point(module_scope)
