# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/system_modes_msgs/srv/get_available_modes.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/rolling/system_modes_msgs/srv/get_available_modes.proto\x12\x32make87_messages_ros2.rolling.system_modes_msgs.srv\"\x1a\n\x18GetAvailableModesRequest\"4\n\x19GetAvailableModesResponse\x12\x17\n\x0f\x61vailable_modes\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.system_modes_msgs.srv.get_available_modes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETAVAILABLEMODESREQUEST']._serialized_start=132
  _globals['_GETAVAILABLEMODESREQUEST']._serialized_end=158
  _globals['_GETAVAILABLEMODESRESPONSE']._serialized_start=160
  _globals['_GETAVAILABLEMODESRESPONSE']._serialized_end=212
# @@protoc_insertion_point(module_scope)
