# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_nav_time_utc.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import utc_std_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_utc__std__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_nav_time_utc.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a;make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/utc_std.proto\"\xce\x02\n\rUBXNavTimeUTC\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0c\n\x04itow\x18\x02 \x01(\r\x12\r\n\x05t_acc\x18\x03 \x01(\r\x12\x0c\n\x04nano\x18\x04 \x01(\x05\x12\x0c\n\x04year\x18\x05 \x01(\x05\x12\r\n\x05month\x18\x06 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x07 \x01(\x05\x12\x0c\n\x04hour\x18\x08 \x01(\x05\x12\x0b\n\x03min\x18\t \x01(\x05\x12\x0b\n\x03sec\x18\n \x01(\x05\x12\x11\n\tvalid_tow\x18\x0b \x01(\x08\x12\x11\n\tvalid_wkn\x18\x0c \x01(\x08\x12\x11\n\tvalid_utc\x18\r \x01(\x08\x12\x46\n\x07utc_std\x18\x0e \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.UtcStdb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.ubx_nav_time_utc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UBXNAVTIMEUTC']._serialized_start=235
  _globals['_UBXNAVTIMEUTC']._serialized_end=569
# @@protoc_insertion_point(module_scope)
