# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_nav_msgs/msg/route_offset.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_position_pb2 as make87__messages__ros2_dot_rolling_dot_marti__nav__msgs_dot_msg_dot_route__position__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/marti_nav_msgs/msg/route_offset.proto\x12/make87_messages_ros2.rolling.marti_nav_msgs.msg\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x44make87_messages_ros2/rolling/marti_nav_msgs/msg/route_position.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xf5\x01\n\x0bRouteOffset\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12K\n\rrelative_pose\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12V\n\x0eroute_position\x18\x03 \x01(\x0b\x32>.make87_messages_ros2.rolling.marti_nav_msgs.msg.RoutePositionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_nav_msgs.msg.route_offset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROUTEOFFSET']._serialized_start=305
  _globals['_ROUTEOFFSET']._serialized_end=550
# @@protoc_insertion_point(module_scope)
