# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/sig_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import sig_flags_pb2 as make87__messages__ros2_dot_rolling_dot_ublox__ubx__msgs_dot_msg_dot_sig__flags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/ublox_ubx_msgs/msg/sig_data.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\x1a?make87_messages_ros2/rolling/ublox_ubx_msgs/msg/sig_flags.proto\"\xf3\x01\n\x07SigData\x12\x0f\n\x07gnss_id\x18\x01 \x01(\r\x12\r\n\x05sv_id\x18\x02 \x01(\r\x12\x0e\n\x06sig_id\x18\x03 \x01(\r\x12\x0f\n\x07\x66req_id\x18\x04 \x01(\r\x12\x0e\n\x06pr_res\x18\x05 \x01(\x05\x12\x0b\n\x03\x63no\x18\x06 \x01(\r\x12\x13\n\x0bquality_ind\x18\x07 \x01(\r\x12\x13\n\x0b\x63orr_source\x18\x08 \x01(\r\x12\x12\n\niono_model\x18\t \x01(\r\x12L\n\tsig_flags\x18\n \x01(\x0b\x32\x39.make87_messages_ros2.rolling.ublox_ubx_msgs.msg.SigFlagsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.sig_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SIGDATA']._serialized_start=181
  _globals['_SIGDATA']._serialized_end=424
# @@protoc_insertion_point(module_scope)
