# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/cartographer_ros_msgs/srv/submap_query.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.cartographer_ros_msgs.msg import status_response_pb2 as make87__messages__ros2_dot_humble_dot_cartographer__ros__msgs_dot_msg_dot_status__response__pb2
from make87_messages_ros2.humble.cartographer_ros_msgs.msg import submap_texture_pb2 as make87__messages__ros2_dot_humble_dot_cartographer__ros__msgs_dot_msg_dot_submap__texture__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/cartographer_ros_msgs/srv/submap_query.proto\x12\x35make87_messages_ros2.humble.cartographer_ros_msgs.srv\x1a!make87_messages/core/header.proto\x1aKmake87_messages_ros2/humble/cartographer_ros_msgs/msg/status_response.proto\x1aJmake87_messages_ros2/humble/cartographer_ros_msgs/msg/submap_texture.proto\"o\n\x12SubmapQueryRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x15\n\rtrajectory_id\x18\x02 \x01(\x05\x12\x14\n\x0csubmap_index\x18\x03 \x01(\x05\"\x8a\x02\n\x13SubmapQueryResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12U\n\x06status\x18\x02 \x01(\x0b\x32\x45.make87_messages_ros2.humble.cartographer_ros_msgs.msg.StatusResponse\x12\x16\n\x0esubmap_version\x18\x03 \x01(\x05\x12V\n\x08textures\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.humble.cartographer_ros_msgs.msg.SubmapTextureb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.cartographer_ros_msgs.srv.submap_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SUBMAPQUERYREQUEST']._serialized_start=319
  _globals['_SUBMAPQUERYREQUEST']._serialized_end=430
  _globals['_SUBMAPQUERYRESPONSE']._serialized_start=433
  _globals['_SUBMAPQUERYRESPONSE']._serialized_end=699
# @@protoc_insertion_point(module_scope)
