# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_fleet_msgs/msg/lane_states.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import speed_limited_lane_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_speed__limited__lane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rmf_fleet_msgs/msg/lane_states.proto\x12/make87_messages_ros2.rolling.rmf_fleet_msgs.msg\x1aHmake87_messages_ros2/rolling/rmf_fleet_msgs/msg/speed_limited_lane.proto\"\x8f\x01\n\nLaneStates\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63losed_lanes\x18\x02 \x03(\x04\x12W\n\x0cspeed_limits\x18\x03 \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.SpeedLimitedLaneb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_fleet_msgs.msg.lane_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LANESTATES']._serialized_start=193
  _globals['_LANESTATES']._serialized_end=336
# @@protoc_insertion_point(module_scope)
