# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/itinerary_set.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import route_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/itinerary_set.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1a=make87_messages_ros2/rolling/rmf_traffic_msgs/msg/route.proto\"\xaf\x01\n\x0cItinerarySet\x12\x13\n\x0bparticipant\x18\x01 \x01(\x04\x12\x0c\n\x04plan\x18\x02 \x01(\x04\x12K\n\titinerary\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.Route\x12\x14\n\x0cstorage_base\x18\x04 \x01(\x04\x12\x19\n\x11itinerary_version\x18\x05 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.itinerary_set_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ITINERARYSET']._serialized_start=188
  _globals['_ITINERARYSET']._serialized_end=363
# @@protoc_insertion_point(module_scope)
