# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ds_dbw_msgs/msg/driver_assist.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ds_dbw_msgs.msg import decel_src_pb2 as make87__messages__ros2_dot_humble_dot_ds__dbw__msgs_dot_msg_dot_decel__src__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/humble/ds_dbw_msgs/msg/driver_assist.proto\x12+make87_messages_ros2.humble.ds_dbw_msgs.msg\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/ds_dbw_msgs/msg/decel_src.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xa3\x04\n\x0c\x44riverAssist\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\r\n\x05\x64\x65\x63\x65l\x18\x03 \x01(\x02\x12H\n\tdecel_src\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.humble.ds_dbw_msgs.msg.DecelSrc\x12\x12\n\nfcw_active\x18\x05 \x01(\x08\x12\x13\n\x0b\x66\x63w_enabled\x18\x06 \x01(\x08\x12\x12\n\naeb_active\x18\x07 \x01(\x08\x12\x15\n\raeb_precharge\x18\x08 \x01(\x08\x12\x13\n\x0b\x61\x65\x62_enabled\x18\t \x01(\x08\x12\x13\n\x0b\x61\x63\x63_braking\x18\n \x01(\x08\x12\x13\n\x0b\x61\x63\x63_enabled\x18\x0b \x01(\x08\x12\x14\n\x0c\x62lis_l_alert\x18\x0c \x01(\x08\x12\x16\n\x0e\x62lis_l_enabled\x18\r \x01(\x08\x12\x14\n\x0c\x62lis_r_alert\x18\x0e \x01(\x08\x12\x16\n\x0e\x62lis_r_enabled\x18\x0f \x01(\x08\x12\x13\n\x0b\x63ta_l_alert\x18\x10 \x01(\x08\x12\x15\n\rcta_l_enabled\x18\x11 \x01(\x08\x12\x13\n\x0b\x63ta_r_alert\x18\x12 \x01(\x08\x12\x15\n\rcta_r_enabled\x18\x13 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ds_dbw_msgs.msg.driver_assist_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DRIVERASSIST']._serialized_start=264
  _globals['_DRIVERASSIST']._serialized_end=811
# @@protoc_insertion_point(module_scope)
