# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plotjuggler_msgs/msg/data_points.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.plotjuggler_msgs.msg import data_point_pb2 as make87__messages__ros2_dot_jazzy_dot_plotjuggler__msgs_dot_msg_dot_data__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/plotjuggler_msgs/msg/data_points.proto\x12/make87_messages_ros2.jazzy.plotjuggler_msgs.msg\x1a@make87_messages_ros2/jazzy/plotjuggler_msgs/msg/data_point.proto\"r\n\nDataPoints\x12\x17\n\x0f\x64ictionary_uuid\x18\x01 \x01(\r\x12K\n\x07samples\x18\x02 \x03(\x0b\x32:.make87_messages_ros2.jazzy.plotjuggler_msgs.msg.DataPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plotjuggler_msgs.msg.data_points_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DATAPOINTS']._serialized_start=184
  _globals['_DATAPOINTS']._serialized_end=298
# @@protoc_insertion_point(module_scope)
