# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/srv/open_snapshot_stream.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import snapshot_stream_parameters_pb2 as make87__messages__ros2_dot_rolling_dot_py__trees__ros__interfaces_dot_msg_dot_snapshot__stream__parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/py_trees_ros_interfaces/srv/open_snapshot_stream.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.srv\x1aYmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/snapshot_stream_parameters.proto\"\x97\x01\n\x19OpenSnapshotStreamRequest\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x66\n\nparameters\x18\x02 \x01(\x0b\x32R.make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.SnapshotStreamParameters\"0\n\x1aOpenSnapshotStreamResponse\x12\x12\n\ntopic_name\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.srv.open_snapshot_stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OPENSNAPSHOTSTREAMREQUEST']._serialized_start=237
  _globals['_OPENSNAPSHOTSTREAMREQUEST']._serialized_end=388
  _globals['_OPENSNAPSHOTSTREAMRESPONSE']._serialized_start=390
  _globals['_OPENSNAPSHOTSTREAMRESPONSE']._serialized_end=438
# @@protoc_insertion_point(module_scope)
