# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/esf_raw.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ublox_msgs.msg import esf_raw_block_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__msgs_dot_msg_dot_esf__raw__block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/ublox_msgs/msg/esf_raw.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\x1a=make87_messages_ros2/jazzy/ublox_msgs/msg/esf_raw_block.proto\"c\n\x06\x45sfRAW\x12\x11\n\treserved0\x18\x01 \x03(\r\x12\x46\n\x06\x62locks\x18\x02 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.ublox_msgs.msg.EsfRAWBlockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.esf_raw_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESFRAW']._serialized_start=165
  _globals['_ESFRAW']._serialized_end=264
# @@protoc_insertion_point(module_scope)
