# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/get_cartesian_path.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_trajectory_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__trajectory__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/moveit_msgs/srv/get_cartesian_path.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/constraints.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/move_it_error_codes.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\x1a\x42make87_messages_ros2/humble/moveit_msgs/msg/robot_trajectory.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xb7\x05\n\x17GetCartesianPathRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12L\n\x0bstart_state\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12\x12\n\ngroup_name\x18\x04 \x01(\t\x12\x11\n\tlink_name\x18\x05 \x01(\t\x12\x46\n\twaypoints\x18\x06 \x03(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x10\n\x08max_step\x18\x07 \x01(\x01\x12\x16\n\x0ejump_threshold\x18\x08 \x01(\x01\x12 \n\x18prismatic_jump_threshold\x18\t \x01(\x01\x12\x1f\n\x17revolute_jump_threshold\x18\n \x01(\x01\x12\x18\n\x10\x61void_collisions\x18\x0b \x01(\x08\x12R\n\x10path_constraints\x18\x0c \x01(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\x12#\n\x1bmax_velocity_scaling_factor\x18\r \x01(\x01\x12\'\n\x1fmax_acceleration_scaling_factor\x18\x0e \x01(\x01\x12$\n\x1c\x63\x61rtesian_speed_limited_link\x18\x0f \x01(\t\x12\x1b\n\x13max_cartesian_speed\x18\x10 \x01(\x01\"\xcb\x02\n\x18GetCartesianPathResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12L\n\x0bstart_state\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12N\n\x08solution\x18\x03 \x01(\x0b\x32<.make87_messages_ros2.humble.moveit_msgs.msg.RobotTrajectory\x12\x10\n\x08\x66raction\x18\x04 \x01(\x01\x12Q\n\nerror_code\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.humble.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.get_cartesian_path_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETCARTESIANPATHREQUEST']._serialized_start=531
  _globals['_GETCARTESIANPATHREQUEST']._serialized_end=1226
  _globals['_GETCARTESIANPATHRESPONSE']._serialized_start=1229
  _globals['_GETCARTESIANPATHRESPONSE']._serialized_end=1560
# @@protoc_insertion_point(module_scope)
