# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/cleanup_local_grids.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rtabmap_msgs/srv/cleanup_local_grids.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\"@\n\x18\x43leanupLocalGridsRequest\x12\x0e\n\x06radius\x18\x01 \x01(\x05\x12\x14\n\x0c\x66ilter_scans\x18\x02 \x01(\x08\"-\n\x19\x43leanupLocalGridsResponse\x12\x10\n\x08modified\x18\x01 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.cleanup_local_grids_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CLEANUPLOCALGRIDSREQUEST']._serialized_start=118
  _globals['_CLEANUPLOCALGRIDSREQUEST']._serialized_end=182
  _globals['_CLEANUPLOCALGRIDSRESPONSE']._serialized_start=184
  _globals['_CLEANUPLOCALGRIDSRESPONSE']._serialized_end=229
# @@protoc_insertion_point(module_scope)
