# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_msgs/msg/nav_dgps.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ublox_msgs.msg import nav_dgpssv_pb2 as make87__messages__ros2_dot_humble_dot_ublox__msgs_dot_msg_dot_nav__dgpssv__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/humble/ublox_msgs/msg/nav_dgps.proto\x12*make87_messages_ros2.humble.ublox_msgs.msg\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/ublox_msgs/msg/nav_dgpssv.proto\"\xef\x01\n\x07NavDGPS\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05i_tow\x18\x02 \x01(\r\x12\x0b\n\x03\x61ge\x18\x03 \x01(\x05\x12\x0f\n\x07\x62\x61se_id\x18\x04 \x01(\x05\x12\x13\n\x0b\x62\x61se_health\x18\x05 \x01(\x05\x12\x0e\n\x06num_ch\x18\x06 \x01(\x05\x12\x0e\n\x06status\x18\x07 \x01(\r\x12\x11\n\treserved1\x18\x08 \x01(\r\x12\x41\n\x02sv\x18\t \x03(\x0b\x32\x35.make87_messages_ros2.humble.ublox_msgs.msg.NavDGPSSVb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_msgs.msg.nav_dgps_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NAVDGPS']._serialized_start=202
  _globals['_NAVDGPS']._serialized_end=441
# @@protoc_insertion_point(module_scope)
