# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_introspection_msgs/msg/topic_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/marti_introspection_msgs/msg/topic_info.proto\x12\x39make87_messages_ros2.rolling.marti_introspection_msgs.msg\"~\n\tTopicInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rresolved_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05group\x18\x04 \x01(\t\x12\x14\n\x0cmessage_type\x18\x05 \x01(\t\x12\x12\n\nadvertised\x18\x06 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_introspection_msgs.msg.topic_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TOPICINFO']._serialized_start=137
  _globals['_TOPICINFO']._serialized_end=263
# @@protoc_insertion_point(module_scope)
