# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mapviz_interfaces/srv/add_mapviz_display.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.marti_common_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_jazzy_dot_marti__common__msgs_dot_msg_dot_key__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/mapviz_interfaces/srv/add_mapviz_display.proto\x12\x30make87_messages_ros2.jazzy.mapviz_interfaces.srv\x1a@make87_messages_ros2/jazzy/marti_common_msgs/msg/key_value.proto\"\xaa\x01\n\x17\x41\x64\x64MapvizDisplayRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\ndraw_order\x18\x03 \x01(\x05\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12N\n\nproperties\x18\x05 \x03(\x0b\x32:.make87_messages_ros2.jazzy.marti_common_msgs.msg.KeyValue\"<\n\x18\x41\x64\x64MapvizDisplayResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mapviz_interfaces.srv.add_mapviz_display_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ADDMAPVIZDISPLAYREQUEST']._serialized_start=194
  _globals['_ADDMAPVIZDISPLAYREQUEST']._serialized_end=364
  _globals['_ADDMAPVIZDISPLAYRESPONSE']._serialized_start=366
  _globals['_ADDMAPVIZDISPLAYRESPONSE']._serialized_end=426
# @@protoc_insertion_point(module_scope)
