# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mrpt_nav_interfaces/msg/georeferencing_metadata.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/mrpt_nav_interfaces/msg/georeferencing_metadata.proto\x12\x34make87_messages_ros2.rolling.mrpt_nav_interfaces.msg\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1aImake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance.proto\"\xa6\x02\n\x16GeoreferencingMetadata\x12\r\n\x05valid\x18\x01 \x01(\x08\x12X\n\x0ct_enu_to_map\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovariance\x12J\n\x0ct_enu_to_utm\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x11\n\tlongitude\x18\x05 \x01(\x01\x12\x0e\n\x06height\x18\x06 \x01(\x01\x12\x10\n\x08utm_zone\x18\x07 \x01(\x05\x12\x10\n\x08utm_band\x18\x08 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mrpt_nav_interfaces.msg.georeferencing_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GEOREFERENCINGMETADATA']._serialized_start=275
  _globals['_GEOREFERENCINGMETADATA']._serialized_end=569
# @@protoc_insertion_point(module_scope)
