# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_gz_interfaces/srv/control_world.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ros_gz_interfaces.msg import world_control_pb2 as make87__messages__ros2_dot_rolling_dot_ros__gz__interfaces_dot_msg_dot_world__control__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/ros_gz_interfaces/srv/control_world.proto\x12\x32make87_messages_ros2.rolling.ros_gz_interfaces.srv\x1a\x46make87_messages_ros2/rolling/ros_gz_interfaces/msg/world_control.proto\"n\n\x13\x43ontrolWorldRequest\x12W\n\rworld_control\x18\x01 \x01(\x0b\x32@.make87_messages_ros2.rolling.ros_gz_interfaces.msg.WorldControl\"\'\n\x14\x43ontrolWorldResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_gz_interfaces.srv.control_world_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONTROLWORLDREQUEST']._serialized_start=198
  _globals['_CONTROLWORLDREQUEST']._serialized_end=308
  _globals['_CONTROLWORLDRESPONSE']._serialized_start=310
  _globals['_CONTROLWORLDRESPONSE']._serialized_end=349
# @@protoc_insertion_point(module_scope)
