# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/set_link_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.gazebo_msgs.msg import link_state_pb2 as make87__messages__ros2_dot_jazzy_dot_gazebo__msgs_dot_msg_dot_link__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/gazebo_msgs/srv/set_link_state.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a;make87_messages_ros2/jazzy/gazebo_msgs/msg/link_state.proto\"`\n\x13SetLinkStateRequest\x12I\n\nlink_state\x18\x01 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.gazebo_msgs.msg.LinkState\"?\n\x14SetLinkStateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0estatus_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.set_link_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETLINKSTATEREQUEST']._serialized_start=172
  _globals['_SETLINKSTATEREQUEST']._serialized_end=268
  _globals['_SETLINKSTATERESPONSE']._serialized_start=270
  _globals['_SETLINKSTATERESPONSE']._serialized_end=333
# @@protoc_insertion_point(module_scope)
