# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/attached_collision_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_joint__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/moveit_msgs/msg/attached_collision_object.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x41make87_messages_ros2/jazzy/moveit_msgs/msg/collision_object.proto\x1a\x45make87_messages_ros2/jazzy/trajectory_msgs/msg/joint_trajectory.proto\"\xf7\x01\n\x17\x41ttachedCollisionObject\x12\x11\n\tlink_name\x18\x01 \x01(\t\x12K\n\x06object\x18\x02 \x01(\x0b\x32;.make87_messages_ros2.jazzy.moveit_msgs.msg.CollisionObject\x12\x13\n\x0btouch_links\x18\x03 \x03(\t\x12W\n\x0e\x64\x65tach_posture\x18\x04 \x01(\x0b\x32?.make87_messages_ros2.jazzy.trajectory_msgs.msg.JointTrajectory\x12\x0e\n\x06weight\x18\x05 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.attached_collision_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ATTACHEDCOLLISIONOBJECT']._serialized_start=261
  _globals['_ATTACHEDCOLLISIONOBJECT']._serialized_end=508
# @@protoc_insertion_point(module_scope)
