# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/psdk_interfaces/msg/gps_details.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/psdk_interfaces/msg/gps_details.proto\x12/make87_messages_ros2.humble.psdk_interfaces.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x90\x03\n\nGPSDetails\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x16\n\x0ehorizontal_dop\x18\x03 \x01(\x02\x12\x14\n\x0cposition_dop\x18\x04 \x01(\x02\x12\x11\n\tfix_state\x18\x05 \x01(\x02\x12\x19\n\x11vertical_accuracy\x18\x06 \x01(\x02\x12\x1b\n\x13horizontal_accuracy\x18\x07 \x01(\x02\x12\x16\n\x0espeed_accuracy\x18\x08 \x01(\x02\x12\x1f\n\x17num_gps_satellites_used\x18\t \x01(\r\x12#\n\x1bnum_glonass_satellites_used\x18\n \x01(\r\x12!\n\x19num_total_satellites_used\x18\x0b \x01(\r\x12\x13\n\x0bgps_counter\x18\x0c \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.psdk_interfaces.msg.gps_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GPSDETAILS']._serialized_start=209
  _globals['_GPSDETAILS']._serialized_end=609
# @@protoc_insertion_point(module_scope)
