# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/tf2_msgs/srv/frame_graph.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/tf2_msgs/srv/frame_graph.proto\x12\'make87_messages_ros2.jazzy.tf2_msgs.srv\"\x13\n\x11\x46rameGraphRequest\"(\n\x12\x46rameGraphResponse\x12\x12\n\nframe_yaml\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.tf2_msgs.srv.frame_graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FRAMEGRAPHREQUEST']._serialized_start=102
  _globals['_FRAMEGRAPHREQUEST']._serialized_end=121
  _globals['_FRAMEGRAPHRESPONSE']._serialized_start=123
  _globals['_FRAMEGRAPHRESPONSE']._serialized_end=163
# @@protoc_insertion_point(module_scope)
