# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/scenario_execution_interfaces/srv/execute_scenario.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.scenario_execution_interfaces.msg import scenario_pb2 as make87__messages__ros2_dot_jazzy_dot_scenario__execution__interfaces_dot_msg_dot_scenario__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/jazzy/scenario_execution_interfaces/srv/execute_scenario.proto\x12<make87_messages_ros2.jazzy.scenario_execution_interfaces.srv\x1aKmake87_messages_ros2/jazzy/scenario_execution_interfaces/msg/scenario.proto\"r\n\x16\x45xecuteScenarioRequest\x12X\n\x08scenario\x18\x01 \x01(\x0b\x32\x46.make87_messages_ros2.jazzy.scenario_execution_interfaces.msg.Scenario\")\n\x17\x45xecuteScenarioResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.scenario_execution_interfaces.srv.execute_scenario_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EXECUTESCENARIOREQUEST']._serialized_start=226
  _globals['_EXECUTESCENARIOREQUEST']._serialized_end=340
  _globals['_EXECUTESCENARIORESPONSE']._serialized_start=342
  _globals['_EXECUTESCENARIORESPONSE']._serialized_end=383
# @@protoc_insertion_point(module_scope)
