# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_rxm_rawx.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import rawx_data_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_rawx__data__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import rec_stat_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_rec__stat__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_rxm_rawx.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a=make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/rawx_data.proto\x1a<make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/rec_stat.proto\"\xb5\x02\n\nUBXRxmRawx\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0f\n\x07rcv_tow\x18\x02 \x01(\x01\x12\x0c\n\x04week\x18\x03 \x01(\r\x12\x0e\n\x06leap_s\x18\x04 \x01(\x05\x12\x10\n\x08num_meas\x18\x05 \x01(\r\x12H\n\x08rec_stat\x18\x06 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.RecStat\x12\x0f\n\x07version\x18\x07 \x01(\r\x12J\n\trawx_data\x18\x08 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.RawxDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.ubx_rxm_rawx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UBXRXMRAWX']._serialized_start=295
  _globals['_UBXRXMRAWX']._serialized_end=604
# @@protoc_insertion_point(module_scope)
