# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosapi_msgs/srv/node_details.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/rosapi_msgs/srv/node_details.proto\x12,make87_messages_ros2.rolling.rosapi_msgs.srv\"\"\n\x12NodeDetailsRequest\x12\x0c\n\x04node\x18\x01 \x01(\t\"P\n\x13NodeDetailsResponse\x12\x13\n\x0bsubscribing\x18\x01 \x03(\t\x12\x12\n\npublishing\x18\x02 \x03(\t\x12\x10\n\x08services\x18\x03 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosapi_msgs.srv.node_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NODEDETAILSREQUEST']._serialized_start=113
  _globals['_NODEDETAILSREQUEST']._serialized_end=147
  _globals['_NODEDETAILSRESPONSE']._serialized_start=149
  _globals['_NODEDETAILSRESPONSE']._serialized_end=229
# @@protoc_insertion_point(module_scope)
