# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/septentrio_gnss_driver/msg/meas_epoch_channel_type1.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import meas_epoch_channel_type2_pb2 as make87__messages__ros2_dot_jazzy_dot_septentrio__gnss__driver_dot_msg_dot_meas__epoch__channel__type2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/jazzy/septentrio_gnss_driver/msg/meas_epoch_channel_type1.proto\x12\x35make87_messages_ros2.jazzy.septentrio_gnss_driver.msg\x1aTmake87_messages_ros2/jazzy/septentrio_gnss_driver/msg/meas_epoch_channel_type2.proto\"\xbe\x02\n\x15MeasEpochChannelType1\x12\x12\n\nrx_channel\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\r\n\x05sv_id\x18\x03 \x01(\r\x12\x0c\n\x04misc\x18\x04 \x01(\r\x12\x10\n\x08\x63ode_lsb\x18\x05 \x01(\r\x12\x0f\n\x07\x64oppler\x18\x06 \x01(\x05\x12\x13\n\x0b\x63\x61rrier_lsb\x18\x07 \x01(\r\x12\x13\n\x0b\x63\x61rrier_msb\x18\x08 \x01(\x05\x12\x0b\n\x03\x63n0\x18\t \x01(\r\x12\x11\n\tlock_time\x18\n \x01(\r\x12\x10\n\x08obs_info\x18\x0b \x01(\r\x12\n\n\x02n2\x18\x0c \x01(\r\x12[\n\x05type2\x18\r \x03(\x0b\x32L.make87_messages_ros2.jazzy.septentrio_gnss_driver.msg.MeasEpochChannelType2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.septentrio_gnss_driver.msg.meas_epoch_channel_type1_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MEASEPOCHCHANNELTYPE1']._serialized_start=230
  _globals['_MEASEPOCHCHANNELTYPE1']._serialized_end=548
# @@protoc_insertion_point(module_scope)
