# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/msg/key_point.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rtabmap_msgs.msg import point2f_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_point2f__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/rtabmap_msgs/msg/key_point.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.msg\x1a\x39make87_messages_ros2/jazzy/rtabmap_msgs/msg/point2f.proto\"\x9d\x01\n\x08KeyPoint\x12@\n\x02pt\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Point2f\x12\x0c\n\x04size\x18\x02 \x01(\x02\x12\r\n\x05\x61ngle\x18\x03 \x01(\x02\x12\x10\n\x08response\x18\x04 \x01(\x02\x12\x0e\n\x06octave\x18\x05 \x01(\x05\x12\x10\n\x08\x63lass_id\x18\x06 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.msg.key_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_KEYPOINT']._serialized_start=168
  _globals['_KEYPOINT']._serialized_end=325
# @@protoc_insertion_point(module_scope)
