# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_charger_msgs/msg/charger_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rmf_charger_msgs/msg/charger_state.proto\x12\x31make87_messages_ros2.rolling.rmf_charger_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\"\xb6\x02\n\x0c\x43hargerState\x12O\n\x0c\x63harger_time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\r\n\x05state\x18\x02 \x01(\r\x12\x14\n\x0c\x63harger_name\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\x12\n\nrequest_id\x18\x05 \x01(\t\x12\x13\n\x0brobot_fleet\x18\x06 \x01(\t\x12\x12\n\nrobot_name\x18\x07 \x01(\t\x12\\\n\x15time_to_fully_charged\x18\x08 \x01(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_charger_msgs.msg.charger_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CHARGERSTATE']._serialized_start=257
  _globals['_CHARGERSTATE']._serialized_end=567
# @@protoc_insertion_point(module_scope)
