# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_scheduler_msgs/srv/list_schedules.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg import schedule_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__scheduler__msgs_dot_msg_dot_schedule__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/rmf_scheduler_msgs/srv/list_schedules.proto\x12\x31make87_messages_ros2.jazzy.rmf_scheduler_msgs.srv\x1a@make87_messages_ros2/jazzy/rmf_scheduler_msgs/msg/schedule.proto\"-\n\x14ListSchedulesRequest\x12\x15\n\rcreated_after\x18\x01 \x01(\x03\"\x89\x01\n\x15ListSchedulesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12N\n\tschedules\x18\x03 \x03(\x0b\x32;.make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg.Scheduleb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_scheduler_msgs.srv.list_schedules_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LISTSCHEDULESREQUEST']._serialized_start=191
  _globals['_LISTSCHEDULESREQUEST']._serialized_end=236
  _globals['_LISTSCHEDULESRESPONSE']._serialized_start=239
  _globals['_LISTSCHEDULESRESPONSE']._serialized_end=376
# @@protoc_insertion_point(module_scope)
