# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/realsense2_camera_msgs/msg/rgbd.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import camera_info_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_camera__info__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/realsense2_camera_msgs/msg/rgbd.proto\x12\x36make87_messages_ros2.humble.realsense2_camera_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/sensor_msgs/msg/camera_info.proto\x1a\x37make87_messages_ros2/humble/sensor_msgs/msg/image.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xa5\x03\n\x04RGBD\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12P\n\x0frgb_camera_info\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.humble.sensor_msgs.msg.CameraInfo\x12R\n\x11\x64\x65pth_camera_info\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.humble.sensor_msgs.msg.CameraInfo\x12?\n\x03rgb\x18\x05 \x01(\x0b\x32\x32.make87_messages_ros2.humble.sensor_msgs.msg.Image\x12\x41\n\x05\x64\x65pth\x18\x06 \x01(\x0b\x32\x32.make87_messages_ros2.humble.sensor_msgs.msg.Imageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.realsense2_camera_msgs.msg.rgbd_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RGBD']._serialized_start=336
  _globals['_RGBD']._serialized_end=757
# @@protoc_insertion_point(module_scope)
