# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rclpy_message_converter_msgs/msg/nested_uint8_array_test_message.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rclpy_message_converter_msgs.msg import uint8_array_test_message_pb2 as make87__messages__ros2_dot_jazzy_dot_rclpy__message__converter__msgs_dot_msg_dot_uint8__array__test__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\namake87_messages_ros2/jazzy/rclpy_message_converter_msgs/msg/nested_uint8_array_test_message.proto\x12;make87_messages_ros2.jazzy.rclpy_message_converter_msgs.msg\x1aZmake87_messages_ros2/jazzy/rclpy_message_converter_msgs/msg/uint8_array_test_message.proto\"\x81\x01\n\x1bNestedUint8ArrayTestMessage\x12\x62\n\x06\x61rrays\x18\x01 \x03(\x0b\x32R.make87_messages_ros2.jazzy.rclpy_message_converter_msgs.msg.Uint8ArrayTestMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rclpy_message_converter_msgs.msg.nested_uint8_array_test_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NESTEDUINT8ARRAYTESTMESSAGE']._serialized_start=255
  _globals['_NESTEDUINT8ARRAYTESTMESSAGE']._serialized_end=384
# @@protoc_insertion_point(module_scope)
