# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/mounting_position_f.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/ibeo_msgs/msg/mounting_position_f.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\"\x8b\x01\n\x11MountingPositionF\x12\x11\n\tyaw_angle\x18\x01 \x01(\x02\x12\x13\n\x0bpitch_angle\x18\x02 \x01(\x02\x12\x12\n\nroll_angle\x18\x03 \x01(\x02\x12\x12\n\nx_position\x18\x04 \x01(\x02\x12\x12\n\ny_position\x18\x05 \x01(\x02\x12\x12\n\nz_position\x18\x06 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.mounting_position_f_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MOUNTINGPOSITIONF']._serialized_start=113
  _globals['_MOUNTINGPOSITIONF']._serialized_end=252
# @@protoc_insertion_point(module_scope)
