# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/cfg_dgnss.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/ublox_msgs/msg/cfg_dgnss.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"1\n\x08\x43\x66gDGNSS\x12\x12\n\ndgnss_mode\x18\x01 \x01(\r\x12\x11\n\treserved0\x18\x02 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.cfg_dgnss_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CFGDGNSS']._serialized_start=108
  _globals['_CFGDGNSS']._serialized_end=157
# @@protoc_insertion_point(module_scope)
