# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/fuse_msgs/srv/set_pose_deprecated.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__stamped__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/fuse_msgs/srv/set_pose_deprecated.proto\x12*make87_messages_ros2.rolling.fuse_msgs.srv\x1aQmake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance_stamped.proto\"s\n\x18SetPoseDeprecatedRequest\x12W\n\x04pose\x18\x01 \x01(\x0b\x32I.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovarianceStamped\"\x1b\n\x19SetPoseDeprecatedResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.fuse_msgs.srv.set_pose_deprecated_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETPOSEDEPRECATEDREQUEST']._serialized_start=199
  _globals['_SETPOSEDEPRECATEDREQUEST']._serialized_end=314
  _globals['_SETPOSEDEPRECATEDRESPONSE']._serialized_start=316
  _globals['_SETPOSEDEPRECATEDRESPONSE']._serialized_end=343
# @@protoc_insertion_point(module_scope)
