# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/hand_eye_calibration.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rc_reason_msgs/srv/hand_eye_calibration.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\"\x1b\n\x19HandEyeCalibrationRequest\"\xf8\x01\n\x1aHandEyeCalibrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x42\n\x04pose\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\r\n\x05\x65rror\x18\x05 \x01(\x01\x12\x1f\n\x17translation_error_meter\x18\x06 \x01(\x01\x12\x1d\n\x15rotation_error_degree\x18\x07 \x01(\x01\x12\x15\n\rrobot_mounted\x18\x08 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.hand_eye_calibration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HANDEYECALIBRATIONREQUEST']._serialized_start=186
  _globals['_HANDEYECALIBRATIONREQUEST']._serialized_end=213
  _globals['_HANDEYECALIBRATIONRESPONSE']._serialized_start=216
  _globals['_HANDEYECALIBRATIONRESPONSE']._serialized_end=464
# @@protoc_insertion_point(module_scope)
