# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/zbar_ros_interfaces/msg/symbol.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.vision_msgs.msg import point2_d_pb2 as make87__messages__ros2_dot_jazzy_dot_vision__msgs_dot_msg_dot_point2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/zbar_ros_interfaces/msg/symbol.proto\x12\x32make87_messages_ros2.jazzy.zbar_ros_interfaces.msg\x1a\x39make87_messages_ros2/jazzy/vision_msgs/msg/point2_d.proto\"[\n\x06Symbol\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x43\n\x06points\x18\x02 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.vision_msgs.msg.Point2Db\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.zbar_ros_interfaces.msg.symbol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SYMBOL']._serialized_start=178
  _globals['_SYMBOL']._serialized_end=269
# @@protoc_insertion_point(module_scope)
