# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_perception_msgs/msg/predicted_object_kinematics.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import predicted_path_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__perception__msgs_dot_msg_dot_predicted__path__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import accel_with_covariance_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_accel__with__covariance__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/jazzy/autoware_perception_msgs/msg/predicted_object_kinematics.proto\x12\x37make87_messages_ros2.jazzy.autoware_perception_msgs.msg\x1aLmake87_messages_ros2/jazzy/autoware_perception_msgs/msg/predicted_path.proto\x1aHmake87_messages_ros2/jazzy/geometry_msgs/msg/accel_with_covariance.proto\x1aGmake87_messages_ros2/jazzy/geometry_msgs/msg/pose_with_covariance.proto\x1aHmake87_messages_ros2/jazzy/geometry_msgs/msg/twist_with_covariance.proto\"\xbf\x03\n\x19PredictedObjectKinematics\x12\x66\n\x1cinitial_pose_with_covariance\x18\x01 \x01(\x0b\x32@.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseWithCovariance\x12h\n\x1dinitial_twist_with_covariance\x18\x02 \x01(\x0b\x32\x41.make87_messages_ros2.jazzy.geometry_msgs.msg.TwistWithCovariance\x12o\n$initial_acceleration_with_covariance\x18\x03 \x01(\x0b\x32\x41.make87_messages_ros2.jazzy.geometry_msgs.msg.AccelWithCovariance\x12_\n\x0fpredicted_paths\x18\x04 \x03(\x0b\x32\x46.make87_messages_ros2.jazzy.autoware_perception_msgs.msg.PredictedPathb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_perception_msgs.msg.predicted_object_kinematics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PREDICTEDOBJECTKINEMATICS']._serialized_start=450
  _globals['_PREDICTEDOBJECTKINEMATICS']._serialized_end=897
# @@protoc_insertion_point(module_scope)
