# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/srv/unregister_participant.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/rmf_traffic_msgs/srv/unregister_participant.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.srv\"6\n\x1cUnregisterParticipantRequest\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\x04\"D\n\x1dUnregisterParticipantResponse\x12\x14\n\x0c\x63onfirmation\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.srv.unregister_participant_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UNREGISTERPARTICIPANTREQUEST']._serialized_start=133
  _globals['_UNREGISTERPARTICIPANTREQUEST']._serialized_end=187
  _globals['_UNREGISTERPARTICIPANTRESPONSE']._serialized_start=189
  _globals['_UNREGISTERPARTICIPANTRESPONSE']._serialized_end=257
# @@protoc_insertion_point(module_scope)
