# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/srv/grasp_planning.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import grasp_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_grasp__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/moveit_msgs/srv/grasp_planning.proto\x12,make87_messages_ros2.rolling.moveit_msgs.srv\x1a\x43make87_messages_ros2/rolling/moveit_msgs/msg/collision_object.proto\x1a\x38make87_messages_ros2/rolling/moveit_msgs/msg/grasp.proto\x1a\x46make87_messages_ros2/rolling/moveit_msgs/msg/move_it_error_codes.proto\"\xbc\x02\n\x14GraspPlanningRequest\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12M\n\x06target\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.moveit_msgs.msg.CollisionObject\x12\x18\n\x10support_surfaces\x18\x03 \x03(\t\x12M\n\x10\x63\x61ndidate_grasps\x18\x04 \x03(\x0b\x32\x33.make87_messages_ros2.rolling.moveit_msgs.msg.Grasp\x12X\n\x11movable_obstacles\x18\x05 \x03(\x0b\x32=.make87_messages_ros2.rolling.moveit_msgs.msg.CollisionObject\"\xb0\x01\n\x15GraspPlanningResponse\x12\x43\n\x06grasps\x18\x01 \x03(\x0b\x32\x33.make87_messages_ros2.rolling.moveit_msgs.msg.Grasp\x12R\n\nerror_code\x18\x02 \x01(\x0b\x32>.make87_messages_ros2.rolling.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.srv.grasp_planning_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRASPPLANNINGREQUEST']._serialized_start=315
  _globals['_GRASPPLANNINGREQUEST']._serialized_end=631
  _globals['_GRASPPLANNINGRESPONSE']._serialized_start=634
  _globals['_GRASPPLANNINGRESPONSE']._serialized_end=810
# @@protoc_insertion_point(module_scope)
