# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/msg/range_rectangle.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rc_reason_msgs.msg import rectangle_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_rectangle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rc_reason_msgs/msg/range_rectangle.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.msg\x1a?make87_messages_ros2/rolling/rc_reason_msgs/msg/rectangle.proto\"\xb8\x01\n\x0eRangeRectangle\x12R\n\x0emin_dimensions\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.rolling.rc_reason_msgs.msg.Rectangle\x12R\n\x0emax_dimensions\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.rc_reason_msgs.msg.Rectangleb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.msg.range_rectangle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RANGERECTANGLE']._serialized_start=188
  _globals['_RANGERECTANGLE']._serialized_end=372
# @@protoc_insertion_point(module_scope)
