# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/msg/camera_model.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import camera_info_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_camera__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/humble/rtabmap_msgs/msg/camera_model.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/geometry_msgs/msg/transform.proto\x1a=make87_messages_ros2/humble/sensor_msgs/msg/camera_info.proto\"\xdc\x01\n\x0b\x43\x61meraModel\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12L\n\x0b\x63\x61mera_info\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.sensor_msgs.msg.CameraInfo\x12Q\n\x0flocal_transform\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transformb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.msg.camera_model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CAMERAMODEL']._serialized_start=275
  _globals['_CAMERAMODEL']._serialized_end=495
# @@protoc_insertion_point(module_scope)
