# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plansys2_msgs/srv/get_problem_instance_details.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.plansys2_msgs.msg import param_pb2 as make87__messages__ros2_dot_jazzy_dot_plansys2__msgs_dot_msg_dot_param__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/jazzy/plansys2_msgs/srv/get_problem_instance_details.proto\x12,make87_messages_ros2.jazzy.plansys2_msgs.srv\x1a\x38make87_messages_ros2/jazzy/plansys2_msgs/msg/param.proto\"4\n GetProblemInstanceDetailsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\x8f\x01\n!GetProblemInstanceDetailsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x45\n\x08instance\x18\x02 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.plansys2_msgs.msg.Param\x12\x12\n\nerror_info\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plansys2_msgs.srv.get_problem_instance_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPROBLEMINSTANCEDETAILSREQUEST']._serialized_start=187
  _globals['_GETPROBLEMINSTANCEDETAILSREQUEST']._serialized_end=239
  _globals['_GETPROBLEMINSTANCEDETAILSRESPONSE']._serialized_start=242
  _globals['_GETPROBLEMINSTANCEDETAILSRESPONSE']._serialized_end=385
# @@protoc_insertion_point(module_scope)
