# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/application_outputs.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/application_outputs.proto\x12>make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg\"\x9f\x07\n\x12\x41pplicationOutputs\x12(\n evaluation_path_outputs_eval_out\x18\x01 \x03(\x08\x12\'\n\x1f\x65valuation_path_outputs_is_safe\x18\x02 \x03(\x08\x12(\n evaluation_path_outputs_is_valid\x18\x03 \x03(\x08\x12&\n\x1emonitoring_case_number_outputs\x18\x04 \x03(\r\x12,\n$monitoring_case_number_outputs_flags\x18\x05 \x03(\x08\x12\x19\n\x11sleep_mode_output\x18\x06 \x01(\r\x12\x1f\n\x17sleep_mode_output_valid\x18\x07 \x01(\x08\x12(\n error_flag_contamination_warning\x18\x08 \x01(\x08\x12&\n\x1e\x65rror_flag_contamination_error\x18\t \x01(\x08\x12%\n\x1d\x65rror_flag_manipulation_error\x18\n \x01(\x08\x12\x18\n\x10\x65rror_flag_glare\x18\x0b \x01(\x08\x12-\n%error_flag_reference_contour_intruded\x18\x0c \x01(\x08\x12!\n\x19\x65rror_flag_critical_error\x18\r \x01(\x08\x12\x1d\n\x15\x65rror_flags_are_valid\x18\x0e \x01(\x08\x12*\n\"linear_velocity_outputs_velocity_0\x18\x0f \x01(\x05\x12\x30\n(linear_velocity_outputs_velocity_0_valid\x18\x10 \x01(\x08\x12=\n5linear_velocity_outputs_velocity_0_transmitted_safely\x18\x11 \x01(\x08\x12*\n\"linear_velocity_outputs_velocity_1\x18\x12 \x01(\x05\x12\x30\n(linear_velocity_outputs_velocity_1_valid\x18\x13 \x01(\x08\x12=\n5linear_velocity_outputs_velocity_1_transmitted_safely\x18\x14 \x01(\x08\x12\x1a\n\x12resulting_velocity\x18\x15 \x03(\x05\x12 \n\x18resulting_velocity_flags\x18\x16 \x03(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.application_outputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_APPLICATIONOUTPUTS']._serialized_start=157
  _globals['_APPLICATIONOUTPUTS']._serialized_end=1084
# @@protoc_insertion_point(module_scope)
