# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/device_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg import active_monitoring_case_pb2 as make87__messages__ros2_dot_rolling_dot_sick__safevisionary__interfaces_dot_msg_dot_active__monitoring__case__pb2
from make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg import general_status_pb2 as make87__messages__ros2_dot_rolling_dot_sick__safevisionary__interfaces_dot_msg_dot_general__status__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/device_status.proto\x12>make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg\x1a[make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/active_monitoring_case.proto\x1aSmake87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/general_status.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xb3\x03\n\x0c\x44\x65viceStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\x65\n\x0egeneral_status\x18\x03 \x01(\x0b\x32M.make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.GeneralStatus\x12\x1a\n\x12\x63op_safety_related\x18\x04 \x01(\r\x12\x1e\n\x16\x63op_non_safety_related\x18\x05 \x01(\r\x12\x1a\n\x12\x63op_reset_required\x18\x06 \x01(\r\x12t\n\x16\x61\x63tive_monitoring_case\x18\x07 \x01(\x0b\x32T.make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.ActiveMonitoringCase\x12\x1b\n\x13\x63ontamination_level\x18\x08 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.device_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DEVICESTATUS']._serialized_start=385
  _globals['_DEVICESTATUS']._serialized_end=820
# @@protoc_insertion_point(module_scope)
