# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/webots_ros2_msgs/srv/spawn_node_from_string.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/jazzy/webots_ros2_msgs/srv/spawn_node_from_string.proto\x12/make87_messages_ros2.jazzy.webots_ros2_msgs.srv\"*\n\x1aSpawnNodeFromStringRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\".\n\x1bSpawnNodeFromStringResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.webots_ros2_msgs.srv.spawn_node_from_string_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SPAWNNODEFROMSTRINGREQUEST']._serialized_start=129
  _globals['_SPAWNNODEFROMSTRINGREQUEST']._serialized_end=171
  _globals['_SPAWNNODEFROMSTRINGRESPONSE']._serialized_start=173
  _globals['_SPAWNNODEFROMSTRINGRESPONSE']._serialized_end=219
# @@protoc_insertion_point(module_scope)
