# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/test_interface_files/msg/nested.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.test_interface_files.msg import basic_types_pb2 as make87__messages__ros2_dot_rolling_dot_test__interface__files_dot_msg_dot_basic__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/test_interface_files/msg/nested.proto\x12\x35make87_messages_ros2.rolling.test_interface_files.msg\x1aGmake87_messages_ros2/rolling/test_interface_files/msg/basic_types.proto\"f\n\x06Nested\x12\\\n\x11\x62\x61sic_types_value\x18\x01 \x01(\x0b\x32\x41.make87_messages_ros2.rolling.test_interface_files.msg.BasicTypesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.test_interface_files.msg.nested_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NESTED']._serialized_start=198
  _globals['_NESTED']._serialized_end=300
# @@protoc_insertion_point(module_scope)
