# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/object_recognition_msgs/msg/recognized_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__stamped__pb2
from make87_messages_ros2.humble.object_recognition_msgs.msg import object_type_pb2 as make87__messages__ros2_dot_humble_dot_object__recognition__msgs_dot_msg_dot_object__type__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.humble.shape_msgs.msg import mesh_pb2 as make87__messages__ros2_dot_humble_dot_shape__msgs_dot_msg_dot_mesh__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/humble/object_recognition_msgs/msg/recognized_object.proto\x12\x37make87_messages_ros2.humble.object_recognition_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/point.proto\x1aPmake87_messages_ros2/humble/geometry_msgs/msg/pose_with_covariance_stamped.proto\x1aImake87_messages_ros2/humble/object_recognition_msgs/msg/object_type.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\x1a\x35make87_messages_ros2/humble/shape_msgs/msg/mesh.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xb0\x04\n\x10RecognizedObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12Q\n\x04type\x18\x03 \x01(\x0b\x32\x43.make87_messages_ros2.humble.object_recognition_msgs.msg.ObjectType\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12N\n\x0cpoint_clouds\x18\x05 \x03(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2\x12G\n\rbounding_mesh\x18\x06 \x01(\x0b\x32\x30.make87_messages_ros2.humble.shape_msgs.msg.Mesh\x12O\n\x11\x62ounding_contours\x18\x07 \x03(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12V\n\x04pose\x18\x08 \x01(\x0b\x32H.make87_messages_ros2.humble.geometry_msgs.msg.PoseWithCovarianceStampedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.object_recognition_msgs.msg.recognized_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RECOGNIZEDOBJECT']._serialized_start=566
  _globals['_RECOGNIZEDOBJECT']._serialized_end=1126
# @@protoc_insertion_point(module_scope)
