# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nao_sensor_msgs/msg/buttons.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/nao_sensor_msgs/msg/buttons.proto\x12.make87_messages_ros2.jazzy.nao_sensor_msgs.msg\"\x8a\x01\n\x07\x42uttons\x12\r\n\x05\x63hest\x18\x01 \x01(\x08\x12\x1a\n\x12l_foot_bumper_left\x18\x02 \x01(\x08\x12\x1b\n\x13l_foot_bumper_right\x18\x03 \x01(\x08\x12\x1a\n\x12r_foot_bumper_left\x18\x04 \x01(\x08\x12\x1b\n\x13r_foot_bumper_right\x18\x05 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nao_sensor_msgs.msg.buttons_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BUTTONS']._serialized_start=113
  _globals['_BUTTONS']._serialized_end=251
# @@protoc_insertion_point(module_scope)
