# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/micro_ros_diagnostic_msgs/srv/micro_ros_self_test.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.micro_ros_diagnostic_msgs.msg import micro_ros_diagnostic_status_pb2 as make87__messages__ros2_dot_humble_dot_micro__ros__diagnostic__msgs_dot_msg_dot_micro__ros__diagnostic__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/humble/micro_ros_diagnostic_msgs/srv/micro_ros_self_test.proto\x12\x39make87_messages_ros2.humble.micro_ros_diagnostic_msgs.srv\x1a!make87_messages/core/header.proto\x1a[make87_messages_ros2/humble/micro_ros_diagnostic_msgs/msg/micro_ros_diagnostic_status.proto\"G\n\x17MicroROSSelfTestRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\"\xc9\x01\n\x18MicroROSSelfTestResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06passed\x18\x03 \x01(\r\x12\x63\n\x06status\x18\x04 \x01(\x0b\x32S.make87_messages_ros2.humble.micro_ros_diagnostic_msgs.msg.MicroROSDiagnosticStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.micro_ros_diagnostic_msgs.srv.micro_ros_self_test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MICROROSSELFTESTREQUEST']._serialized_start=274
  _globals['_MICROROSSELFTESTREQUEST']._serialized_end=345
  _globals['_MICROROSSELFTESTRESPONSE']._serialized_start=348
  _globals['_MICROROSSELFTESTRESPONSE']._serialized_end=549
# @@protoc_insertion_point(module_scope)
