# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/kinematic_solver_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import joint_limits_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_joint__limits__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/moveit_msgs/msg/kinematic_solver_info.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a=make87_messages_ros2/jazzy/moveit_msgs/msg/joint_limits.proto\"\x87\x01\n\x13KinematicSolverInfo\x12\x13\n\x0bjoint_names\x18\x01 \x03(\t\x12G\n\x06limits\x18\x02 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.moveit_msgs.msg.JointLimits\x12\x12\n\nlink_names\x18\x03 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.kinematic_solver_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_KINEMATICSOLVERINFO']._serialized_start=182
  _globals['_KINEMATICSOLVERINFO']._serialized_end=317
# @@protoc_insertion_point(module_scope)
