# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nao_lola_command_msgs/msg/left_eye_leds.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_color__rgba__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/nao_lola_command_msgs/msg/left_eye_leds.proto\x12\x34make87_messages_ros2.jazzy.nao_lola_command_msgs.msg\x1a\x38make87_messages_ros2/jazzy/std_msgs/msg/color_rgba.proto\"Q\n\x0bLeftEyeLeds\x12\x42\n\x06\x63olors\x18\x01 \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBAb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nao_lola_command_msgs.msg.left_eye_leds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LEFTEYELEDS']._serialized_start=188
  _globals['_LEFTEYELEDS']._serialized_end=269
# @@protoc_insertion_point(module_scope)
