# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/gimbal_manager_pitchyaw.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/mavros_msgs/srv/gimbal_manager_pitchyaw.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"\x89\x01\n\x1cGimbalManagerPitchyawRequest\x12\r\n\x05pitch\x18\x01 \x01(\x02\x12\x0b\n\x03yaw\x18\x02 \x01(\x02\x12\x12\n\npitch_rate\x18\x03 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x04 \x01(\x02\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12\x18\n\x10gimbal_device_id\x18\x06 \x01(\r\"@\n\x1dGimbalManagerPitchyawResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.gimbal_manager_pitchyaw_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERPITCHYAWREQUEST']._serialized_start=125
  _globals['_GIMBALMANAGERPITCHYAWREQUEST']._serialized_end=262
  _globals['_GIMBALMANAGERPITCHYAWRESPONSE']._serialized_start=264
  _globals['_GIMBALMANAGERPITCHYAWRESPONSE']._serialized_end=328
# @@protoc_insertion_point(module_scope)
