# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_perception_msgs/msg/traffic_signal.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.autoware_perception_msgs.msg import traffic_signal_element_pb2 as make87__messages__ros2_dot_humble_dot_autoware__perception__msgs_dot_msg_dot_traffic__signal__element__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/autoware_perception_msgs/msg/traffic_signal.proto\x12\x38make87_messages_ros2.humble.autoware_perception_msgs.msg\x1a!make87_messages/core/header.proto\x1aUmake87_messages_ros2/humble/autoware_perception_msgs/msg/traffic_signal_element.proto\"\xba\x01\n\rTrafficSignal\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x19\n\x11traffic_signal_id\x18\x02 \x01(\x03\x12`\n\x08\x65lements\x18\x03 \x03(\x0b\x32N.make87_messages_ros2.humble.autoware_perception_msgs.msg.TrafficSignalElementb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_perception_msgs.msg.traffic_signal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRAFFICSIGNAL']._serialized_start=262
  _globals['_TRAFFICSIGNAL']._serialized_end=448
# @@protoc_insertion_point(module_scope)
