# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/kartech_linear_actuator_msgs/msg/enhanced_position_rpt.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/jazzy/kartech_linear_actuator_msgs/msg/enhanced_position_rpt.proto\x12;make87_messages_ros2.jazzy.kartech_linear_actuator_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xe4\x02\n\x13\x45nhancedPositionRpt\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x17\n\x0fshaft_extension\x18\x02 \x01(\x01\x12\x1c\n\x14motor_overload_error\x18\x03 \x01(\x08\x12\x1d\n\x15\x63lutch_overload_error\x18\x04 \x01(\x08\x12\x1d\n\x15motor_open_load_error\x18\x05 \x01(\x08\x12\x1e\n\x16\x63lutch_open_load_error\x18\x06 \x01(\x08\x12\x1c\n\x14position_reach_error\x18\x07 \x01(\x08\x12 \n\x18hardware_warning_1_error\x18\x08 \x01(\x08\x12 \n\x18hardware_warning_2_error\x18\t \x01(\x08\x12\x15\n\rmotor_current\x18\n \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.kartech_linear_actuator_msgs.msg.enhanced_position_rpt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ENHANCEDPOSITIONRPT']._serialized_start=207
  _globals['_ENHANCEDPOSITIONRPT']._serialized_end=563
# @@protoc_insertion_point(module_scope)
