# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import multi_dof_joint_trajectory_point_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_multi__dof__joint__trajectory__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory.proto\x12.make87_messages_ros2.jazzy.trajectory_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1aUmake87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory_point.proto\"\xcd\x01\n\x17MultiDOFJointTrajectory\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x13\n\x0bjoint_names\x18\x02 \x03(\t\x12\\\n\x06points\x18\x03 \x03(\x0b\x32L.make87_messages_ros2.jazzy.trajectory_msgs.msg.MultiDOFJointTrajectoryPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.trajectory_msgs.msg.multi_dof_joint_trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MULTIDOFJOINTTRAJECTORY']._serialized_start=273
  _globals['_MULTIDOFJOINTTRAJECTORY']._serialized_end=478
# @@protoc_insertion_point(module_scope)
