# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/r2r_spl_test_interfaces/msg/basic_types.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/r2r_spl_test_interfaces/msg/basic_types.proto\x12\x37make87_messages_ros2.humble.r2r_spl_test_interfaces.msg\x1a!make87_messages/core/header.proto\"\xb4\x02\n\nBasicTypes\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08val_bool\x18\x02 \x01(\x08\x12\x10\n\x08val_byte\x18\x03 \x01(\r\x12\x10\n\x08val_char\x18\x04 \x01(\x05\x12\x13\n\x0bval_float32\x18\x05 \x01(\x02\x12\x13\n\x0bval_float64\x18\x06 \x01(\x01\x12\x10\n\x08val_int8\x18\x07 \x01(\x05\x12\x11\n\tval_uint8\x18\x08 \x01(\r\x12\x11\n\tval_int16\x18\t \x01(\x05\x12\x12\n\nval_uint16\x18\n \x01(\r\x12\x11\n\tval_int32\x18\x0b \x01(\x05\x12\x12\n\nval_uint32\x18\x0c \x01(\r\x12\x11\n\tval_int64\x18\r \x01(\x03\x12\x12\n\nval_uint64\x18\x0e \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.r2r_spl_test_interfaces.msg.basic_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BASICTYPES']._serialized_start=170
  _globals['_BASICTYPES']._serialized_end=478
# @@protoc_insertion_point(module_scope)
