# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/lgsvl_msgs/msg/detected_radar_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/lgsvl_msgs/msg/detected_radar_object.proto\x12*make87_messages_ros2.humble.lgsvl_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/point.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\"\xf4\x06\n\x13\x44\x65tectedRadarObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\x05\x12J\n\nsensor_aim\x18\x03 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12L\n\x0csensor_right\x18\x04 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12M\n\x0fsensor_position\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12O\n\x0fsensor_velocity\x18\x06 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\x14\n\x0csensor_angle\x18\x07 \x01(\x01\x12M\n\x0fobject_position\x18\x08 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12O\n\x0fobject_velocity\x18\t \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12V\n\x18object_relative_position\x18\n \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12X\n\x18object_relative_velocity\x18\x0b \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12T\n\x14object_collider_size\x18\x0c \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\x14\n\x0cobject_state\x18\r \x01(\r\x12\x15\n\rnew_detection\x18\x0e \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.lgsvl_msgs.msg.detected_radar_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTEDRADAROBJECT']._serialized_start=274
  _globals['_DETECTEDRADAROBJECT']._serialized_end=1158
# @@protoc_insertion_point(module_scope)
