# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/diagnostic_msgs/msg/diagnostic_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.diagnostic_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_jazzy_dot_diagnostic__msgs_dot_msg_dot_key__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/diagnostic_msgs/msg/diagnostic_status.proto\x12.make87_messages_ros2.jazzy.diagnostic_msgs.msg\x1a>make87_messages_ros2/jazzy/diagnostic_msgs/msg/key_value.proto\"\x9f\x01\n\x10\x44iagnosticStatus\x12\r\n\x05level\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x13\n\x0bhardware_id\x18\x04 \x01(\t\x12H\n\x06values\x18\x05 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.diagnostic_msgs.msg.KeyValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.diagnostic_msgs.msg.diagnostic_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DIAGNOSTICSTATUS']._serialized_start=187
  _globals['_DIAGNOSTICSTATUS']._serialized_end=346
# @@protoc_insertion_point(module_scope)
