# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/behaviour_tree.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.diagnostic_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_jazzy_dot_diagnostic__msgs_dot_msg_dot_key__value__pb2
from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import activity_item_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_activity__item__pb2
from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import behaviour_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_behaviour__pb2
from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import statistics_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/behaviour_tree.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg\x1a>make87_messages_ros2/jazzy/diagnostic_msgs/msg/key_value.proto\x1aJmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/activity_item.proto\x1a\x46make87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/behaviour.proto\x1aGmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/statistics.proto\"\x90\x03\n\rBehaviourTree\x12U\n\nbehaviours\x18\x01 \x03(\x0b\x32\x41.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.Behaviour\x12\x0f\n\x07\x63hanged\x18\x02 \x01(\x08\x12\\\n\x1a\x62lackboard_on_visited_path\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.diagnostic_msgs.msg.KeyValue\x12\x61\n\x13\x62lackboard_activity\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.ActivityItem\x12V\n\nstatistics\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.Statisticsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.behaviour_tree_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BEHAVIOURTREE']._serialized_start=421
  _globals['_BEHAVIOURTREE']._serialized_end=821
# @@protoc_insertion_point(module_scope)
