# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_query_participants_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__participants__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_query_spacetime_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__spacetime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query.proto\x12\x30make87_messages_ros2.humble.rmf_traffic_msgs.msg\x1a!make87_messages/core/header.proto\x1aRmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query_participants.proto\x1aOmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query_spacetime.proto\"\xfd\x01\n\rScheduleQuery\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12[\n\tspacetime\x18\x02 \x01(\x0b\x32H.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleQuerySpacetime\x12\x61\n\x0cparticipants\x18\x03 \x01(\x0b\x32K.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleQueryParticipantsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_traffic_msgs.msg.schedule_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SCHEDULEQUERY']._serialized_start=324
  _globals['_SCHEDULEQUERY']._serialized_end=577
# @@protoc_insertion_point(module_scope)
