# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/object2271.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ibeo_msgs.msg import tracked_properties_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_tracked__properties__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import untracked_properties_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_untracked__properties__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/ibeo_msgs/msg/object2271.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a\x43make87_messages_ros2/rolling/ibeo_msgs/msg/tracked_properties.proto\x1a\x45make87_messages_ros2/rolling/ibeo_msgs/msg/untracked_properties.proto\"\xa0\x02\n\nObject2271\x12\n\n\x02id\x18\x01 \x01(\r\x12$\n\x1ctracked_properties_available\x18\x02 \x01(\x08\x12&\n\x1euntracked_properties_available\x18\x03 \x01(\x08\x12Y\n\x12tracked_properties\x18\x04 \x01(\x0b\x32=.make87_messages_ros2.rolling.ibeo_msgs.msg.TrackedProperties\x12]\n\x14untracked_properties\x18\x05 \x01(\x0b\x32?.make87_messages_ros2.rolling.ibeo_msgs.msg.UntrackedPropertiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.object2271_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBJECT2271']._serialized_start=248
  _globals['_OBJECT2271']._serialized_end=536
# @@protoc_insertion_point(module_scope)
