# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/example_interfaces/msg/u_int64_multi_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.example_interfaces.msg import multi_array_layout_pb2 as make87__messages__ros2_dot_humble_dot_example__interfaces_dot_msg_dot_multi__array__layout__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/humble/example_interfaces/msg/u_int64_multi_array.proto\x12\x32make87_messages_ros2.humble.example_interfaces.msg\x1a!make87_messages/core/header.proto\x1aKmake87_messages_ros2/humble/example_interfaces/msg/multi_array_layout.proto\"\xa4\x01\n\x10UInt64MultiArray\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12T\n\x06layout\x18\x02 \x01(\x0b\x32\x44.make87_messages_ros2.humble.example_interfaces.msg.MultiArrayLayout\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.example_interfaces.msg.u_int64_multi_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UINT64MULTIARRAY']._serialized_start=245
  _globals['_UINT64MULTIARRAY']._serialized_end=409
# @@protoc_insertion_point(module_scope)
