# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/automotive_platform_msgs/msg/user_input_media.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/automotive_platform_msgs/msg/user_input_media.proto\x12\x39make87_messages_ros2.rolling.automotive_platform_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xde\x02\n\x0eUserInputMedia\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x12\n\nbtn_vol_up\x18\x02 \x01(\x08\x12\x14\n\x0c\x62tn_vol_down\x18\x03 \x01(\x08\x12\x10\n\x08\x62tn_mute\x18\x04 \x01(\x08\x12\x10\n\x08\x62tn_next\x18\x05 \x01(\x08\x12\x10\n\x08\x62tn_prev\x18\x06 \x01(\x08\x12\x18\n\x10\x62tn_next_hang_up\x18\x07 \x01(\x08\x12\x17\n\x0f\x62tn_prev_answer\x18\x08 \x01(\x08\x12\x13\n\x0b\x62tn_hang_up\x18\t \x01(\x08\x12\x12\n\nbtn_answer\x18\n \x01(\x08\x12\x10\n\x08\x62tn_play\x18\x0b \x01(\x08\x12\x11\n\tbtn_pause\x18\x0c \x01(\x08\x12\x16\n\x0e\x62tn_play_pause\x18\r \x01(\x08\x12\x10\n\x08\x62tn_mode\x18\x0e \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.automotive_platform_msgs.msg.user_input_media_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_USERINPUTMEDIA']._serialized_start=200
  _globals['_USERINPUTMEDIA']._serialized_end=550
# @@protoc_insertion_point(module_scope)
