# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/radar_msgs/msg/radar_track.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_jazzy_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/radar_msgs/msg/radar_track.proto\x12)make87_messages_ros2.jazzy.radar_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a:make87_messages_ros2/jazzy/geometry_msgs/msg/vector3.proto\x1a@make87_messages_ros2/jazzy/unique_identifier_msgs/msg/uuid.proto\"\x85\x04\n\nRadarTrack\x12I\n\x04uuid\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.jazzy.unique_identifier_msgs.msg.UUID\x12\x45\n\x08position\x18\x02 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12G\n\x08velocity\x18\x03 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12K\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12\x43\n\x04size\x18\x05 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12\x16\n\x0e\x63lassification\x18\x06 \x01(\r\x12\x1b\n\x13position_covariance\x18\x07 \x03(\x02\x12\x1b\n\x13velocity_covariance\x18\x08 \x03(\x02\x12\x1f\n\x17\x61\x63\x63\x65leration_covariance\x18\t \x03(\x02\x12\x17\n\x0fsize_covariance\x18\n \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.radar_msgs.msg.radar_track_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RADARTRACK']._serialized_start=291
  _globals['_RADARTRACK']._serialized_end=808
# @@protoc_insertion_point(module_scope)
