# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/constraints.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import joint_constraint_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_joint__constraint__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import orientation_constraint_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_orientation__constraint__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import position_constraint_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_position__constraint__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import visibility_constraint_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_visibility__constraint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/moveit_msgs/msg/constraints.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x43make87_messages_ros2/rolling/moveit_msgs/msg/joint_constraint.proto\x1aImake87_messages_ros2/rolling/moveit_msgs/msg/orientation_constraint.proto\x1a\x46make87_messages_ros2/rolling/moveit_msgs/msg/position_constraint.proto\x1aHmake87_messages_ros2/rolling/moveit_msgs/msg/visibility_constraint.proto\"\x9f\x03\n\x0b\x43onstraints\x12\x0c\n\x04name\x18\x01 \x01(\t\x12X\n\x11joint_constraints\x18\x02 \x03(\x0b\x32=.make87_messages_ros2.rolling.moveit_msgs.msg.JointConstraint\x12^\n\x14position_constraints\x18\x03 \x03(\x0b\x32@.make87_messages_ros2.rolling.moveit_msgs.msg.PositionConstraint\x12\x64\n\x17orientation_constraints\x18\x04 \x03(\x0b\x32\x43.make87_messages_ros2.rolling.moveit_msgs.msg.OrientationConstraint\x12\x62\n\x16visibility_constraints\x18\x05 \x03(\x0b\x32\x42.make87_messages_ros2.rolling.moveit_msgs.msg.VisibilityConstraintb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.constraints_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONSTRAINTS']._serialized_start=403
  _globals['_CONSTRAINTS']._serialized_end=818
# @@protoc_insertion_point(module_scope)
