# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mrpt_nav_interfaces/srv/get_pointmap_layer.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/mrpt_nav_interfaces/srv/get_pointmap_layer.proto\x12\x32make87_messages_ros2.jazzy.mrpt_nav_interfaces.srv\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\"-\n\x17GetPointmapLayerRequest\x12\x12\n\nlayer_name\x18\x01 \x01(\t\"r\n\x18GetPointmapLayerResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12G\n\x06points\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mrpt_nav_interfaces.srv.get_pointmap_layer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPOINTMAPLAYERREQUEST']._serialized_start=194
  _globals['_GETPOINTMAPLAYERREQUEST']._serialized_end=239
  _globals['_GETPOINTMAPLAYERRESPONSE']._serialized_start=241
  _globals['_GETPOINTMAPLAYERRESPONSE']._serialized_end=355
# @@protoc_insertion_point(module_scope)
