# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/set_joint_trajectory.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_joint__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/gazebo_msgs/srv/set_joint_trajectory.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a\x45make87_messages_ros2/jazzy/trajectory_msgs/msg/joint_trajectory.proto\"\x8b\x02\n\x19SetJointTrajectoryRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12Y\n\x10joint_trajectory\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.jazzy.trajectory_msgs.msg.JointTrajectory\x12\x46\n\nmodel_pose\x18\x03 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x16\n\x0eset_model_pose\x18\x04 \x01(\x08\x12\x1f\n\x17\x64isable_physics_updates\x18\x05 \x01(\x08\"E\n\x1aSetJointTrajectoryResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0estatus_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.set_joint_trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETJOINTTRAJECTORYREQUEST']._serialized_start=246
  _globals['_SETJOINTTRAJECTORYREQUEST']._serialized_end=513
  _globals['_SETJOINTTRAJECTORYRESPONSE']._serialized_start=515
  _globals['_SETJOINTTRAJECTORYRESPONSE']._serialized_end=584
# @@protoc_insertion_point(module_scope)
