# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/game_controller_spl_interfaces/msg/rcgcd16.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.game_controller_spl_interfaces.msg import team_info15_pb2 as make87__messages__ros2_dot_jazzy_dot_game__controller__spl__interfaces_dot_msg_dot_team__info15__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/game_controller_spl_interfaces/msg/rcgcd16.proto\x12=make87_messages_ros2.jazzy.game_controller_spl_interfaces.msg\x1aOmake87_messages_ros2/jazzy/game_controller_spl_interfaces/msg/team_info15.proto\"\xd8\x02\n\x07RCGCD16\x12\x15\n\rpacket_number\x18\x01 \x01(\r\x12\x18\n\x10players_per_team\x18\x02 \x01(\r\x12\x19\n\x11\x63ompetition_phase\x18\x03 \x01(\r\x12\x18\n\x10\x63ompetition_type\x18\x04 \x01(\r\x12\x12\n\ngame_phase\x18\x05 \x01(\r\x12\r\n\x05state\x18\x06 \x01(\r\x12\x10\n\x08set_play\x18\x07 \x01(\r\x12\x12\n\nfirst_half\x18\x08 \x01(\r\x12\x14\n\x0ckicking_team\x18\t \x01(\r\x12\x16\n\x0esecs_remaining\x18\n \x01(\x05\x12\x16\n\x0esecondary_time\x18\x0b \x01(\x05\x12X\n\x05teams\x18\x0c \x03(\x0b\x32I.make87_messages_ros2.jazzy.game_controller_spl_interfaces.msg.TeamInfo15b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.game_controller_spl_interfaces.msg.rcgcd16_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RCGCD16']._serialized_start=224
  _globals['_RCGCD16']._serialized_end=568
# @@protoc_insertion_point(module_scope)
