# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_perception_msgs/msg/traffic_light_group.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import traffic_light_element_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__perception__msgs_dot_msg_dot_traffic__light__element__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/jazzy/autoware_perception_msgs/msg/traffic_light_group.proto\x12\x37make87_messages_ros2.jazzy.autoware_perception_msgs.msg\x1aSmake87_messages_ros2/jazzy/autoware_perception_msgs/msg/traffic_light_element.proto\"\x93\x01\n\x11TrafficLightGroup\x12\x1e\n\x16traffic_light_group_id\x18\x01 \x01(\x03\x12^\n\x08\x65lements\x18\x02 \x03(\x0b\x32L.make87_messages_ros2.jazzy.autoware_perception_msgs.msg.TrafficLightElementb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_perception_msgs.msg.traffic_light_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRAFFICLIGHTGROUP']._serialized_start=228
  _globals['_TRAFFICLIGHTGROUP']._serialized_end=375
# @@protoc_insertion_point(module_scope)
