# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/controller_manager_msgs/msg/controller_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.controller_manager_msgs.msg import chain_connection_pb2 as make87__messages__ros2_dot_jazzy_dot_controller__manager__msgs_dot_msg_dot_chain__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/jazzy/controller_manager_msgs/msg/controller_state.proto\x12\x36make87_messages_ros2.jazzy.controller_manager_msgs.msg\x1aMmake87_messages_ros2/jazzy/controller_manager_msgs/msg/chain_connection.proto\"\xef\x02\n\x0f\x43ontrollerState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x1a\n\x12\x63laimed_interfaces\x18\x04 \x03(\t\x12#\n\x1brequired_command_interfaces\x18\x05 \x03(\t\x12!\n\x19required_state_interfaces\x18\x06 \x03(\t\x12\x14\n\x0cis_chainable\x18\x07 \x01(\x08\x12\x12\n\nis_chained\x18\x08 \x01(\x08\x12!\n\x19\x65xported_state_interfaces\x18\t \x03(\t\x12\x1c\n\x14reference_interfaces\x18\n \x03(\t\x12\x62\n\x11\x63hain_connections\x18\x0b \x03(\x0b\x32G.make87_messages_ros2.jazzy.controller_manager_msgs.msg.ChainConnectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.controller_manager_msgs.msg.controller_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONTROLLERSTATE']._serialized_start=217
  _globals['_CONTROLLERSTATE']._serialized_end=584
# @@protoc_insertion_point(module_scope)
