# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/get_base_plane_calibration.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.rolling.shape_msgs.msg import plane_pb2 as make87__messages__ros2_dot_rolling_dot_shape__msgs_dot_msg_dot_plane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/rc_reason_msgs/srv/get_base_plane_calibration.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\x1a\x37make87_messages_ros2/rolling/shape_msgs/msg/plane.proto\"~\n\x1eGetBasePlaneCalibrationRequest\x12\x12\n\npose_frame\x18\x01 \x01(\t\x12H\n\nrobot_pose\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\"\xca\x01\n\x1fGetBasePlaneCalibrationResponse\x12\x12\n\npose_frame\x18\x01 \x01(\t\x12\x41\n\x05plane\x18\x02 \x01(\x0b\x32\x32.make87_messages_ros2.rolling.shape_msgs.msg.Plane\x12P\n\x0breturn_code\x18\x03 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.get_base_plane_calibration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETBASEPLANECALIBRATIONREQUEST']._serialized_start=316
  _globals['_GETBASEPLANECALIBRATIONREQUEST']._serialized_end=442
  _globals['_GETBASEPLANECALIBRATIONRESPONSE']._serialized_start=445
  _globals['_GETBASEPLANECALIBRATIONRESPONSE']._serialized_end=647
# @@protoc_insertion_point(module_scope)
