# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/mon_ver.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ublox_msgs.msg import mon_ver_extension_pb2 as make87__messages__ros2_dot_rolling_dot_ublox__msgs_dot_msg_dot_mon__ver__extension__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/ublox_msgs/msg/mon_ver.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\x1a\x43make87_messages_ros2/rolling/ublox_msgs/msg/mon_ver_extension.proto\"\x81\x01\n\x06MonVER\x12\x12\n\nsw_version\x18\x01 \x03(\x05\x12\x12\n\nhw_version\x18\x02 \x03(\x05\x12O\n\textension\x18\x03 \x03(\x0b\x32<.make87_messages_ros2.rolling.ublox_msgs.msg.MonVERExtensionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.mon_ver_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MONVER']._serialized_start=176
  _globals['_MONVER']._serialized_end=305
# @@protoc_insertion_point(module_scope)
