# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/hil_sensor.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/mavros_msgs/msg/hil_sensor.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/vector3.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\x91\x03\n\tHilSensor\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x44\n\x03\x61\x63\x63\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\x45\n\x04gyro\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\x44\n\x03mag\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\x14\n\x0c\x61\x62s_pressure\x18\x05 \x01(\x02\x12\x15\n\rdiff_pressure\x18\x06 \x01(\x02\x12\x14\n\x0cpressure_alt\x18\x07 \x01(\x02\x12\x13\n\x0btemperature\x18\x08 \x01(\x02\x12\x16\n\x0e\x66ields_updated\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.hil_sensor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HILSENSOR']._serialized_start=230
  _globals['_HILSENSOR']._serialized_end=631
# @@protoc_insertion_point(module_scope)
