# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/gimbal_manager_set_attitude.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_quaternion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/mavros_msgs/msg/gimbal_manager_set_attitude.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\x1a?make87_messages_ros2/rolling/geometry_msgs/msg/quaternion.proto\"\x8f\x02\n\x18GimbalManagerSetAttitude\x12\x15\n\rtarget_system\x18\x01 \x01(\r\x12\x18\n\x10target_component\x18\x02 \x01(\r\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x18\n\x10gimbal_device_id\x18\x04 \x01(\r\x12\x45\n\x01q\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.rolling.geometry_msgs.msg.Quaternion\x12\x1a\n\x12\x61ngular_velocity_x\x18\x06 \x01(\x02\x12\x1a\n\x12\x61ngular_velocity_y\x18\x07 \x01(\x02\x12\x1a\n\x12\x61ngular_velocity_z\x18\x08 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.gimbal_manager_set_attitude_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERSETATTITUDE']._serialized_start=194
  _globals['_GIMBALMANAGERSETATTITUDE']._serialized_end=465
# @@protoc_insertion_point(module_scope)
