# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_signal_mask.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_signal_mask.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\"\xd7\x01\n\x11NovatelSignalMask\x12\x15\n\roriginal_mask\x18\x01 \x01(\r\x12\x1f\n\x17gps_l1_used_in_solution\x18\x02 \x01(\x08\x12\x1f\n\x17gps_l2_used_in_solution\x18\x03 \x01(\x08\x12\x1f\n\x17gps_l3_used_in_solution\x18\x04 \x01(\x08\x12#\n\x1bglonass_l1_used_in_solution\x18\x05 \x01(\x08\x12#\n\x1bglonass_l2_used_in_solution\x18\x06 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.novatel_signal_mask_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NOVATELSIGNALMASK']._serialized_start=131
  _globals['_NOVATELSIGNALMASK']._serialized_end=346
# @@protoc_insertion_point(module_scope)
