# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/qb_device_msgs/srv/set_commands.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/qb_device_msgs/srv/set_commands.proto\x12.make87_messages_ros2.humble.qb_device_msgs.srv\x1a!make87_messages/core/header.proto\"\xa7\x01\n\x12SetCommandsRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x13\n\x0bmax_repeats\x18\x03 \x01(\x05\x12\x14\n\x0cset_commands\x18\x04 \x01(\x08\x12\x1a\n\x12set_commands_async\x18\x05 \x01(\x08\x12\x10\n\x08\x63ommands\x18\x06 \x03(\x05\"f\n\x13SetCommandsResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x10\n\x08\x66\x61ilures\x18\x03 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.qb_device_msgs.srv.set_commands_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETCOMMANDSREQUEST']._serialized_start=153
  _globals['_SETCOMMANDSREQUEST']._serialized_end=320
  _globals['_SETCOMMANDSRESPONSE']._serialized_start=322
  _globals['_SETCOMMANDSRESPONSE']._serialized_end=424
# @@protoc_insertion_point(module_scope)
