# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/turtlesim/srv/teleport_relative.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/turtlesim/srv/teleport_relative.proto\x12(make87_messages_ros2.jazzy.turtlesim.srv\":\n\x17TeleportRelativeRequest\x12\x0e\n\x06linear\x18\x01 \x01(\x02\x12\x0f\n\x07\x61ngular\x18\x02 \x01(\x02\"\x1a\n\x18TeleportRelativeResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.turtlesim.srv.teleport_relative_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TELEPORTRELATIVEREQUEST']._serialized_start=110
  _globals['_TELEPORTRELATIVEREQUEST']._serialized_end=168
  _globals['_TELEPORTRELATIVERESPONSE']._serialized_start=170
  _globals['_TELEPORTRELATIVERESPONSE']._serialized_end=196
# @@protoc_insertion_point(module_scope)
