# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_status_aiding.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/sbg_driver/msg/sbg_status_aiding.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\"\x86\x03\n\x0fSbgStatusAiding\x12\x15\n\rgps1_pos_recv\x18\x01 \x01(\x08\x12\x15\n\rgps1_vel_recv\x18\x02 \x01(\x08\x12\x15\n\rgps1_hdt_recv\x18\x03 \x01(\x08\x12\x15\n\rgps1_utc_recv\x18\x04 \x01(\x08\x12\x15\n\rgps2_pos_recv\x18\x05 \x01(\x08\x12\x15\n\rgps2_vel_recv\x18\x06 \x01(\x08\x12\x15\n\rgps2_hdt_recv\x18\x07 \x01(\x08\x12\x15\n\rgps2_utc_recv\x18\x08 \x01(\x08\x12\x10\n\x08mag_recv\x18\t \x01(\x08\x12\x10\n\x08odo_recv\x18\n \x01(\x08\x12\x10\n\x08\x64vl_recv\x18\x0b \x01(\x08\x12\x11\n\tusbl_recv\x18\x0c \x01(\x08\x12\x12\n\ndepth_recv\x18\r \x01(\x08\x12\x15\n\rair_data_recv\x18\x0e \x01(\x08\x12\x15\n\ruser_pos_recv\x18\x0f \x01(\x08\x12\x15\n\ruser_vel_recv\x18\x10 \x01(\x08\x12\x19\n\x11user_heading_recv\x18\x11 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_status_aiding_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SBGSTATUSAIDING']._serialized_start=113
  _globals['_SBGSTATUSAIDING']._serialized_end=503
# @@protoc_insertion_point(module_scope)
