# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/topic_tools_interfaces/srv/demux_list.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/topic_tools_interfaces/srv/demux_list.proto\x12\x35make87_messages_ros2.jazzy.topic_tools_interfaces.srv\"\x12\n\x10\x44\x65muxListRequest\"#\n\x11\x44\x65muxListResponse\x12\x0e\n\x06topics\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.topic_tools_interfaces.srv.demux_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DEMUXLISTREQUEST']._serialized_start=129
  _globals['_DEMUXLISTREQUEST']._serialized_end=147
  _globals['_DEMUXLISTRESPONSE']._serialized_start=149
  _globals['_DEMUXLISTRESPONSE']._serialized_end=184
# @@protoc_insertion_point(module_scope)
