# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/geographic_msgs/msg/geo_point_stamped.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geographic_msgs.msg import geo_point_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_geo__point__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/geographic_msgs/msg/geo_point_stamped.proto\x12\x30make87_messages_ros2.rolling.geographic_msgs.msg\x1a@make87_messages_ros2/rolling/geographic_msgs/msg/geo_point.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa2\x01\n\x0fGeoPointStamped\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12L\n\x08position\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.geographic_msgs.msg.GeoPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.geographic_msgs.msg.geo_point_stamped_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GEOPOINTSTAMPED']._serialized_start=249
  _globals['_GEOPOINTSTAMPED']._serialized_end=411
# @@protoc_insertion_point(module_scope)
