# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/io_input_values.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/io_input_values.proto\x12>make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg\"K\n\rIOInputValues\x12\r\n\x05pin_5\x18\x01 \x01(\r\x12\r\n\x05pin_6\x18\x02 \x01(\r\x12\r\n\x05pin_7\x18\x03 \x01(\r\x12\r\n\x05pin_8\x18\x04 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.io_input_values_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_IOINPUTVALUES']._serialized_start=152
  _globals['_IOINPUTVALUES']._serialized_end=227
# @@protoc_insertion_point(module_scope)
