# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/action_msgs/msg/goal_status_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.action_msgs.msg import goal_status_pb2 as make87__messages__ros2_dot_jazzy_dot_action__msgs_dot_msg_dot_goal__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/action_msgs/msg/goal_status_array.proto\x12*make87_messages_ros2.jazzy.action_msgs.msg\x1a<make87_messages_ros2/jazzy/action_msgs/msg/goal_status.proto\"^\n\x0fGoalStatusArray\x12K\n\x0bstatus_list\x18\x01 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.action_msgs.msg.GoalStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.action_msgs.msg.goal_status_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GOALSTATUSARRAY']._serialized_start=176
  _globals['_GOALSTATUSARRAY']._serialized_end=270
# @@protoc_insertion_point(module_scope)
