# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_v2x_msgs.msg import virtual_gate_area_status_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__v2x__msgs_dot_msg_dot_virtual__gate__area__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_status.proto\x12\x30make87_messages_ros2.jazzy.autoware_v2x_msgs.msg\x1aOmake87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_area_status.proto\"k\n\x11VirtualGateStatus\x12V\n\x05\x61reas\x18\x01 \x03(\x0b\x32G.make87_messages_ros2.jazzy.autoware_v2x_msgs.msg.VirtualGateAreaStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_v2x_msgs.msg.virtual_gate_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VIRTUALGATESTATUS']._serialized_start=209
  _globals['_VIRTUALGATESTATUS']._serialized_end=316
# @@protoc_insertion_point(module_scope)
