# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/diagnostic_msgs/srv/add_diagnostics.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/diagnostic_msgs/srv/add_diagnostics.proto\x12\x30make87_messages_ros2.rolling.diagnostic_msgs.srv\"/\n\x15\x41\x64\x64\x44iagnosticsRequest\x12\x16\n\x0eload_namespace\x18\x01 \x01(\t\":\n\x16\x41\x64\x64\x44iagnosticsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.diagnostic_msgs.srv.add_diagnostics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ADDDIAGNOSTICSREQUEST']._serialized_start=124
  _globals['_ADDDIAGNOSTICSREQUEST']._serialized_end=171
  _globals['_ADDDIAGNOSTICSRESPONSE']._serialized_start=173
  _globals['_ADDDIAGNOSTICSRESPONSE']._serialized_end=231
# @@protoc_insertion_point(module_scope)
