# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/srv/get_dispatch_states.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_task_msgs.msg import dispatch_states_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__task__msgs_dot_msg_dot_dispatch__states__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/rmf_task_msgs/srv/get_dispatch_states.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.srv\x1a\x42make87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_states.proto\",\n\x18GetDispatchStatesRequest\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"z\n\x19GetDispatchStatesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12L\n\x06states\x18\x02 \x01(\x0b\x32<.make87_messages_ros2.jazzy.rmf_task_msgs.msg.DispatchStatesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.srv.get_dispatch_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETDISPATCHSTATESREQUEST']._serialized_start=188
  _globals['_GETDISPATCHSTATESREQUEST']._serialized_end=232
  _globals['_GETDISPATCHSTATESRESPONSE']._serialized_start=234
  _globals['_GETDISPATCHSTATESRESPONSE']._serialized_end=356
# @@protoc_insertion_point(module_scope)
