# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/nav_pvt.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/ublox_msgs/msg/nav_pvt.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\xf3\x03\n\x06NavPVT\x12\r\n\x05i_tow\x18\x01 \x01(\r\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\r\n\x05month\x18\x03 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\r\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0b\n\x03min\x18\x06 \x01(\r\x12\x0b\n\x03sec\x18\x07 \x01(\r\x12\r\n\x05valid\x18\x08 \x01(\r\x12\r\n\x05t_acc\x18\t \x01(\r\x12\x0c\n\x04nano\x18\n \x01(\x05\x12\x10\n\x08\x66ix_type\x18\x0b \x01(\r\x12\r\n\x05\x66lags\x18\x0c \x01(\r\x12\x0e\n\x06\x66lags2\x18\r \x01(\r\x12\x0e\n\x06num_sv\x18\x0e \x01(\r\x12\x0b\n\x03lon\x18\x0f \x01(\x05\x12\x0b\n\x03lat\x18\x10 \x01(\x05\x12\x0e\n\x06height\x18\x11 \x01(\x05\x12\r\n\x05h_msl\x18\x12 \x01(\x05\x12\r\n\x05h_acc\x18\x13 \x01(\r\x12\r\n\x05v_acc\x18\x14 \x01(\r\x12\r\n\x05vel_n\x18\x15 \x01(\x05\x12\r\n\x05vel_e\x18\x16 \x01(\x05\x12\r\n\x05vel_d\x18\x17 \x01(\x05\x12\x0f\n\x07g_speed\x18\x18 \x01(\x05\x12\x0f\n\x07heading\x18\x19 \x01(\x05\x12\r\n\x05s_acc\x18\x1a \x01(\r\x12\x10\n\x08head_acc\x18\x1b \x01(\r\x12\r\n\x05p_dop\x18\x1c \x01(\r\x12\x11\n\treserved1\x18\x1d \x03(\r\x12\x10\n\x08head_veh\x18\x1e \x01(\x05\x12\x0f\n\x07mag_dec\x18\x1f \x01(\x05\x12\x0f\n\x07mag_acc\x18  \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.nav_pvt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NAVPVT']._serialized_start=107
  _globals['_NAVPVT']._serialized_end=606
# @@protoc_insertion_point(module_scope)
