# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_mrr_msgs/msg/mrr_status_radar.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/delphi_mrr_msgs/msg/mrr_status_radar.proto\x12/make87_messages_ros2.humble.delphi_mrr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x8d\x04\n\x0eMrrStatusRadar\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x1d\n\x15\x63\x61n_interference_type\x18\x03 \x01(\r\x12 \n\x18\x63\x61n_recommend_unconverge\x18\x04 \x01(\x08\x12(\n can_blockage_sidelobe_filter_val\x18\x05 \x01(\r\x12\"\n\x1a\x63\x61n_radar_align_incomplete\x18\x06 \x01(\x08\x12\x1d\n\x15\x63\x61n_blockage_sidelobe\x18\x07 \x01(\x08\x12\x18\n\x10\x63\x61n_blockage_mnr\x18\x08 \x01(\x08\x12\x1e\n\x16\x63\x61n_radar_ext_cond_nok\x18\t \x01(\x08\x12!\n\x19\x63\x61n_radar_align_out_range\x18\n \x01(\x08\x12!\n\x19\x63\x61n_radar_align_not_start\x18\x0b \x01(\x08\x12 \n\x18\x63\x61n_radar_overheat_error\x18\x0c \x01(\x08\x12\x18\n\x10\x63\x61n_radar_not_op\x18\r \x01(\x08\x12\x1c\n\x14\x63\x61n_xcvr_operational\x18\x0e \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_mrr_msgs.msg.mrr_status_radar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MRRSTATUSRADAR']._serialized_start=214
  _globals['_MRRSTATUSRADAR']._serialized_end=739
# @@protoc_insertion_point(module_scope)
