# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/kobuki_ros_interfaces/msg/sensor_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/kobuki_ros_interfaces/msg/sensor_state.proto\x12\x34make87_messages_ros2.jazzy.kobuki_ros_interfaces.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xfe\x02\n\x0bSensorState\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x12\n\ntime_stamp\x18\x02 \x01(\r\x12\x0e\n\x06\x62umper\x18\x03 \x01(\r\x12\x12\n\nwheel_drop\x18\x04 \x01(\r\x12\r\n\x05\x63liff\x18\x05 \x01(\r\x12\x14\n\x0cleft_encoder\x18\x06 \x01(\r\x12\x15\n\rright_encoder\x18\x07 \x01(\r\x12\x10\n\x08left_pwm\x18\x08 \x01(\x05\x12\x11\n\tright_pwm\x18\t \x01(\x05\x12\x0f\n\x07\x62uttons\x18\n \x01(\r\x12\x0f\n\x07\x63harger\x18\x0b \x01(\r\x12\x0f\n\x07\x62\x61ttery\x18\x0c \x01(\r\x12\x0e\n\x06\x62ottom\x18\r \x03(\r\x12\x0f\n\x07\x63urrent\x18\x0e \x03(\r\x12\x14\n\x0cover_current\x18\x0f \x01(\r\x12\x15\n\rdigital_input\x18\x10 \x01(\r\x12\x14\n\x0c\x61nalog_input\x18\x11 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.kobuki_ros_interfaces.msg.sensor_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENSORSTATE']._serialized_start=184
  _globals['_SENSORSTATE']._serialized_end=566
# @@protoc_insertion_point(module_scope)
