# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_ubx_msgs/msg/ubx_nav_hp_pos_llh.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/ublox_ubx_msgs/msg/ubx_nav_hp_pos_llh.proto\x12.make87_messages_ros2.humble.ublox_ubx_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xfa\x03\n\x0eUBXNavHPPosLLH\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0f\n\x07version\x18\x03 \x01(\r\x12\x13\n\x0binvalid_lon\x18\x04 \x01(\x08\x12\x13\n\x0binvalid_lat\x18\x05 \x01(\x08\x12\x16\n\x0einvalid_height\x18\x06 \x01(\x08\x12\x14\n\x0cinvalid_hmsl\x18\x07 \x01(\x08\x12\x16\n\x0einvalid_lon_hp\x18\x08 \x01(\x08\x12\x16\n\x0einvalid_lat_hp\x18\t \x01(\x08\x12\x19\n\x11invalid_height_hp\x18\n \x01(\x08\x12\x17\n\x0finvalid_hmsl_hp\x18\x0b \x01(\x08\x12\x0c\n\x04itow\x18\x0c \x01(\r\x12\x0b\n\x03lon\x18\r \x01(\x05\x12\x0b\n\x03lat\x18\x0e \x01(\x05\x12\x0e\n\x06height\x18\x0f \x01(\x05\x12\x0c\n\x04hmsl\x18\x10 \x01(\x05\x12\x0e\n\x06lon_hp\x18\x11 \x01(\x05\x12\x0e\n\x06lat_hp\x18\x12 \x01(\x05\x12\x11\n\theight_hp\x18\x13 \x01(\x05\x12\x0f\n\x07hmsl_hp\x18\x14 \x01(\x05\x12\r\n\x05h_acc\x18\x15 \x01(\r\x12\r\n\x05v_acc\x18\x16 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_ubx_msgs.msg.ubx_nav_hp_pos_llh_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UBXNAVHPPOSLLH']._serialized_start=214
  _globals['_UBXNAVHPPOSLLH']._serialized_end=720
# @@protoc_insertion_point(module_scope)
