# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/visualization_msgs/msg/interactive_marker_update.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.visualization_msgs.msg import interactive_marker_pb2 as make87__messages__ros2_dot_jazzy_dot_visualization__msgs_dot_msg_dot_interactive__marker__pb2
from make87_messages_ros2.jazzy.visualization_msgs.msg import interactive_marker_pose_pb2 as make87__messages__ros2_dot_jazzy_dot_visualization__msgs_dot_msg_dot_interactive__marker__pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/jazzy/visualization_msgs/msg/interactive_marker_update.proto\x12\x31make87_messages_ros2.jazzy.visualization_msgs.msg\x1aJmake87_messages_ros2/jazzy/visualization_msgs/msg/interactive_marker.proto\x1aOmake87_messages_ros2/jazzy/visualization_msgs/msg/interactive_marker_pose.proto\"\x8b\x02\n\x17InteractiveMarkerUpdate\x12\x11\n\tserver_id\x18\x01 \x01(\t\x12\x0f\n\x07seq_num\x18\x02 \x01(\x04\x12\x0c\n\x04type\x18\x03 \x01(\r\x12U\n\x07markers\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.jazzy.visualization_msgs.msg.InteractiveMarker\x12W\n\x05poses\x18\x05 \x03(\x0b\x32H.make87_messages_ros2.jazzy.visualization_msgs.msg.InteractiveMarkerPose\x12\x0e\n\x06\x65rases\x18\x06 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.visualization_msgs.msg.interactive_marker_update_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTERACTIVEMARKERUPDATE']._serialized_start=294
  _globals['_INTERACTIVEMARKERUPDATE']._serialized_end=561
# @@protoc_insertion_point(module_scope)
