# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/grid_map_msgs/msg/grid_map_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/grid_map_msgs/msg/grid_map_info.proto\x12,make87_messages_ros2.jazzy.grid_map_msgs.msg\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"\x87\x01\n\x0bGridMapInfo\x12\x12\n\nresolution\x18\x01 \x01(\x01\x12\x10\n\x08length_x\x18\x02 \x01(\x01\x12\x10\n\x08length_y\x18\x03 \x01(\x01\x12@\n\x04pose\x18\x04 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Poseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.grid_map_msgs.msg.grid_map_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRIDMAPINFO']._serialized_start=172
  _globals['_GRIDMAPINFO']._serialized_end=307
# @@protoc_insertion_point(module_scope)
