# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/qb_device_msgs/msg/info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/humble/qb_device_msgs/msg/info.proto\x12.make87_messages_ros2.humble.qb_device_msgs.msg\x1a!make87_messages/core/header.proto\"\x9e\x02\n\x04Info\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x13\n\x0bserial_port\x18\x03 \x01(\t\x12\x13\n\x0bmax_repeats\x18\x04 \x01(\x05\x12\x15\n\rget_positions\x18\x05 \x01(\x08\x12\x14\n\x0cget_currents\x18\x06 \x01(\x08\x12\x1d\n\x15get_distinct_packages\x18\x07 \x01(\x08\x12\x14\n\x0cset_commands\x18\x08 \x01(\x08\x12\x1a\n\x12set_commands_async\x18\t \x01(\x08\x12\x17\n\x0fposition_limits\x18\n \x03(\x05\x12\x1b\n\x13\x65ncoder_resolutions\x18\x0b \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.qb_device_msgs.msg.info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INFO']._serialized_start=145
  _globals['_INFO']._serialized_end=431
# @@protoc_insertion_point(module_scope)
