# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_dashboard_msgs/srv/get_loaded_program.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/ur_dashboard_msgs/srv/get_loaded_program.proto\x12\x30make87_messages_ros2.jazzy.ur_dashboard_msgs.srv\"\x19\n\x17GetLoadedProgramRequest\"Q\n\x18GetLoadedProgramResponse\x12\x0e\n\x06\x61nswer\x18\x01 \x01(\t\x12\x14\n\x0cprogram_name\x18\x02 \x01(\t\x12\x0f\n\x07success\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_dashboard_msgs.srv.get_loaded_program_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETLOADEDPROGRAMREQUEST']._serialized_start=127
  _globals['_GETLOADEDPROGRAMREQUEST']._serialized_end=152
  _globals['_GETLOADEDPROGRAMRESPONSE']._serialized_start=154
  _globals['_GETLOADEDPROGRAMRESPONSE']._serialized_end=235
# @@protoc_insertion_point(module_scope)
