# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/map_msgs/srv/get_point_map.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/map_msgs/srv/get_point_map.proto\x12\'make87_messages_ros2.jazzy.map_msgs.srv\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\"\x14\n\x12GetPointMapRequest\"[\n\x13GetPointMapResponse\x12\x44\n\x03map\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.map_msgs.srv.get_point_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPOINTMAPREQUEST']._serialized_start=167
  _globals['_GETPOINTMAPREQUEST']._serialized_end=187
  _globals['_GETPOINTMAPRESPONSE']._serialized_start=189
  _globals['_GETPOINTMAPRESPONSE']._serialized_end=280
# @@protoc_insertion_point(module_scope)
