# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/delete_regions_of_interest2_d.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/rc_reason_msgs/srv/delete_regions_of_interest2_d.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\"E\n DeleteRegionsOfInterest2DRequest\x12!\n\x19region_of_interest_2d_ids\x18\x01 \x03(\t\"u\n!DeleteRegionsOfInterest2DResponse\x12P\n\x0breturn_code\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.delete_regions_of_interest2_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DELETEREGIONSOFINTEREST2DREQUEST']._serialized_start=203
  _globals['_DELETEREGIONSOFINTEREST2DREQUEST']._serialized_end=272
  _globals['_DELETEREGIONSOFINTEREST2DRESPONSE']._serialized_start=274
  _globals['_DELETEREGIONSOFINTEREST2DRESPONSE']._serialized_end=391
# @@protoc_insertion_point(module_scope)
