# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ur_msgs/srv/set_force_mode.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_wrench__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/humble/ur_msgs/srv/set_force_mode.proto\x12\'make87_messages_ros2.humble.ur_msgs.srv\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/geometry_msgs/msg/pose_stamped.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/twist.proto\x1a:make87_messages_ros2/humble/geometry_msgs/msg/wrench.proto\"\xa7\x04\n\x13SetForceModeRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12N\n\ntask_frame\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12\x1a\n\x12selection_vector_x\x18\x03 \x01(\x08\x12\x1a\n\x12selection_vector_y\x18\x04 \x01(\x08\x12\x1a\n\x12selection_vector_z\x18\x05 \x01(\x08\x12\x1b\n\x13selection_vector_rx\x18\x06 \x01(\x08\x12\x1b\n\x13selection_vector_ry\x18\x07 \x01(\x08\x12\x1b\n\x13selection_vector_rz\x18\x08 \x01(\x08\x12\x45\n\x06wrench\x18\t \x01(\x0b\x32\x35.make87_messages_ros2.humble.geometry_msgs.msg.Wrench\x12\x0c\n\x04type\x18\n \x01(\r\x12J\n\x0cspeed_limits\x18\x0b \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Twist\x12\x18\n\x10\x64\x65viation_limits\x18\x0c \x03(\x02\x12\x16\n\x0e\x64\x61mping_factor\x18\r \x01(\x02\x12\x14\n\x0cgain_scaling\x18\x0e \x01(\x02\"U\n\x14SetForceModeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ur_msgs.srv.set_force_mode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETFORCEMODEREQUEST']._serialized_start=326
  _globals['_SETFORCEMODEREQUEST']._serialized_end=877
  _globals['_SETFORCEMODERESPONSE']._serialized_start=879
  _globals['_SETFORCEMODERESPONSE']._serialized_end=964
# @@protoc_insertion_point(module_scope)
