# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/control_toolbox/srv/set_pid_gains.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/control_toolbox/srv/set_pid_gains.proto\x12\x30make87_messages_ros2.rolling.control_toolbox.srv\"Z\n\x12SetPidGainsRequest\x12\t\n\x01p\x18\x01 \x01(\x01\x12\t\n\x01i\x18\x02 \x01(\x01\x12\t\n\x01\x64\x18\x03 \x01(\x01\x12\x0f\n\x07i_clamp\x18\x04 \x01(\x01\x12\x12\n\nantiwindup\x18\x05 \x01(\x08\"\x15\n\x13SetPidGainsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.control_toolbox.srv.set_pid_gains_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETPIDGAINSREQUEST']._serialized_start=122
  _globals['_SETPIDGAINSREQUEST']._serialized_end=212
  _globals['_SETPIDGAINSRESPONSE']._serialized_start=214
  _globals['_SETPIDGAINSRESPONSE']._serialized_end=235
# @@protoc_insertion_point(module_scope)
