# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mobileye_560_660_msgs/msg/obstacle_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/rolling/mobileye_560_660_msgs/msg/obstacle_status.proto\x12\x36make87_messages_ros2.rolling.mobileye_560_660_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xd4\x02\n\x0eObstacleStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x15\n\rnum_obstacles\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x1b\n\x13\x61pplication_version\x18\x04 \x01(\r\x12%\n\x1d\x61\x63tive_version_number_section\x18\x05 \x01(\r\x12\x1f\n\x17left_close_range_cut_in\x18\x06 \x01(\x08\x12 \n\x18right_close_range_cut_in\x18\x07 \x01(\x08\x12\x0f\n\x07stop_go\x18\x08 \x01(\r\x12\x18\n\x10protocol_version\x18\t \x01(\r\x12\x11\n\tclose_car\x18\n \x01(\x08\x12\x10\n\x08\x66\x61ilsafe\x18\x0b \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mobileye_560_660_msgs.msg.obstacle_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBSTACLESTATUS']._serialized_start=193
  _globals['_OBSTACLESTATUS']._serialized_end=533
# @@protoc_insertion_point(module_scope)
