# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_proposal.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import negotiation_key_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_negotiation__key__pb2
from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import route_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_proposal.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.msg\x1a\x45make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_key.proto\x1a;make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/route.proto\"\x97\x02\n\x13NegotiationProposal\x12\x18\n\x10\x63onflict_version\x18\x01 \x01(\x04\x12\x18\n\x10proposal_version\x18\x02 \x01(\x04\x12\x17\n\x0f\x66or_participant\x18\x03 \x01(\x04\x12W\n\x0eto_accommodate\x18\x04 \x03(\x0b\x32?.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.NegotiationKey\x12\x0f\n\x07plan_id\x18\x05 \x01(\x04\x12I\n\titinerary\x18\x06 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.Routeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.negotiation_proposal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NEGOTIATIONPROPOSAL']._serialized_start=260
  _globals['_NEGOTIATIONPROPOSAL']._serialized_end=539
# @@protoc_insertion_point(module_scope)
