# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gps_msgs/msg/gps_fix.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.gps_msgs.msg import gps_status_pb2 as make87__messages__ros2_dot_jazzy_dot_gps__msgs_dot_msg_dot_gps__status__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5make87_messages_ros2/jazzy/gps_msgs/msg/gps_fix.proto\x12\'make87_messages_ros2.jazzy.gps_msgs.msg\x1a\x38make87_messages_ros2/jazzy/gps_msgs/msg/gps_status.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xe0\x04\n\x06GPSFix\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x42\n\x06status\x18\x02 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.gps_msgs.msg.GPSStatus\x12\x10\n\x08latitude\x18\x03 \x01(\x01\x12\x11\n\tlongitude\x18\x04 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x05 \x01(\x01\x12\r\n\x05track\x18\x06 \x01(\x01\x12\r\n\x05speed\x18\x07 \x01(\x01\x12\r\n\x05\x63limb\x18\x08 \x01(\x01\x12\r\n\x05pitch\x18\t \x01(\x01\x12\x0c\n\x04roll\x18\n \x01(\x01\x12\x0b\n\x03\x64ip\x18\x0b \x01(\x01\x12\x0c\n\x04time\x18\x0c \x01(\x01\x12\x0c\n\x04gdop\x18\r \x01(\x01\x12\x0c\n\x04pdop\x18\x0e \x01(\x01\x12\x0c\n\x04hdop\x18\x0f \x01(\x01\x12\x0c\n\x04vdop\x18\x10 \x01(\x01\x12\x0c\n\x04tdop\x18\x11 \x01(\x01\x12\x0b\n\x03\x65rr\x18\x12 \x01(\x01\x12\x10\n\x08\x65rr_horz\x18\x13 \x01(\x01\x12\x10\n\x08\x65rr_vert\x18\x14 \x01(\x01\x12\x11\n\terr_track\x18\x15 \x01(\x01\x12\x11\n\terr_speed\x18\x16 \x01(\x01\x12\x11\n\terr_climb\x18\x17 \x01(\x01\x12\x10\n\x08\x65rr_time\x18\x18 \x01(\x01\x12\x11\n\terr_pitch\x18\x19 \x01(\x01\x12\x10\n\x08\x65rr_roll\x18\x1a \x01(\x01\x12\x0f\n\x07\x65rr_dip\x18\x1b \x01(\x01\x12\x1b\n\x13position_covariance\x18\x1c \x03(\x01\x12 \n\x18position_covariance_type\x18\x1d \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gps_msgs.msg.gps_fix_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GPSFIX']._serialized_start=211
  _globals['_GPSFIX']._serialized_end=819
# @@protoc_insertion_point(module_scope)
