# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/septentrio_gnss_driver/msg/att_cov_euler.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import block_header_pb2 as make87__messages__ros2_dot_jazzy_dot_septentrio__gnss__driver_dot_msg_dot_block__header__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/septentrio_gnss_driver/msg/att_cov_euler.proto\x12\x35make87_messages_ros2.jazzy.septentrio_gnss_driver.msg\x1aHmake87_messages_ros2/jazzy/septentrio_gnss_driver/msg/block_header.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xbf\x02\n\x0b\x41ttCovEuler\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12X\n\x0c\x62lock_header\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.septentrio_gnss_driver.msg.BlockHeader\x12\r\n\x05\x65rror\x18\x03 \x01(\r\x12\x14\n\x0c\x63ov_headhead\x18\x04 \x01(\x02\x12\x16\n\x0e\x63ov_pitchpitch\x18\x05 \x01(\x02\x12\x14\n\x0c\x63ov_rollroll\x18\x06 \x01(\x02\x12\x15\n\rcov_headpitch\x18\x07 \x01(\x02\x12\x14\n\x0c\x63ov_headroll\x18\x08 \x01(\x02\x12\x15\n\rcov_pitchroll\x18\t \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.septentrio_gnss_driver.msg.att_cov_euler_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ATTCOVEULER']._serialized_start=261
  _globals['_ATTCOVEULER']._serialized_end=580
# @@protoc_insertion_point(module_scope)
