# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/diagnostic_msgs/srv/self_test.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.diagnostic_msgs.msg import diagnostic_status_pb2 as make87__messages__ros2_dot_jazzy_dot_diagnostic__msgs_dot_msg_dot_diagnostic__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/diagnostic_msgs/srv/self_test.proto\x12.make87_messages_ros2.jazzy.diagnostic_msgs.srv\x1a\x46make87_messages_ros2/jazzy/diagnostic_msgs/msg/diagnostic_status.proto\"\x11\n\x0fSelfTestRequest\"\x80\x01\n\x10SelfTestResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06passed\x18\x02 \x01(\r\x12P\n\x06status\x18\x03 \x03(\x0b\x32@.make87_messages_ros2.jazzy.diagnostic_msgs.msg.DiagnosticStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.diagnostic_msgs.srv.self_test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SELFTESTREQUEST']._serialized_start=186
  _globals['_SELFTESTREQUEST']._serialized_end=203
  _globals['_SELFTESTRESPONSE']._serialized_start=206
  _globals['_SELFTESTRESPONSE']._serialized_end=334
# @@protoc_insertion_point(module_scope)
