# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosbridge_test_msgs/srv/test_multiple_response_fields.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/rolling/rosbridge_test_msgs/srv/test_multiple_response_fields.proto\x12\x34make87_messages_ros2.rolling.rosbridge_test_msgs.srv\"#\n!TestMultipleResponseFieldsRequest\"p\n\"TestMultipleResponseFieldsResponse\x12\x11\n\tint_value\x18\x01 \x01(\x05\x12\x13\n\x0b\x66loat_value\x18\x02 \x01(\x02\x12\x0e\n\x06string\x18\x03 \x01(\t\x12\x12\n\nbool_value\x18\x04 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosbridge_test_msgs.srv.test_multiple_response_fields_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TESTMULTIPLERESPONSEFIELDSREQUEST']._serialized_start=146
  _globals['_TESTMULTIPLERESPONSEFIELDSREQUEST']._serialized_end=181
  _globals['_TESTMULTIPLERESPONSEFIELDSRESPONSE']._serialized_start=183
  _globals['_TESTMULTIPLERESPONSEFIELDSRESPONSE']._serialized_end=295
# @@protoc_insertion_point(module_scope)
