# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/msg/info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import map_graph_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_map__graph__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/humble/rtabmap_msgs/msg/info.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/geometry_msgs/msg/transform.proto\x1a<make87_messages_ros2/humble/rtabmap_msgs/msg/map_graph.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xe4\x05\n\x04Info\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0e\n\x06ref_id\x18\x03 \x01(\x05\x12\x17\n\x0floop_closure_id\x18\x04 \x01(\x05\x12\x1e\n\x16proximity_detection_id\x18\x05 \x01(\x05\x12\x13\n\x0blandmark_id\x18\x06 \x01(\x05\x12X\n\x16loop_closure_transform\x18\x07 \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12\x10\n\x08wm_state\x18\x08 \x03(\x05\x12\x16\n\x0eposterior_keys\x18\t \x03(\x05\x12\x18\n\x10posterior_values\x18\n \x03(\x02\x12\x17\n\x0flikelihood_keys\x18\x0b \x03(\x05\x12\x19\n\x11likelihood_values\x18\x0c \x03(\x02\x12\x1b\n\x13raw_likelihood_keys\x18\r \x03(\x05\x12\x1d\n\x15raw_likelihood_values\x18\x0e \x03(\x02\x12\x14\n\x0cweights_keys\x18\x0f \x03(\x05\x12\x16\n\x0eweights_values\x18\x10 \x03(\x05\x12\x13\n\x0blabels_keys\x18\x11 \x03(\x05\x12\x15\n\rlabels_values\x18\x12 \x03(\t\x12\x12\n\nstats_keys\x18\x13 \x03(\t\x12\x14\n\x0cstats_values\x18\x14 \x03(\x02\x12\x12\n\nlocal_path\x18\x15 \x03(\x05\x12\x17\n\x0f\x63urrent_goal_id\x18\x16 \x01(\x05\x12J\n\nodom_cache\x18\x17 \x01(\x0b\x32\x36.make87_messages_ros2.humble.rtabmap_msgs.msg.MapGraphb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.msg.info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INFO']._serialized_start=321
  _globals['_INFO']._serialized_end=1061
# @@protoc_insertion_point(module_scope)
