# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_door_msgs/msg/supervisor_heartbeat.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_door_msgs.msg import door_sessions_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__door__msgs_dot_msg_dot_door__sessions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/rmf_door_msgs/msg/supervisor_heartbeat.proto\x12,make87_messages_ros2.jazzy.rmf_door_msgs.msg\x1a@make87_messages_ros2/jazzy/rmf_door_msgs/msg/door_sessions.proto\"g\n\x13SupervisorHeartbeat\x12P\n\x0c\x61ll_sessions\x18\x01 \x03(\x0b\x32:.make87_messages_ros2.jazzy.rmf_door_msgs.msg.DoorSessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_door_msgs.msg.supervisor_heartbeat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SUPERVISORHEARTBEAT']._serialized_start=187
  _globals['_SUPERVISORHEARTBEAT']._serialized_end=290
# @@protoc_insertion_point(module_scope)
