# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/off_highway_premium_radar_sample_msgs/msg/sensor_modulation_performance.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nimake87_messages_ros2/humble/off_highway_premium_radar_sample_msgs/msg/sensor_modulation_performance.proto\x12\x45make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg\x1a!make87_messages/core/header.proto\"\x90\x04\n\x1bSensorModulationPerformance\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12(\n detection_of_measurement_program\x18\x02 \x01(\r\x12\x15\n\rmodulation_id\x18\x03 \x01(\r\x12\x1e\n\x16\x64istance_range_scaling\x18\x04 \x01(\x02\x12\x1d\n\x15separability_distance\x18\x05 \x01(\x02\x12&\n\x1eseparability_relative_velocity\x18\x06 \x01(\x02\x12\x1a\n\x12precision_distance\x18\x07 \x01(\x02\x12#\n\x1bprecision_relative_velocity\x18\x08 \x01(\x02\x12\x34\n,covariance_of_distance_and_relative_velocity\x18\t \x01(\x02\x12#\n\x1bminimum_measurable_distance\x18\n \x01(\x02\x12#\n\x1bmaximum_measurable_distance\x18\x0b \x01(\x02\x12,\n$minimum_measurable_relative_velocity\x18\x0c \x01(\x02\x12,\n$maximum_measurable_relative_velocity\x18\r \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg.sensor_modulation_performance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENSORMODULATIONPERFORMANCE']._serialized_start=216
  _globals['_SENSORMODULATIONPERFORMANCE']._serialized_end=744
# @@protoc_insertion_point(module_scope)
