# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/canopen_interfaces/srv/co_write.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/canopen_interfaces/srv/co_write.proto\x12\x32make87_messages_ros2.humble.canopen_interfaces.srv\x1a!make87_messages/core/header.proto\"m\n\x0e\x43OWriteRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05index\x18\x02 \x01(\r\x12\x10\n\x08subindex\x18\x03 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\r\"P\n\x0f\x43OWriteResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.canopen_interfaces.srv.co_write_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COWRITEREQUEST']._serialized_start=156
  _globals['_COWRITEREQUEST']._serialized_end=265
  _globals['_COWRITERESPONSE']._serialized_start=267
  _globals['_COWRITERESPONSE']._serialized_end=347
# @@protoc_insertion_point(module_scope)
