# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/extended_laser_scan.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sensor_msgs.msg import laser_scan_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_laser__scan__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/extended_laser_scan.proto\x12>make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg\x1a;make87_messages_ros2/jazzy/sensor_msgs/msg/laser_scan.proto\"\xa5\x01\n\x11\x45xtendedLaserScan\x12I\n\nlaser_scan\x18\x01 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.sensor_msgs.msg.LaserScan\x12\x18\n\x10reflektor_status\x18\x02 \x03(\x08\x12\x18\n\x10reflektor_median\x18\x03 \x03(\x08\x12\x11\n\tintrusion\x18\x04 \x03(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.extended_laser_scan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EXTENDEDLASERSCAN']._serialized_start=218
  _globals['_EXTENDEDLASERSCAN']._serialized_end=383
# @@protoc_insertion_point(module_scope)
