# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/intrusion_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import intrusion_datum_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_intrusion__datum__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/intrusion_data.proto\x12>make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg\x1aTmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/intrusion_datum.proto\"m\n\rIntrusionData\x12\\\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32N.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.IntrusionDatumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.intrusion_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTRUSIONDATA']._serialized_start=237
  _globals['_INTRUSIONDATA']._serialized_end=346
# @@protoc_insertion_point(module_scope)
