# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ros_ign_interfaces/msg/world_control.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.humble.ros_gz_interfaces.msg import world_reset_pb2 as make87__messages__ros2_dot_humble_dot_ros__gz__interfaces_dot_msg_dot_world__reset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/ros_ign_interfaces/msg/world_control.proto\x12\x32make87_messages_ros2.humble.ros_ign_interfaces.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\x1a\x43make87_messages_ros2/humble/ros_gz_interfaces/msg/world_reset.proto\"\x9c\x02\n\x0cWorldControl\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05pause\x18\x02 \x01(\x08\x12\x0c\n\x04step\x18\x03 \x01(\x08\x12\x12\n\nmulti_step\x18\x04 \x01(\r\x12L\n\x05reset\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.humble.ros_gz_interfaces.msg.WorldReset\x12\x0c\n\x04seed\x18\x06 \x01(\r\x12Q\n\x0frun_to_sim_time\x18\x07 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ros_ign_interfaces.msg.world_control_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_WORLDCONTROL']._serialized_start=294
  _globals['_WORLDCONTROL']._serialized_end=578
# @@protoc_insertion_point(module_scope)
