# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/vehicle_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/mavros_msgs/msg/vehicle_info.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xd5\x03\n\x0bVehicleInfo\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x16\n\x0e\x61vailable_info\x18\x02 \x01(\r\x12\r\n\x05sysid\x18\x03 \x01(\r\x12\x0e\n\x06\x63ompid\x18\x04 \x01(\r\x12\x11\n\tautopilot\x18\x05 \x01(\r\x12\x0c\n\x04type\x18\x06 \x01(\r\x12\x15\n\rsystem_status\x18\x07 \x01(\r\x12\x11\n\tbase_mode\x18\x08 \x01(\r\x12\x13\n\x0b\x63ustom_mode\x18\t \x01(\r\x12\x0c\n\x04mode\x18\n \x01(\t\x12\x0f\n\x07mode_id\x18\x0b \x01(\r\x12\x14\n\x0c\x63\x61pabilities\x18\x0c \x01(\x04\x12\x19\n\x11\x66light_sw_version\x18\r \x01(\r\x12\x1d\n\x15middleware_sw_version\x18\x0e \x01(\r\x12\x15\n\ros_sw_version\x18\x0f \x01(\r\x12\x15\n\rboard_version\x18\x10 \x01(\r\x12\x1d\n\x15\x66light_custom_version\x18\x11 \x01(\t\x12\x11\n\tvendor_id\x18\x12 \x01(\r\x12\x12\n\nproduct_id\x18\x13 \x01(\r\x12\x0b\n\x03uid\x18\x14 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.vehicle_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VEHICLEINFO']._serialized_start=164
  _globals['_VEHICLEINFO']._serialized_end=633
# @@protoc_insertion_point(module_scope)
