# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/map_msgs/msg/projected_map.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.nav_msgs.msg import occupancy_grid_pb2 as make87__messages__ros2_dot_rolling_dot_nav__msgs_dot_msg_dot_occupancy__grid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/map_msgs/msg/projected_map.proto\x12)make87_messages_ros2.rolling.map_msgs.msg\x1a>make87_messages_ros2/rolling/nav_msgs/msg/occupancy_grid.proto\"s\n\x0cProjectedMap\x12\x45\n\x03map\x18\x01 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.nav_msgs.msg.OccupancyGrid\x12\r\n\x05min_z\x18\x02 \x01(\x01\x12\r\n\x05max_z\x18\x03 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.map_msgs.msg.projected_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PROJECTEDMAP']._serialized_start=172
  _globals['_PROJECTEDMAP']._serialized_end=287
# @@protoc_insertion_point(module_scope)
