# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/route.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import traffic_dependency_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_traffic__dependency__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import trajectory_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/rmf_traffic_msgs/msg/route.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1aJmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/traffic_dependency.proto\x1a\x42make87_messages_ros2/rolling/rmf_traffic_msgs/msg/trajectory.proto\"\xd8\x01\n\x05Route\x12\x0b\n\x03map\x18\x01 \x01(\t\x12Q\n\ntrajectory\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.Trajectory\x12\x13\n\x0b\x63heckpoints\x18\x03 \x03(\x04\x12Z\n\x0c\x64\x65pendencies\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.TrafficDependencyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROUTE']._serialized_start=261
  _globals['_ROUTE']._serialized_end=477
# @@protoc_insertion_point(module_scope)
