# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marine_acoustic_msgs/msg/dvl.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/marine_acoustic_msgs/msg/dvl.proto\x12\x35make87_messages_ros2.rolling.marine_acoustic_msgs.msg\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/vector3.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xb2\x04\n\x03\x44vl\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x15\n\rvelocity_mode\x18\x02 \x01(\r\x12\x10\n\x08\x64vl_type\x18\x03 \x01(\r\x12I\n\x08velocity\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\x16\n\x0evelocity_covar\x18\x05 \x03(\x01\x12\x10\n\x08\x61ltitude\x18\x06 \x01(\x01\x12\x12\n\ncourse_gnd\x18\x07 \x01(\x01\x12\x11\n\tspeed_gnd\x18\x08 \x01(\x01\x12\x16\n\x0enum_good_beams\x18\t \x01(\r\x12\x13\n\x0bsound_speed\x18\n \x01(\x02\x12\x19\n\x11\x62\x65\x61m_ranges_valid\x18\x0b \x01(\x08\x12\x1d\n\x15\x62\x65\x61m_velocities_valid\x18\x0c \x01(\x08\x12N\n\rbeam_unit_vec\x18\r \x03(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\r\n\x05range\x18\x0e \x03(\x01\x12\x13\n\x0brange_covar\x18\x0f \x03(\x02\x12\x14\n\x0c\x62\x65\x61m_quality\x18\x10 \x03(\x02\x12\x15\n\rbeam_velocity\x18\x11 \x03(\x02\x12\x1b\n\x13\x62\x65\x61m_velocity_covar\x18\x12 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marine_acoustic_msgs.msg.dvl_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DVL']._serialized_start=241
  _globals['_DVL']._serialized_end=803
# @@protoc_insertion_point(module_scope)
