# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_gz_interfaces/srv/set_entity_pose.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.ros_gz_interfaces.msg import entity_pb2 as make87__messages__ros2_dot_rolling_dot_ros__gz__interfaces_dot_msg_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/ros_gz_interfaces/srv/set_entity_pose.proto\x12\x32make87_messages_ros2.rolling.ros_gz_interfaces.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a?make87_messages_ros2/rolling/ros_gz_interfaces/msg/entity.proto\"\xa6\x01\n\x14SetEntityPoseRequest\x12J\n\x06\x65ntity\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.rolling.ros_gz_interfaces.msg.Entity\x12\x42\n\x04pose\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\"(\n\x15SetEntityPoseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_gz_interfaces.srv.set_entity_pose_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETENTITYPOSEREQUEST']._serialized_start=253
  _globals['_SETENTITYPOSEREQUEST']._serialized_end=419
  _globals['_SETENTITYPOSERESPONSE']._serialized_start=421
  _globals['_SETENTITYPOSERESPONSE']._serialized_end=461
# @@protoc_insertion_point(module_scope)
