# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/msg/task_summary.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.rmf_task_msgs.msg import task_profile_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__task__msgs_dot_msg_dot_task__profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/rmf_task_msgs/msg/task_summary.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a?make87_messages_ros2/jazzy/rmf_task_msgs/msg/task_profile.proto\"\xa0\x03\n\x0bTaskSummary\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\t\x12O\n\x0ctask_profile\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.rmf_task_msgs.msg.TaskProfile\x12\r\n\x05state\x18\x04 \x01(\r\x12\x0e\n\x06status\x18\x05 \x01(\t\x12P\n\x0fsubmission_time\x18\x06 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12K\n\nstart_time\x18\x07 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12I\n\x08\x65nd_time\x18\x08 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x12\n\nrobot_name\x18\t \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.msg.task_summary_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TASKSUMMARY']._serialized_start=241
  _globals['_TASKSUMMARY']._serialized_end=657
# @@protoc_insertion_point(module_scope)
