# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcl_interfaces/srv/set_parameters.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rcl_interfaces.msg import parameter_pb2 as make87__messages__ros2_dot_humble_dot_rcl__interfaces_dot_msg_dot_parameter__pb2
from make87_messages_ros2.humble.rcl_interfaces.msg import set_parameters_result_pb2 as make87__messages__ros2_dot_humble_dot_rcl__interfaces_dot_msg_dot_set__parameters__result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/humble/rcl_interfaces/srv/set_parameters.proto\x12.make87_messages_ros2.humble.rcl_interfaces.srv\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/rcl_interfaces/msg/parameter.proto\x1aJmake87_messages_ros2/humble/rcl_interfaces/msg/set_parameters_result.proto\"\x93\x01\n\x14SetParametersRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12M\n\nparameters\x18\x02 \x03(\x0b\x32\x39.make87_messages_ros2.humble.rcl_interfaces.msg.Parameter\"\x9b\x01\n\x15SetParametersResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12T\n\x07results\x18\x02 \x03(\x0b\x32\x43.make87_messages_ros2.humble.rcl_interfaces.msg.SetParametersResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcl_interfaces.srv.set_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETPARAMETERSREQUEST']._serialized_start=295
  _globals['_SETPARAMETERSREQUEST']._serialized_end=442
  _globals['_SETPARAMETERSRESPONSE']._serialized_start=445
  _globals['_SETPARAMETERSRESPONSE']._serialized_end=600
# @@protoc_insertion_point(module_scope)
