# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/webots_ros2_msgs/msg/camera_recognition_objects.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.webots_ros2_msgs.msg import camera_recognition_object_pb2 as make87__messages__ros2_dot_rolling_dot_webots__ros2__msgs_dot_msg_dot_camera__recognition__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/webots_ros2_msgs/msg/camera_recognition_objects.proto\x12\x31make87_messages_ros2.rolling.webots_ros2_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1aQmake87_messages_ros2/rolling/webots_ros2_msgs/msg/camera_recognition_object.proto\"\xba\x01\n\x18\x43\x61meraRecognitionObjects\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12[\n\x07objects\x18\x02 \x03(\x0b\x32J.make87_messages_ros2.rolling.webots_ros2_msgs.msg.CameraRecognitionObjectb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.webots_ros2_msgs.msg.camera_recognition_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CAMERARECOGNITIONOBJECTS']._serialized_start=277
  _globals['_CAMERARECOGNITIONOBJECTS']._serialized_end=463
# @@protoc_insertion_point(module_scope)
