# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/get_link_properties.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/gazebo_msgs/srv/get_link_properties.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"-\n\x18GetLinkPropertiesRequest\x12\x11\n\tlink_name\x18\x01 \x01(\t\"\xf7\x01\n\x19GetLinkPropertiesResponse\x12?\n\x03\x63om\x18\x01 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x14\n\x0cgravity_mode\x18\x02 \x01(\x08\x12\x0c\n\x04mass\x18\x03 \x01(\x01\x12\x0b\n\x03ixx\x18\x04 \x01(\x01\x12\x0b\n\x03ixy\x18\x05 \x01(\x01\x12\x0b\n\x03ixz\x18\x06 \x01(\x01\x12\x0b\n\x03iyy\x18\x07 \x01(\x01\x12\x0b\n\x03iyz\x18\x08 \x01(\x01\x12\x0b\n\x03izz\x18\t \x01(\x01\x12\x0f\n\x07success\x18\n \x01(\x08\x12\x16\n\x0estatus_message\x18\x0b \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.get_link_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETLINKPROPERTIESREQUEST']._serialized_start=173
  _globals['_GETLINKPROPERTIESREQUEST']._serialized_end=218
  _globals['_GETLINKPROPERTIESRESPONSE']._serialized_start=221
  _globals['_GETLINKPROPERTIESRESPONSE']._serialized_end=468
# @@protoc_insertion_point(module_scope)
