# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/vimbax_camera_msgs/srv/feature_bool_get.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import error_pb2 as make87__messages__ros2_dot_humble_dot_vimbax__camera__msgs_dot_msg_dot_error__pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import feature_module_pb2 as make87__messages__ros2_dot_humble_dot_vimbax__camera__msgs_dot_msg_dot_feature__module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/vimbax_camera_msgs/srv/feature_bool_get.proto\x12\x32make87_messages_ros2.humble.vimbax_camera_msgs.srv\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/vimbax_camera_msgs/msg/error.proto\x1aGmake87_messages_ros2/humble/vimbax_camera_msgs/msg/feature_module.proto\"\xb6\x01\n\x15\x46\x65\x61tureBoolGetRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12Y\n\x0e\x66\x65\x61ture_module\x18\x03 \x01(\x0b\x32\x41.make87_messages_ros2.humble.vimbax_camera_msgs.msg.FeatureModule\"\x9f\x01\n\x16\x46\x65\x61tureBoolGetResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05value\x18\x02 \x01(\x08\x12H\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.humble.vimbax_camera_msgs.msg.Errorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.vimbax_camera_msgs.srv.feature_bool_get_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FEATUREBOOLGETREQUEST']._serialized_start=302
  _globals['_FEATUREBOOLGETREQUEST']._serialized_end=484
  _globals['_FEATUREBOOLGETRESPONSE']._serialized_start=487
  _globals['_FEATUREBOOLGETRESPONSE']._serialized_end=646
# @@protoc_insertion_point(module_scope)
