# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/type_description_interfaces/msg/individual_type_description.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.type_description_interfaces.msg import field_pb2 as make87__messages__ros2_dot_jazzy_dot_type__description__interfaces_dot_msg_dot_field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\\make87_messages_ros2/jazzy/type_description_interfaces/msg/individual_type_description.proto\x12:make87_messages_ros2.jazzy.type_description_interfaces.msg\x1a\x46make87_messages_ros2/jazzy/type_description_interfaces/msg/field.proto\"\x81\x01\n\x19IndividualTypeDescription\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12Q\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x41.make87_messages_ros2.jazzy.type_description_interfaces.msg.Fieldb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.type_description_interfaces.msg.individual_type_description_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INDIVIDUALTYPEDESCRIPTION']._serialized_start=229
  _globals['_INDIVIDUALTYPEDESCRIPTION']._serialized_end=358
# @@protoc_insertion_point(module_scope)
