# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/router_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/router_status.proto\x12\x35make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg\"\xd6\x01\n\x0cRouterStatus\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0emissing_robots\x18\x03 \x03(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\x12\x1b\n\x13overall_path_length\x18\x05 \x01(\x05\x12\x1b\n\x13longest_path_length\x18\x06 \x01(\x05\x12#\n\x1bpriority_scheduling_attemps\x18\x07 \x01(\x05\x12 \n\x18speed_scheduling_attemps\x18\x08 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg.router_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROUTERSTATUS']._serialized_start=133
  _globals['_ROUTERSTATUS']._serialized_end=347
# @@protoc_insertion_point(module_scope)
