# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcl_interfaces/msg/parameter_descriptor.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rcl_interfaces.msg import floating_point_range_pb2 as make87__messages__ros2_dot_rolling_dot_rcl__interfaces_dot_msg_dot_floating__point__range__pb2
from make87_messages_ros2.rolling.rcl_interfaces.msg import integer_range_pb2 as make87__messages__ros2_dot_rolling_dot_rcl__interfaces_dot_msg_dot_integer__range__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rcl_interfaces/msg/parameter_descriptor.proto\x12/make87_messages_ros2.rolling.rcl_interfaces.msg\x1aJmake87_messages_ros2/rolling/rcl_interfaces/msg/floating_point_range.proto\x1a\x43make87_messages_ros2/rolling/rcl_interfaces/msg/integer_range.proto\"\xca\x02\n\x13ParameterDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1e\n\x16\x61\x64\x64itional_constraints\x18\x04 \x01(\t\x12\x11\n\tread_only\x18\x05 \x01(\x08\x12\x16\n\x0e\x64ynamic_typing\x18\x06 \x01(\x08\x12\x61\n\x14\x66loating_point_range\x18\x07 \x03(\x0b\x32\x43.make87_messages_ros2.rolling.rcl_interfaces.msg.FloatingPointRange\x12T\n\rinteger_range\x18\x08 \x03(\x0b\x32=.make87_messages_ros2.rolling.rcl_interfaces.msg.IntegerRangeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcl_interfaces.msg.parameter_descriptor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PARAMETERDESCRIPTOR']._serialized_start=273
  _globals['_PARAMETERDESCRIPTOR']._serialized_end=603
# @@protoc_insertion_point(module_scope)
