# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ur_msgs/msg/io_states.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ur_msgs.msg import analog_pb2 as make87__messages__ros2_dot_humble_dot_ur__msgs_dot_msg_dot_analog__pb2
from make87_messages_ros2.humble.ur_msgs.msg import digital_pb2 as make87__messages__ros2_dot_humble_dot_ur__msgs_dot_msg_dot_digital__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/humble/ur_msgs/msg/io_states.proto\x12\'make87_messages_ros2.humble.ur_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x34make87_messages_ros2/humble/ur_msgs/msg/analog.proto\x1a\x35make87_messages_ros2/humble/ur_msgs/msg/digital.proto\"\xb1\x03\n\x08IOStates\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12K\n\x11\x64igital_in_states\x18\x02 \x03(\x0b\x32\x30.make87_messages_ros2.humble.ur_msgs.msg.Digital\x12L\n\x12\x64igital_out_states\x18\x03 \x03(\x0b\x32\x30.make87_messages_ros2.humble.ur_msgs.msg.Digital\x12\x45\n\x0b\x66lag_states\x18\x04 \x03(\x0b\x32\x30.make87_messages_ros2.humble.ur_msgs.msg.Digital\x12I\n\x10\x61nalog_in_states\x18\x05 \x03(\x0b\x32/.make87_messages_ros2.humble.ur_msgs.msg.Analog\x12J\n\x11\x61nalog_out_states\x18\x06 \x03(\x0b\x32/.make87_messages_ros2.humble.ur_msgs.msg.Analogb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ur_msgs.msg.io_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_IOSTATES']._serialized_start=245
  _globals['_IOSTATES']._serialized_end=678
# @@protoc_insertion_point(module_scope)
