# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_tmode3.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_tmode3.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"\xbc\x02\n\tCfgTMODE3\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x11\n\treserved1\x18\x02 \x01(\r\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x15\n\recef_x_or_lat\x18\x04 \x01(\x05\x12\x15\n\recef_y_or_lon\x18\x05 \x01(\x05\x12\x15\n\recef_z_or_alt\x18\x06 \x01(\x05\x12\x18\n\x10\x65\x63\x65\x66_x_or_lat_hp\x18\x07 \x01(\x05\x12\x18\n\x10\x65\x63\x65\x66_y_or_lon_hp\x18\x08 \x01(\x05\x12\x18\n\x10\x65\x63\x65\x66_z_or_alt_hp\x18\t \x01(\x05\x12\x11\n\treserved2\x18\n \x01(\r\x12\x15\n\rfixed_pos_acc\x18\x0b \x01(\r\x12\x14\n\x0csvin_min_dur\x18\x0c \x01(\r\x12\x16\n\x0esvin_acc_limit\x18\r \x01(\r\x12\x11\n\treserved3\x18\x0e \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.cfg_tmode3_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CFGTMODE3']._serialized_start=106
  _globals['_CFGTMODE3']._serialized_end=422
# @@protoc_insertion_point(module_scope)
