# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/dynamixel_sdk_custom_interfaces/srv/get_position.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/jazzy/dynamixel_sdk_custom_interfaces/srv/get_position.proto\x12>make87_messages_ros2.jazzy.dynamixel_sdk_custom_interfaces.srv\" \n\x12GetPositionRequest\x12\n\n\x02id\x18\x01 \x01(\r\"\'\n\x13GetPositionResponse\x12\x10\n\x08position\x18\x01 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.dynamixel_sdk_custom_interfaces.srv.get_position_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPOSITIONREQUEST']._serialized_start=149
  _globals['_GETPOSITIONREQUEST']._serialized_end=181
  _globals['_GETPOSITIONRESPONSE']._serialized_start=183
  _globals['_GETPOSITIONRESPONSE']._serialized_end=222
# @@protoc_insertion_point(module_scope)
