# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/msg/allowed_collision_matrix.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import allowed_collision_entry_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_allowed__collision__entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/humble/moveit_msgs/msg/allowed_collision_matrix.proto\x12+make87_messages_ros2.humble.moveit_msgs.msg\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/moveit_msgs/msg/allowed_collision_entry.proto\"\xf0\x01\n\x16\x41llowedCollisionMatrix\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0b\x65ntry_names\x18\x02 \x03(\t\x12X\n\x0c\x65ntry_values\x18\x03 \x03(\x0b\x32\x42.make87_messages_ros2.humble.moveit_msgs.msg.AllowedCollisionEntry\x12\x1b\n\x13\x64\x65\x66\x61ult_entry_names\x18\x04 \x03(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_entry_values\x18\x05 \x03(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.msg.allowed_collision_matrix_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ALLOWEDCOLLISIONMATRIX']._serialized_start=234
  _globals['_ALLOWEDCOLLISIONMATRIX']._serialized_end=474
# @@protoc_insertion_point(module_scope)
