# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/example_interfaces/srv/add_two_ints.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/example_interfaces/srv/add_two_ints.proto\x12\x33make87_messages_ros2.rolling.example_interfaces.srv\")\n\x11\x41\x64\x64TwoIntsRequest\x12\t\n\x01\x61\x18\x01 \x01(\x03\x12\t\n\x01\x62\x18\x02 \x01(\x03\"!\n\x12\x41\x64\x64TwoIntsResponse\x12\x0b\n\x03sum\x18\x01 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.example_interfaces.srv.add_two_ints_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ADDTWOINTSREQUEST']._serialized_start=127
  _globals['_ADDTWOINTSREQUEST']._serialized_end=168
  _globals['_ADDTWOINTSRESPONSE']._serialized_start=170
  _globals['_ADDTWOINTSRESPONSE']._serialized_end=203
# @@protoc_insertion_point(module_scope)
