from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ESCInfoItem(_message.Message):
    __slots__ = ("header", "failure_flags", "error_count", "temperature")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FLAGS_FIELD_NUMBER: _ClassVar[int]
    ERROR_COUNT_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    failure_flags: int
    error_count: int
    temperature: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., failure_flags: _Optional[int] = ..., error_count: _Optional[int] = ..., temperature: _Optional[int] = ...) -> None: ...
