# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/command_trigger_interval.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/mavros_msgs/srv/command_trigger_interval.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"M\n\x1d\x43ommandTriggerIntervalRequest\x12\x12\n\ncycle_time\x18\x01 \x01(\x02\x12\x18\n\x10integration_time\x18\x02 \x01(\x02\"A\n\x1e\x43ommandTriggerIntervalResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.command_trigger_interval_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COMMANDTRIGGERINTERVALREQUEST']._serialized_start=125
  _globals['_COMMANDTRIGGERINTERVALREQUEST']._serialized_end=202
  _globals['_COMMANDTRIGGERINTERVALRESPONSE']._serialized_start=204
  _globals['_COMMANDTRIGGERINTERVALRESPONSE']._serialized_end=269
# @@protoc_insertion_point(module_scope)
