# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/srv/global_bundle_adjustment.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/humble/rtabmap_msgs/srv/global_bundle_adjustment.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.srv\x1a!make87_messages/core/header.proto\"\x9c\x01\n\x1dGlobalBundleAdjustmentRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x12\n\niterations\x18\x03 \x01(\x05\x12\x16\n\x0epixel_variance\x18\x04 \x01(\x02\x12\x13\n\x0bvoc_matches\x18\x05 \x01(\x08\"N\n\x1eGlobalBundleAdjustmentResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.srv.global_bundle_adjustment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GLOBALBUNDLEADJUSTMENTREQUEST']._serialized_start=161
  _globals['_GLOBALBUNDLEADJUSTMENTREQUEST']._serialized_end=317
  _globals['_GLOBALBUNDLEADJUSTMENTRESPONSE']._serialized_start=319
  _globals['_GLOBALBUNDLEADJUSTMENTRESPONSE']._serialized_end=397
# @@protoc_insertion_point(module_scope)
