# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/micro_ros_msgs/msg/graph.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.micro_ros_msgs.msg import node_pb2 as make87__messages__ros2_dot_rolling_dot_micro__ros__msgs_dot_msg_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/micro_ros_msgs/msg/graph.proto\x12/make87_messages_ros2.rolling.micro_ros_msgs.msg\x1a:make87_messages_ros2/rolling/micro_ros_msgs/msg/node.proto\"M\n\x05Graph\x12\x44\n\x05nodes\x18\x01 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.micro_ros_msgs.msg.Nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.micro_ros_msgs.msg.graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRAPH']._serialized_start=172
  _globals['_GRAPH']._serialized_end=249
# @@protoc_insertion_point(module_scope)
