# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/turtlebot4_msgs/msg/user_display.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/turtlebot4_msgs/msg/user_display.proto\x12.make87_messages_ros2.jazzy.turtlebot4_msgs.msg\"S\n\x0bUserDisplay\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0f\n\x07\x62\x61ttery\x18\x02 \x01(\t\x12\x0f\n\x07\x65ntries\x18\x03 \x03(\t\x12\x16\n\x0eselected_entry\x18\x04 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.turtlebot4_msgs.msg.user_display_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_USERDISPLAY']._serialized_start=117
  _globals['_USERDISPLAY']._serialized_end=200
# @@protoc_insertion_point(module_scope)
