# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_device_block_pb2 as make87__messages__ros2_dot_humble_dot_sick__scan__xd_dot_msg_dot_radar__pre__header__device__block__pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_encoder_block_pb2 as make87__messages__ros2_dot_humble_dot_sick__scan__xd_dot_msg_dot_radar__pre__header__encoder__block__pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_measurement_param1_block_pb2 as make87__messages__ros2_dot_humble_dot_sick__scan__xd_dot_msg_dot_radar__pre__header__measurement__param1__block__pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_status_block_pb2 as make87__messages__ros2_dot_humble_dot_sick__scan__xd_dot_msg_dot_radar__pre__header__status__block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header.proto\x12,make87_messages_ros2.humble.sick_scan_xd.msg\x1a!make87_messages/core/header.proto\x1aPmake87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header_device_block.proto\x1aQmake87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header_encoder_block.proto\x1a\\make87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header_measurement_param1_block.proto\x1aPmake87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header_status_block.proto\"\xa1\x04\n\x0eRadarPreHeader\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0buiversionno\x18\x02 \x01(\r\x12j\n\x19radarpreheaderdeviceblock\x18\x03 \x01(\x0b\x32G.make87_messages_ros2.humble.sick_scan_xd.msg.RadarPreHeaderDeviceBlock\x12j\n\x19radarpreheaderstatusblock\x18\x04 \x01(\x0b\x32G.make87_messages_ros2.humble.sick_scan_xd.msg.RadarPreHeaderStatusBlock\x12\x80\x01\n$radarpreheadermeasurementparam1block\x18\x05 \x01(\x0b\x32R.make87_messages_ros2.humble.sick_scan_xd.msg.RadarPreHeaderMeasurementParam1Block\x12q\n\x1fradarpreheaderarrayencoderblock\x18\x06 \x03(\x0b\x32H.make87_messages_ros2.humble.sick_scan_xd.msg.RadarPreHeaderEncoderBlockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sick_scan_xd.msg.radar_pre_header_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RADARPREHEADER']._serialized_start=494
  _globals['_RADARPREHEADER']._serialized_end=1039
# @@protoc_insertion_point(module_scope)
