# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/msg/link.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6make87_messages_ros2/jazzy/rtabmap_msgs/msg/link.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.msg\x1a<make87_messages_ros2/jazzy/geometry_msgs/msg/transform.proto\"\x95\x01\n\x04Link\x12\x0f\n\x07\x66rom_id\x18\x01 \x01(\x05\x12\r\n\x05to_id\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12J\n\ttransform\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12\x13\n\x0binformation\x18\x05 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.msg.link_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LINK']._serialized_start=166
  _globals['_LINK']._serialized_end=315
# @@protoc_insertion_point(module_scope)
