# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/silhouette_match_detect_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import collision_detection_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_collision__detection__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import grasp_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_grasp__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import load_carrier_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_load__carrier__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import match_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_match__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import silhouette_match_object_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_silhouette__match__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/rc_reason_msgs/srv/silhouette_match_detect_object.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\x1aImake87_messages_ros2/rolling/rc_reason_msgs/msg/collision_detection.proto\x1a;make87_messages_ros2/rolling/rc_reason_msgs/msg/grasp.proto\x1a\x42make87_messages_ros2/rolling/rc_reason_msgs/msg/load_carrier.proto\x1a;make87_messages_ros2/rolling/rc_reason_msgs/msg/match.proto\x1aMmake87_messages_ros2/rolling/rc_reason_msgs/msg/silhouette_match_object.proto\"\x8f\x03\n\"SilhouetteMatchDetectObjectRequest\x12`\n\x10object_to_detect\x18\x01 \x01(\x0b\x32\x46.make87_messages_ros2.rolling.rc_reason_msgs.msg.SilhouetteMatchObject\x12\x0e\n\x06offset\x18\x02 \x01(\x01\x12\x12\n\npose_frame\x18\x03 \x01(\t\x12H\n\nrobot_pose\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x17\n\x0fload_carrier_id\x18\x05 \x01(\t\x12`\n\x13\x63ollision_detection\x18\x06 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.rc_reason_msgs.msg.CollisionDetection\x12\x1e\n\x16object_plane_detection\x18\x07 \x01(\x08\"\xbe\x03\n#SilhouetteMatchDetectObjectResponse\x12L\n\ttimestamp\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x11\n\tobject_id\x18\x02 \x01(\t\x12G\n\x07matches\x18\x03 \x03(\x0b\x32\x36.make87_messages_ros2.rolling.rc_reason_msgs.msg.Match\x12\x46\n\x06grasps\x18\x04 \x03(\x0b\x32\x36.make87_messages_ros2.rolling.rc_reason_msgs.msg.Grasp\x12S\n\rload_carriers\x18\x05 \x03(\x0b\x32<.make87_messages_ros2.rolling.rc_reason_msgs.msg.LoadCarrier\x12P\n\x0breturn_code\x18\x06 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.silhouette_match_detect_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SILHOUETTEMATCHDETECTOBJECTREQUEST']._serialized_start=672
  _globals['_SILHOUETTEMATCHDETECTOBJECTREQUEST']._serialized_end=1071
  _globals['_SILHOUETTEMATCHDETECTOBJECTRESPONSE']._serialized_start=1074
  _globals['_SILHOUETTEMATCHDETECTOBJECTRESPONSE']._serialized_end=1520
# @@protoc_insertion_point(module_scope)
