# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/rxm_svsi.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ublox_msgs.msg import rxm_svsisv_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__msgs_dot_msg_dot_rxm__svsisv__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/ublox_msgs/msg/rxm_svsi.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\x1a:make87_messages_ros2/jazzy/ublox_msgs/msg/rxm_svsisv.proto\"\x89\x01\n\x07RxmSVSI\x12\r\n\x05i_tow\x18\x01 \x01(\x05\x12\x0c\n\x04week\x18\x02 \x01(\x05\x12\x0f\n\x07num_vis\x18\x03 \x01(\r\x12\x0e\n\x06num_sv\x18\x04 \x01(\r\x12@\n\x02sv\x18\x05 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.ublox_msgs.msg.RxmSVSISVb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.rxm_svsi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RXMSVSI']._serialized_start=164
  _globals['_RXMSVSI']._serialized_end=301
# @@protoc_insertion_point(module_scope)
