# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_planning_msgs/msg/trajectory_point.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/autoware_planning_msgs/msg/trajectory_point.proto\x12\x36make87_messages_ros2.humble.autoware_planning_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/builtin_interfaces/msg/duration.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\"\x8c\x03\n\x0fTrajectoryPoint\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12U\n\x0ftime_from_start\x18\x02 \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Duration\x12\x41\n\x04pose\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12!\n\x19longitudinal_velocity_mps\x18\x04 \x01(\x02\x12\x1c\n\x14lateral_velocity_mps\x18\x05 \x01(\x02\x12\x19\n\x11\x61\x63\x63\x65leration_mps2\x18\x06 \x01(\x02\x12\x18\n\x10heading_rate_rps\x18\x07 \x01(\x02\x12\x1d\n\x15\x66ront_wheel_angle_rad\x18\x08 \x01(\x02\x12\x1c\n\x14rear_wheel_angle_rad\x18\t \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_planning_msgs.msg.trajectory_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRAJECTORYPOINT']._serialized_start=298
  _globals['_TRAJECTORYPOINT']._serialized_end=694
# @@protoc_insertion_point(module_scope)
