# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_babel_fish_test_msgs/msg/test_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg import test_sub_array_pb2 as make87__messages__ros2_dot_rolling_dot_ros__babel__fish__test__msgs_dot_msg_dot_test__sub__array__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/ros_babel_fish_test_msgs/msg/test_array.proto\x12\x39make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1aNmake87_messages_ros2/rolling/ros_babel_fish_test_msgs/msg/test_sub_array.proto\"\xab\x04\n\tTestArray\x12\r\n\x05\x62ools\x18\x01 \x03(\x08\x12\x0e\n\x06uint8s\x18\x02 \x03(\r\x12\x0f\n\x07uint16s\x18\x03 \x03(\r\x12\x0f\n\x07uint32s\x18\x04 \x03(\r\x12\x0f\n\x07uint64s\x18\x05 \x03(\x04\x12\r\n\x05int8s\x18\x06 \x03(\x05\x12\x0e\n\x06int16s\x18\x07 \x03(\x05\x12\x0e\n\x06int32s\x18\x08 \x03(\x05\x12\x0e\n\x06int64s\x18\t \x03(\x03\x12\x10\n\x08\x66loat32s\x18\n \x03(\x02\x12\x10\n\x08\x66loat64s\x18\x0b \x03(\x01\x12H\n\x05times\x18\x0c \x03(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12P\n\tdurations\x18\r \x03(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Duration\x12\x0f\n\x07strings\x18\x0e \x03(\t\x12`\n\x0fsubarrays_fixed\x18\x0f \x03(\x0b\x32G.make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg.TestSubArray\x12Z\n\tsubarrays\x18\x10 \x03(\x0b\x32G.make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg.TestSubArrayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg.test_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TESTARRAY']._serialized_start=350
  _globals['_TESTARRAY']._serialized_end=905
# @@protoc_insertion_point(module_scope)
