# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/msg/odom_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import camera_models_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_camera__models__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import key_point_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_key__point__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import point2f_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_point2f__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import point3f_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_point3f__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/humble/rtabmap_msgs/msg/odom_info.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\x1a=make87_messages_ros2/humble/geometry_msgs/msg/transform.proto\x1a@make87_messages_ros2/humble/rtabmap_msgs/msg/camera_models.proto\x1a<make87_messages_ros2/humble/rtabmap_msgs/msg/key_point.proto\x1a:make87_messages_ros2/humble/rtabmap_msgs/msg/point2f.proto\x1a:make87_messages_ros2/humble/rtabmap_msgs/msg/point3f.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x9f\x0e\n\x08OdomInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0c\n\x04lost\x18\x03 \x01(\x08\x12\x0f\n\x07matches\x18\x04 \x01(\x05\x12\x0f\n\x07inliers\x18\x05 \x01(\x05\x12\x19\n\x11icp_inliers_ratio\x18\x06 \x01(\x02\x12\x14\n\x0cicp_rotation\x18\x07 \x01(\x02\x12\x17\n\x0ficp_translation\x18\x08 \x01(\x02\x12!\n\x19icp_structural_complexity\x18\t \x01(\x02\x12#\n\x1bicp_structural_distribution\x18\n \x01(\x02\x12\x1b\n\x13icp_correspondences\x18\x0b \x01(\x05\x12\x12\n\ncovariance\x18\x0c \x03(\x01\x12\x10\n\x08\x66\x65\x61tures\x18\r \x01(\x05\x12\x16\n\x0elocal_map_size\x18\x0e \x01(\x05\x12\x1b\n\x13local_scan_map_size\x18\x0f \x01(\x05\x12\x18\n\x10local_key_frames\x18\x10 \x01(\x05\x12\x1d\n\x15local_bundle_outliers\x18\x11 \x01(\x05\x12 \n\x18local_bundle_constraints\x18\x12 \x01(\x05\x12\x19\n\x11local_bundle_time\x18\x13 \x01(\x02\x12\x17\n\x0fkey_frame_added\x18\x14 \x01(\x08\x12\x17\n\x0ftime_estimation\x18\x15 \x01(\x02\x12\x1f\n\x17time_particle_filtering\x18\x16 \x01(\x02\x12\r\n\x05stamp\x18\x17 \x01(\x02\x12\x10\n\x08interval\x18\x18 \x01(\x02\x12\x1a\n\x12\x64istance_travelled\x18\x19 \x01(\x02\x12\x14\n\x0cmemory_usage\x18\x1a \x01(\x05\x12\x1a\n\x12gravity_roll_error\x18\x1b \x01(\x02\x12\x1b\n\x13gravity_pitch_error\x18\x1c \x01(\x02\x12\x18\n\x10local_bundle_ids\x18\x1d \x03(\x05\x12W\n\x13local_bundle_models\x18\x1e \x03(\x0b\x32:.make87_messages_ros2.humble.rtabmap_msgs.msg.CameraModels\x12O\n\x12local_bundle_poses\x18\x1f \x03(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12K\n\ttransform\x18  \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12T\n\x12transform_filtered\x18! \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12X\n\x16transform_ground_truth\x18\" \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12G\n\x05guess\x18# \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12\x0c\n\x04type\x18$ \x01(\x05\x12\x12\n\nwords_keys\x18% \x03(\x05\x12L\n\x0cwords_values\x18& \x03(\x0b\x32\x36.make87_messages_ros2.humble.rtabmap_msgs.msg.KeyPoint\x12\x14\n\x0cword_matches\x18\' \x03(\x05\x12\x14\n\x0cword_inliers\x18( \x03(\x05\x12\x16\n\x0elocal_map_keys\x18) \x03(\x05\x12O\n\x10local_map_values\x18* \x03(\x0b\x32\x35.make87_messages_ros2.humble.rtabmap_msgs.msg.Point3f\x12P\n\x0elocal_scan_map\x18+ \x01(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2\x12J\n\x0bref_corners\x18, \x03(\x0b\x32\x35.make87_messages_ros2.humble.rtabmap_msgs.msg.Point2f\x12J\n\x0bnew_corners\x18- \x03(\x0b\x32\x35.make87_messages_ros2.humble.rtabmap_msgs.msg.Point2f\x12\x16\n\x0e\x63orner_inliers\x18. \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.msg.odom_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ODOMINFO']._serialized_start=634
  _globals['_ODOMINFO']._serialized_end=2457
# @@protoc_insertion_point(module_scope)
