# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/tuw_object_msgs/msg/object_with_covariance_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.humble.tuw_object_msgs.msg import object_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_tuw__object__msgs_dot_msg_dot_object__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/humble/tuw_object_msgs/msg/object_with_covariance_array.proto\x12/make87_messages_ros2.humble.tuw_object_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\x1aLmake87_messages_ros2/humble/tuw_object_msgs/msg/object_with_covariance.proto\"\xe8\x01\n\x19ObjectWithCovarianceArray\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12V\n\x07objects\x18\x03 \x03(\x0b\x32\x45.make87_messages_ros2.humble.tuw_object_msgs.msg.ObjectWithCovarianceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.tuw_object_msgs.msg.object_with_covariance_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBJECTWITHCOVARIANCEARRAY']._serialized_start=304
  _globals['_OBJECTWITHCOVARIANCEARRAY']._serialized_end=536
# @@protoc_insertion_point(module_scope)
