from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrajectoryStates(_message.Message):
    __slots__ = ("header", "trajectory_id", "trajectory_state")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_STATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    trajectory_id: _containers.RepeatedScalarFieldContainer[int]
    trajectory_state: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., trajectory_id: _Optional[_Iterable[int]] = ..., trajectory_state: _Optional[_Iterable[int]] = ...) -> None: ...
