# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_mrr_msgs/msg/active_fault_latched1.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/humble/delphi_mrr_msgs/msg/active_fault_latched1.proto\x12/make87_messages_ros2.humble.delphi_mrr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd7\x12\n\x13\x41\x63tiveFaultLatched1\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12%\n\x1d\x61\x63tive_flt_latched_byte7_bit7\x18\x03 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte7_bit6\x18\x04 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte7_bit5\x18\x05 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte7_bit4\x18\x06 \x01(\x08\x12\x1f\n\x17\x61rm_to_dsp_chksum_fault\x18\x07 \x01(\x08\x12\x1f\n\x17\x64sp_to_arm_chksum_fault\x18\x08 \x01(\x08\x12 \n\x18host_to_arm_chksum_fault\x18\t \x01(\x08\x12 \n\x18\x61rm_to_host_chksum_fault\x18\n \x01(\x08\x12\x1c\n\x14loop_bw_out_of_range\x18\x0b \x01(\x08\x12\x19\n\x11\x64sp_overrun_fault\x18\x0c \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte6_bit5\x18\r \x01(\x08\x12 \n\x18tuning_sensitivity_fault\x18\x0e \x01(\x08\x12#\n\x1bsaturated_tuning_freq_fault\x18\x0f \x01(\x08\x12\x1d\n\x15local_osc_power_fault\x18\x10 \x01(\x08\x12\x1f\n\x17transmitter_power_fault\x18\x11 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte6_bit0\x18\x12 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte5_bit7\x18\x13 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte5_bit6\x18\x14 \x01(\x08\x12\x1d\n\x15xcvr_device_spi_fault\x18\x15 \x01(\x08\x12\"\n\x1a\x66req_synthesizer_spi_fault\x18\x16 \x01(\x08\x12(\n analog_converter_devic_spi_fault\x18\x17 \x01(\x08\x12\x1a\n\x12side_lobe_blockage\x18\x18 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte5_bit1\x18\x19 \x01(\x08\x12\x13\n\x0bmnr_blocked\x18\x1a \x01(\x08\x12\x1b\n\x13\x65\x63u_temp_high_fault\x18\x1b \x01(\x08\x12#\n\x1btransmitter_temp_high_fault\x18\x1c \x01(\x08\x12&\n\x1e\x61lignment_routine_failed_fault\x18\x1d \x01(\x08\x12\x1f\n\x17unreasonable_radar_data\x18\x1e \x01(\x08\x12&\n\x1emicroprocessor_temp_high_fault\x18\x1f \x01(\x08\x12\'\n\x1fvertical_alignment_out_of_range\x18  \x01(\x08\x12)\n!horizontal_alignment_out_of_range\x18! \x01(\x08\x12\x1e\n\x16\x66\x61\x63tory_alignment_mode\x18\" \x01(\x08\x12\x19\n\x11\x62\x61ttery_low_fault\x18# \x01(\x08\x12\x1a\n\x12\x62\x61ttery_high_fault\x18$ \x01(\x08\x12\"\n\x1av_1p25_supply_out_of_range\x18% \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte3_bit4\x18& \x01(\x08\x12\x1f\n\x17thermistor_out_of_range\x18\' \x01(\x08\x12%\n\x1dv_3p3_dac_supply_out_of_range\x18( \x01(\x08\x12%\n\x1dv_3p3_raw_supply_out_of_range\x18) \x01(\x08\x12\x1f\n\x17v_5_supply_out_of_range\x18* \x01(\x08\x12\x1c\n\x14transmitter_id_fault\x18+ \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit6\x18, \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit5\x18- \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit4\x18. \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit3\x18/ \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit2\x18\x30 \x01(\x08\x12\x1e\n\x16pcan_missing_msg_fault\x18\x31 \x01(\x08\x12\x14\n\x0cpcan_bus_off\x18\x32 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte1_bit7\x18\x33 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte1_bit6\x18\x34 \x01(\x08\x12#\n\x1binstruction_set_check_fault\x18\x35 \x01(\x08\x12\x1c\n\x14stack_overflow_fault\x18\x36 \x01(\x08\x12\x16\n\x0ewatchdog_fault\x18\x37 \x01(\x08\x12\x16\n\x0epll_lock_fault\x18\x38 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte1_bit1\x18\x39 \x01(\x08\x12\x1d\n\x15ram_memory_test_fault\x18: \x01(\x08\x12\x1c\n\x14usc_validation_fault\x18; \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte0_bit6\x18< \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte0_bit5\x18= \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte0_bit4\x18> \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte0_bit3\x18? \x01(\x08\x12!\n\x19keep_alive_checksum_fault\x18@ \x01(\x08\x12*\n\"program_calibration_flash_checksum\x18\x41 \x01(\x08\x12(\n application_flash_checksum_fault\x18\x42 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_mrr_msgs.msg.active_fault_latched1_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ACTIVEFAULTLATCHED1']._serialized_start=219
  _globals['_ACTIVEFAULTLATCHED1']._serialized_end=2610
# @@protoc_insertion_point(module_scope)
