# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_states.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_task_msgs.msg import dispatch_state_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__task__msgs_dot_msg_dot_dispatch__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_states.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.msg\x1a\x41make87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_state.proto\"\xac\x01\n\x0e\x44ispatchStates\x12K\n\x06\x61\x63tive\x18\x01 \x03(\x0b\x32;.make87_messages_ros2.jazzy.rmf_task_msgs.msg.DispatchState\x12M\n\x08\x66inished\x18\x02 \x03(\x0b\x32;.make87_messages_ros2.jazzy.rmf_task_msgs.msg.DispatchStateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.msg.dispatch_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DISPATCHSTATES']._serialized_start=184
  _globals['_DISPATCHSTATES']._serialized_end=356
# @@protoc_insertion_point(module_scope)
