# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/get_motion_plan.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import motion_plan_request_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_motion__plan__request__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import motion_plan_response_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_motion__plan__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/moveit_msgs/srv/get_motion_plan.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/motion_plan_request.proto\x1a\x45make87_messages_ros2/jazzy/moveit_msgs/msg/motion_plan_response.proto\"r\n\x14GetMotionPlanRequest\x12Z\n\x13motion_plan_request\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.moveit_msgs.msg.MotionPlanRequest\"u\n\x15GetMotionPlanResponse\x12\\\n\x14motion_plan_response\x18\x01 \x01(\x0b\x32>.make87_messages_ros2.jazzy.moveit_msgs.msg.MotionPlanResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.get_motion_plan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETMOTIONPLANREQUEST']._serialized_start=253
  _globals['_GETMOTIONPLANREQUEST']._serialized_end=367
  _globals['_GETMOTIONPLANRESPONSE']._serialized_start=369
  _globals['_GETMOTIONPLANRESPONSE']._serialized_end=486
# @@protoc_insertion_point(module_scope)
