# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_msgs/srv/set_io.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3make87_messages_ros2/jazzy/ur_msgs/srv/set_io.proto\x12&make87_messages_ros2.jazzy.ur_msgs.srv\"7\n\x0cSetIORequest\x12\x0b\n\x03\x66un\x18\x01 \x01(\x05\x12\x0b\n\x03pin\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x02\" \n\rSetIOResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_msgs.srv.set_io_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETIOREQUEST']._serialized_start=95
  _globals['_SETIOREQUEST']._serialized_end=150
  _globals['_SETIORESPONSE']._serialized_start=152
  _globals['_SETIORESPONSE']._serialized_end=184
# @@protoc_insertion_point(module_scope)
