# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/get_physics_properties.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.gazebo_msgs.msg import ode_physics_pb2 as make87__messages__ros2_dot_jazzy_dot_gazebo__msgs_dot_msg_dot_ode__physics__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/gazebo_msgs/srv/get_physics_properties.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a<make87_messages_ros2/jazzy/gazebo_msgs/msg/ode_physics.proto\x1a:make87_messages_ros2/jazzy/geometry_msgs/msg/vector3.proto\"\x1d\n\x1bGetPhysicsPropertiesRequest\"\x96\x02\n\x1cGetPhysicsPropertiesResponse\x12\x11\n\ttime_step\x18\x01 \x01(\x01\x12\r\n\x05pause\x18\x02 \x01(\x08\x12\x17\n\x0fmax_update_rate\x18\x03 \x01(\x01\x12\x46\n\x07gravity\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12J\n\node_config\x18\x05 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.gazebo_msgs.msg.ODEPhysics\x12\x0f\n\x07success\x18\x06 \x01(\x08\x12\x16\n\x0estatus_message\x18\x07 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.get_physics_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPHYSICSPROPERTIESREQUEST']._serialized_start=241
  _globals['_GETPHYSICSPROPERTIESREQUEST']._serialized_end=270
  _globals['_GETPHYSICSPROPERTIESRESPONSE']._serialized_start=273
  _globals['_GETPHYSICSPROPERTIESRESPONSE']._serialized_end=551
# @@protoc_insertion_point(module_scope)
