# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/grasping_msgs/msg/graspable_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.grasping_msgs.msg import object_pb2 as make87__messages__ros2_dot_rolling_dot_grasping__msgs_dot_msg_dot_object__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import grasp_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_grasp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/grasping_msgs/msg/graspable_object.proto\x12.make87_messages_ros2.rolling.grasping_msgs.msg\x1a;make87_messages_ros2/rolling/grasping_msgs/msg/object.proto\x1a\x38make87_messages_ros2/rolling/moveit_msgs/msg/grasp.proto\"\x9e\x01\n\x0fGraspableObject\x12\x46\n\x06object\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.grasping_msgs.msg.Object\x12\x43\n\x06grasps\x18\x02 \x03(\x0b\x32\x33.make87_messages_ros2.rolling.moveit_msgs.msg.Graspb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.grasping_msgs.msg.graspable_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRASPABLEOBJECT']._serialized_start=241
  _globals['_GRASPABLEOBJECT']._serialized_end=399
# @@protoc_insertion_point(module_scope)
