# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nav2_msgs/srv/load_map.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.nav_msgs.msg import occupancy_grid_pb2 as make87__messages__ros2_dot_jazzy_dot_nav__msgs_dot_msg_dot_occupancy__grid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/nav2_msgs/srv/load_map.proto\x12(make87_messages_ros2.jazzy.nav2_msgs.srv\x1a<make87_messages_ros2/jazzy/nav_msgs/msg/occupancy_grid.proto\"!\n\x0eLoadMapRequest\x12\x0f\n\x07map_url\x18\x01 \x01(\t\"f\n\x0fLoadMapResponse\x12\x43\n\x03map\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.nav_msgs.msg.OccupancyGrid\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nav2_msgs.srv.load_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LOADMAPREQUEST']._serialized_start=163
  _globals['_LOADMAPREQUEST']._serialized_end=196
  _globals['_LOADMAPRESPONSE']._serialized_start=198
  _globals['_LOADMAPRESPONSE']._serialized_end=300
# @@protoc_insertion_point(module_scope)
