# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/neobotix_usboard_msgs/msg/sensor_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/neobotix_usboard_msgs/msg/sensor_data.proto\x12\x36make87_messages_ros2.rolling.neobotix_usboard_msgs.msg\"K\n\nSensorData\x12\x10\n\x08\x64istance\x18\x01 \x01(\r\x12\x0c\n\x04warn\x18\x02 \x01(\x08\x12\r\n\x05\x61larm\x18\x03 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.neobotix_usboard_msgs.msg.sensor_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENSORDATA']._serialized_start=132
  _globals['_SENSORDATA']._serialized_end=207
# @@protoc_insertion_point(module_scope)
