# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/roi_observation_safety_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n`make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/roi_observation_safety_data.proto\x12>make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg\"\x8a\x03\n\x18ROIObservationSafetyData\x12%\n\x1dinvalid_due_to_invalid_pixels\x18\x01 \x01(\r\x12\x1f\n\x17invalid_due_to_variance\x18\x02 \x01(\r\x12#\n\x1binvalid_due_to_overexposure\x18\x03 \x01(\r\x12$\n\x1cinvalid_due_to_underexposure\x18\x04 \x01(\r\x12(\n invalid_due_to_temporal_variance\x18\x05 \x01(\r\x12\x33\n+invalid_due_to_outside_of_measurement_range\x18\x06 \x01(\r\x12\x33\n+invalid_due_to_retro_reflector_interference\x18\x07 \x01(\r\x12\x1b\n\x13\x63ontamination_error\x18\x08 \x01(\r\x12\x15\n\rquality_class\x18\t \x01(\r\x12\x13\n\x0bslot_active\x18\n \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.roi_observation_safety_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROIOBSERVATIONSAFETYDATA']._serialized_start=165
  _globals['_ROIOBSERVATIONSAFETYDATA']._serialized_end=559
# @@protoc_insertion_point(module_scope)
