# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plansys2_msgs/srv/get_domain_actions.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import empty_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/plansys2_msgs/srv/get_domain_actions.proto\x12,make87_messages_ros2.jazzy.plansys2_msgs.srv\x1a\x33make87_messages_ros2/jazzy/std_msgs/msg/empty.proto\"Z\n\x17GetDomainActionsRequest\x12?\n\x07request\x18\x01 \x01(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Empty\"P\n\x18GetDomainActionsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x61\x63tions\x18\x02 \x03(\t\x12\x12\n\nerror_info\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plansys2_msgs.srv.get_domain_actions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETDOMAINACTIONSREQUEST']._serialized_start=172
  _globals['_GETDOMAINACTIONSREQUEST']._serialized_end=262
  _globals['_GETDOMAINACTIONSRESPONSE']._serialized_start=264
  _globals['_GETDOMAINACTIONSRESPONSE']._serialized_end=344
# @@protoc_insertion_point(module_scope)
