# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/nav_sbas.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ublox_msgs.msg import nav_sbassv_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__msgs_dot_msg_dot_nav__sbassv__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/ublox_msgs/msg/nav_sbas.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\x1a:make87_messages_ros2/jazzy/ublox_msgs/msg/nav_sbassv.proto\"\xb3\x01\n\x07NavSBAS\x12\r\n\x05i_tow\x18\x01 \x01(\r\x12\x0b\n\x03geo\x18\x02 \x01(\r\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x0b\n\x03sys\x18\x04 \x01(\x05\x12\x0f\n\x07service\x18\x05 \x01(\r\x12\x0b\n\x03\x63nt\x18\x06 \x01(\r\x12\x11\n\treserved0\x18\x07 \x03(\r\x12@\n\x02sv\x18\x08 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.ublox_msgs.msg.NavSBASSVb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.nav_sbas_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NAVSBAS']._serialized_start=164
  _globals['_NAVSBAS']._serialized_end=343
# @@protoc_insertion_point(module_scope)
