# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/game_controller_spl_interfaces/msg/team_info15.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.game_controller_spl_interfaces.msg import robot_info15_pb2 as make87__messages__ros2_dot_humble_dot_game__controller__spl__interfaces_dot_msg_dot_robot__info15__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/game_controller_spl_interfaces/msg/team_info15.proto\x12>make87_messages_ros2.humble.game_controller_spl_interfaces.msg\x1a!make87_messages/core/header.proto\x1aQmake87_messages_ros2/humble/game_controller_spl_interfaces/msg/robot_info15.proto\"\xe1\x02\n\nTeamInfo15\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0bteam_number\x18\x02 \x01(\r\x12\x1b\n\x13\x66ield_player_colour\x18\x03 \x01(\r\x12\x19\n\x11goalkeeper_colour\x18\x04 \x01(\r\x12\x12\n\ngoalkeeper\x18\x05 \x01(\r\x12\x13\n\x0bteam_colour\x18\x06 \x01(\r\x12\r\n\x05score\x18\x07 \x01(\r\x12\x14\n\x0cpenalty_shot\x18\x08 \x01(\r\x12\x14\n\x0csingle_shots\x18\t \x01(\r\x12\x16\n\x0emessage_budget\x18\n \x01(\r\x12\\\n\x07players\x18\x0b \x03(\x0b\x32K.make87_messages_ros2.humble.game_controller_spl_interfaces.msg.RobotInfo15b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.game_controller_spl_interfaces.msg.team_info15_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TEAMINFO15']._serialized_start=267
  _globals['_TEAMINFO15']._serialized_end=620
# @@protoc_insertion_point(module_scope)
