# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/septentrio_gnss_driver/msg/vector_info_geod.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/septentrio_gnss_driver/msg/vector_info_geod.proto\x12\x37make87_messages_ros2.rolling.septentrio_gnss_driver.msg\"\x9c\x02\n\x0eVectorInfoGeod\x12\r\n\x05nr_sv\x18\x01 \x01(\r\x12\r\n\x05\x65rror\x18\x02 \x01(\r\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x0c\n\x04misc\x18\x04 \x01(\r\x12\x12\n\ndelta_east\x18\x05 \x01(\x01\x12\x13\n\x0b\x64\x65lta_north\x18\x06 \x01(\x01\x12\x10\n\x08\x64\x65lta_up\x18\x07 \x01(\x01\x12\x10\n\x08\x64\x65lta_ve\x18\x08 \x01(\x02\x12\x10\n\x08\x64\x65lta_vn\x18\t \x01(\x02\x12\x10\n\x08\x64\x65lta_vu\x18\n \x01(\x02\x12\x0f\n\x07\x61zimuth\x18\x0b \x01(\r\x12\x11\n\televation\x18\x0c \x01(\x05\x12\x14\n\x0creference_id\x18\r \x01(\r\x12\x10\n\x08\x63orr_age\x18\x0e \x01(\r\x12\x13\n\x0bsignal_info\x18\x0f \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.septentrio_gnss_driver.msg.vector_info_geod_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VECTORINFOGEOD']._serialized_start=140
  _globals['_VECTORINFOGEOD']._serialized_end=424
# @@protoc_insertion_point(module_scope)
