# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ros2cli_test_interfaces/srv/short_varied_multi_nested.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ros2cli_test_interfaces.msg import short_varied_nested_pb2 as make87__messages__ros2_dot_jazzy_dot_ros2cli__test__interfaces_dot_msg_dot_short__varied__nested__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVmake87_messages_ros2/jazzy/ros2cli_test_interfaces/srv/short_varied_multi_nested.proto\x12\x36make87_messages_ros2.jazzy.ros2cli_test_interfaces.srv\x1aPmake87_messages_ros2/jazzy/ros2cli_test_interfaces/msg/short_varied_nested.proto\"\x87\x01\n\x1dShortVariedMultiNestedRequest\x12\x66\n\x13short_varied_nested\x18\x01 \x01(\x0b\x32I.make87_messages_ros2.jazzy.ros2cli_test_interfaces.msg.ShortVariedNested\"4\n\x1eShortVariedMultiNestedResponse\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ros2cli_test_interfaces.srv.short_varied_multi_nested_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SHORTVARIEDMULTINESTEDREQUEST']._serialized_start=229
  _globals['_SHORTVARIEDMULTINESTEDREQUEST']._serialized_end=364
  _globals['_SHORTVARIEDMULTINESTEDRESPONSE']._serialized_start=366
  _globals['_SHORTVARIEDMULTINESTEDRESPONSE']._serialized_end=418
# @@protoc_insertion_point(module_scope)
