# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ros_ign_interfaces/srv/spawn_entity.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ros_gz_interfaces.msg import entity_factory_pb2 as make87__messages__ros2_dot_humble_dot_ros__gz__interfaces_dot_msg_dot_entity__factory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/ros_ign_interfaces/srv/spawn_entity.proto\x12\x32make87_messages_ros2.humble.ros_ign_interfaces.srv\x1a!make87_messages/core/header.proto\x1a\x46make87_messages_ros2/humble/ros_gz_interfaces/msg/entity_factory.proto\"\x9c\x01\n\x12SpawnEntityRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12X\n\x0e\x65ntity_factory\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.humble.ros_gz_interfaces.msg.EntityFactory\"T\n\x13SpawnEntityResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ros_ign_interfaces.srv.spawn_entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SPAWNENTITYREQUEST']._serialized_start=233
  _globals['_SPAWNENTITYREQUEST']._serialized_end=389
  _globals['_SPAWNENTITYRESPONSE']._serialized_start=391
  _globals['_SPAWNENTITYRESPONSE']._serialized_end=475
# @@protoc_insertion_point(module_scope)
