# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rc_reason_msgs/msg/load_carrier_model.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import box_pb2 as make87__messages__ros2_dot_humble_dot_rc__reason__msgs_dot_msg_dot_box__pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import rectangle_pb2 as make87__messages__ros2_dot_humble_dot_rc__reason__msgs_dot_msg_dot_rectangle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/rc_reason_msgs/msg/load_carrier_model.proto\x12.make87_messages_ros2.humble.rc_reason_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/geometry_msgs/msg/pose_stamped.proto\x1a\x38make87_messages_ros2/humble/rc_reason_msgs/msg/box.proto\x1a>make87_messages_ros2/humble/rc_reason_msgs/msg/rectangle.proto\"\xa8\x04\n\x10LoadCarrierModel\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12M\n\x10outer_dimensions\x18\x04 \x01(\x0b\x32\x33.make87_messages_ros2.humble.rc_reason_msgs.msg.Box\x12M\n\x10inner_dimensions\x18\x05 \x01(\x0b\x32\x33.make87_messages_ros2.humble.rc_reason_msgs.msg.Box\x12P\n\rrim_thickness\x18\x06 \x01(\x0b\x32\x39.make87_messages_ros2.humble.rc_reason_msgs.msg.Rectangle\x12\x17\n\x0frim_step_height\x18\x07 \x01(\x01\x12L\n\trim_ledge\x18\x08 \x01(\x0b\x32\x39.make87_messages_ros2.humble.rc_reason_msgs.msg.Rectangle\x12\x18\n\x10height_open_side\x18\t \x01(\x01\x12H\n\x04pose\x18\n \x01(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12\x11\n\tpose_type\x18\x0b \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rc_reason_msgs.msg.load_carrier_model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LOADCARRIERMODEL']._serialized_start=347
  _globals['_LOADCARRIERMODEL']._serialized_end=899
# @@protoc_insertion_point(module_scope)
