# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_scheduler_msgs/srv/cancel_schedule.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_scheduler_msgs/srv/cancel_schedule.proto\x12\x33make87_messages_ros2.rolling.rmf_scheduler_msgs.srv\"7\n\x15\x43\x61ncelScheduleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x66inished\x18\x02 \x01(\x08\":\n\x16\x43\x61ncelScheduleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_scheduler_msgs.srv.cancel_schedule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CANCELSCHEDULEREQUEST']._serialized_start=130
  _globals['_CANCELSCHEDULEREQUEST']._serialized_end=185
  _globals['_CANCELSCHEDULERESPONSE']._serialized_start=187
  _globals['_CANCELSCHEDULERESPONSE']._serialized_end=245
# @@protoc_insertion_point(module_scope)
