# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_control_msgs/msg/longitudinal.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/autoware_control_msgs/msg/longitudinal.proto\x12\x36make87_messages_ros2.rolling.autoware_control_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\"\x99\x02\n\x0cLongitudinal\x12H\n\x05stamp\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12O\n\x0c\x63ontrol_time\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x10\n\x08velocity\x18\x03 \x01(\x02\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x02\x12\x0c\n\x04jerk\x18\x05 \x01(\x02\x12\x1f\n\x17is_defined_acceleration\x18\x06 \x01(\x08\x12\x17\n\x0fis_defined_jerk\x18\x07 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_control_msgs.msg.longitudinal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LONGITUDINAL']._serialized_start=198
  _globals['_LONGITUDINAL']._serialized_end=479
# @@protoc_insertion_point(module_scope)
