# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_gnss.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ublox_msgs.msg import cfg_gnss_block_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__msgs_dot_msg_dot_cfg__gnss__block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_gnss.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\x1a>make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_gnss_block.proto\"\xad\x01\n\x07\x43\x66gGNSS\x12\x0f\n\x07msg_ver\x18\x01 \x01(\r\x12\x15\n\rnum_trk_ch_hw\x18\x02 \x01(\r\x12\x16\n\x0enum_trk_ch_use\x18\x03 \x01(\r\x12\x19\n\x11num_config_blocks\x18\x04 \x01(\r\x12G\n\x06\x62locks\x18\x05 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.ublox_msgs.msg.CfgGNSSBlockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.cfg_gnss_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CFGGNSS']._serialized_start=168
  _globals['_CFGGNSS']._serialized_end=341
# @@protoc_insertion_point(module_scope)
