# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/nav_msgs/msg/map_meta_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/nav_msgs/msg/map_meta_data.proto\x12)make87_messages_ros2.rolling.nav_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\"\xd8\x01\n\x0bMapMetaData\x12P\n\rmap_load_time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x12\n\nresolution\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\r\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\x44\n\x06origin\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Poseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.nav_msgs.msg.map_meta_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MAPMETADATA']._serialized_start=232
  _globals['_MAPMETADATA']._serialized_end=448
# @@protoc_insertion_point(module_scope)
