# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/composition_interfaces/srv/list_nodes.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/composition_interfaces/srv/list_nodes.proto\x12\x35make87_messages_ros2.jazzy.composition_interfaces.srv\"\x12\n\x10ListNodesRequest\"@\n\x11ListNodesResponse\x12\x17\n\x0f\x66ull_node_names\x18\x01 \x03(\t\x12\x12\n\nunique_ids\x18\x02 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.composition_interfaces.srv.list_nodes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LISTNODESREQUEST']._serialized_start=129
  _globals['_LISTNODESREQUEST']._serialized_end=147
  _globals['_LISTNODESRESPONSE']._serialized_start=149
  _globals['_LISTNODESRESPONSE']._serialized_end=213
# @@protoc_insertion_point(module_scope)
