# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rc_reason_msgs/msg/grasp.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/rc_reason_msgs/msg/grasp.proto\x12-make87_messages_ros2.jazzy.rc_reason_msgs.msg\x1a?make87_messages_ros2/jazzy/geometry_msgs/msg/pose_stamped.proto\"\xbf\x01\n\x05Grasp\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x12\n\nmatch_uuid\x18\x03 \x01(\t\x12G\n\x04pose\x18\x04 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseStamped\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x12\n\ngripper_id\x18\x06 \x01(\t\x12\x19\n\x11\x63ollision_checked\x18\x07 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rc_reason_msgs.msg.grasp_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRASP']._serialized_start=174
  _globals['_GRASP']._serialized_end=365
# @@protoc_insertion_point(module_scope)
