# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/srv/detect_more_loop_closures.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/humble/rtabmap_msgs/srv/detect_more_loop_closures.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.srv\x1a!make87_messages/core/header.proto\"\xd8\x01\n\x1d\x44\x65tectMoreLoopClosuresRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x1a\n\x12\x63luster_radius_max\x18\x02 \x01(\x02\x12\x1a\n\x12\x63luster_radius_min\x18\x03 \x01(\x02\x12\x15\n\rcluster_angle\x18\x04 \x01(\x02\x12\x12\n\niterations\x18\x05 \x01(\x05\x12\x12\n\nintra_only\x18\x06 \x01(\x08\x12\x12\n\ninter_only\x18\x07 \x01(\x08\"`\n\x1e\x44\x65tectMoreLoopClosuresResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08\x64\x65tected\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.srv.detect_more_loop_closures_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTMORELOOPCLOSURESREQUEST']._serialized_start=162
  _globals['_DETECTMORELOOPCLOSURESREQUEST']._serialized_end=378
  _globals['_DETECTMORELOOPCLOSURESRESPONSE']._serialized_start=380
  _globals['_DETECTMORELOOPCLOSURESRESPONSE']._serialized_end=476
# @@protoc_insertion_point(module_scope)
