# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/global_position_target.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/mavros_msgs/msg/global_position_target.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a:make87_messages_ros2/jazzy/geometry_msgs/msg/vector3.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf9\x02\n\x14GlobalPositionTarget\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x18\n\x10\x63oordinate_frame\x18\x02 \x01(\r\x12\x11\n\ttype_mask\x18\x03 \x01(\r\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x11\n\tlongitude\x18\x05 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x06 \x01(\x02\x12G\n\x08velocity\x18\x07 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12T\n\x15\x61\x63\x63\x65leration_or_force\x18\x08 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12\x0b\n\x03yaw\x18\t \x01(\x02\x12\x10\n\x08yaw_rate\x18\n \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.global_position_target_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GLOBALPOSITIONTARGET']._serialized_start=234
  _globals['_GLOBALPOSITIONTARGET']._serialized_end=611
# @@protoc_insertion_point(module_scope)
