# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg import ball_pb2 as make87__messages__ros2_dot_jazzy_dot_soccer__vision__3d__msgs_dot_msg_dot_ball__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball_array.proto\x12\x34make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg\x1a?make87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x97\x01\n\tBallArray\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12I\n\x05\x62\x61lls\x18\x02 \x03(\x0b\x32:.make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg.Ballb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg.ball_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BALLARRAY']._serialized_start=247
  _globals['_BALLARRAY']._serialized_end=398
# @@protoc_insertion_point(module_scope)
