# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rc_reason_msgs/msg/item.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import rectangle_pb2 as make87__messages__ros2_dot_jazzy_dot_rc__reason__msgs_dot_msg_dot_rectangle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/rc_reason_msgs/msg/item.proto\x12-make87_messages_ros2.jazzy.rc_reason_msgs.msg\x1a?make87_messages_ros2/jazzy/geometry_msgs/msg/pose_stamped.proto\x1a=make87_messages_ros2/jazzy/rc_reason_msgs/msg/rectangle.proto\"\xcd\x01\n\x04Item\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x13\n\x0bgrasp_uuids\x18\x02 \x03(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12K\n\trectangle\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.rc_reason_msgs.msg.Rectangle\x12G\n\x04pose\x18\x05 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseStampedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rc_reason_msgs.msg.item_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ITEM']._serialized_start=236
  _globals['_ITEM']._serialized_end=441
# @@protoc_insertion_point(module_scope)
