# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/gazebo_msgs/srv/get_link_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.gazebo_msgs.msg import link_state_pb2 as make87__messages__ros2_dot_humble_dot_gazebo__msgs_dot_msg_dot_link__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/gazebo_msgs/srv/get_link_state.proto\x12+make87_messages_ros2.humble.gazebo_msgs.srv\x1a!make87_messages/core/header.proto\x1a<make87_messages_ros2/humble/gazebo_msgs/msg/link_state.proto\"o\n\x13GetLinkStateRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tlink_name\x18\x02 \x01(\t\x12\x17\n\x0freference_frame\x18\x03 \x01(\t\"\xb9\x01\n\x14GetLinkStateResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12J\n\nlink_state\x18\x02 \x01(\x0b\x32\x36.make87_messages_ros2.humble.gazebo_msgs.msg.LinkState\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\x16\n\x0estatus_message\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.gazebo_msgs.srv.get_link_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETLINKSTATEREQUEST']._serialized_start=210
  _globals['_GETLINKSTATEREQUEST']._serialized_end=321
  _globals['_GETLINKSTATERESPONSE']._serialized_start=324
  _globals['_GETLINKSTATERESPONSE']._serialized_end=509
# @@protoc_insertion_point(module_scope)
