# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/get_position_ik.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import position_ik_request_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_position__ik__request__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/moveit_msgs/srv/get_position_ik.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/move_it_error_codes.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/position_ik_request.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\"\x98\x01\n\x14GetPositionIKRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12R\n\nik_request\x18\x02 \x01(\x0b\x32>.make87_messages_ros2.humble.moveit_msgs.msg.PositionIKRequest\"\xe3\x01\n\x15GetPositionIKResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12I\n\x08solution\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12Q\n\nerror_code\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.humble.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.get_position_ik_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPOSITIONIKREQUEST']._serialized_start=355
  _globals['_GETPOSITIONIKREQUEST']._serialized_end=507
  _globals['_GETPOSITIONIKRESPONSE']._serialized_start=510
  _globals['_GETPOSITIONIKRESPONSE']._serialized_end=737
# @@protoc_insertion_point(module_scope)
