# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nav2_msgs/srv/clear_entire_costmap.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import empty_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/nav2_msgs/srv/clear_entire_costmap.proto\x12)make87_messages_ros2.humble.nav2_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x34make87_messages_ros2/humble/std_msgs/msg/empty.proto\"\x8b\x01\n\x19\x43learEntireCostmapRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12@\n\x07request\x18\x02 \x01(\x0b\x32/.make87_messages_ros2.humble.std_msgs.msg.Empty\"\x8d\x01\n\x1a\x43learEntireCostmapResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x41\n\x08response\x18\x02 \x01(\x0b\x32/.make87_messages_ros2.humble.std_msgs.msg.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nav2_msgs.srv.clear_entire_costmap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CLEARENTIRECOSTMAPREQUEST']._serialized_start=205
  _globals['_CLEARENTIRECOSTMAPREQUEST']._serialized_end=344
  _globals['_CLEARENTIRECOSTMAPRESPONSE']._serialized_start=347
  _globals['_CLEARENTIRECOSTMAPRESPONSE']._serialized_end=488
# @@protoc_insertion_point(module_scope)
