# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/delphi_esr_msgs/msg/esr_status6.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/delphi_esr_msgs/msg/esr_status6.proto\x12.make87_messages_ros2.jazzy.delphi_esr_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xd3\x03\n\nEsrStatus6\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0e\n\x06\x63\x61nmsg\x18\x02 \x01(\t\x12\x17\n\x0fsupply_1p8v_a2d\x18\x03 \x01(\r\x12\x16\n\x0esupply_n5v_a2d\x18\x04 \x01(\r\x12\x15\n\rwave_diff_a2d\x18\x05 \x01(\r\x12\x1f\n\x17sw_version_dsp_3rd_byte\x18\x06 \x01(\r\x12\x1e\n\x16vertical_align_updated\x18\x07 \x01(\x08\x12\x19\n\x11system_power_mode\x18\x08 \x01(\r\x12\x14\n\x0c\x66ound_target\x18\t \x01(\x08\x12\x1c\n\x14recommend_unconverge\x18\n \x01(\x08\x12\x1e\n\x16\x66\x61\x63tory_align_status_1\x18\x0b \x01(\r\x12\x1e\n\x16\x66\x61\x63tory_align_status_2\x18\x0c \x01(\r\x12\x1c\n\x14\x66\x61\x63tory_misalignment\x18\r \x01(\x02\x12\x1f\n\x17serv_align_updates_done\x18\x0e \x01(\r\x12\x1d\n\x15vertical_misalignment\x18\x0f \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.delphi_esr_msgs.msg.esr_status6_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESRSTATUS6']._serialized_start=171
  _globals['_ESRSTATUS6']._serialized_end=638
# @@protoc_insertion_point(module_scope)
