# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_psrdop2.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_message_header_pb2 as make87__messages__ros2_dot_rolling_dot_novatel__gps__msgs_dot_msg_dot_novatel__message__header__pb2
from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_psrdop2_system_pb2 as make87__messages__ros2_dot_rolling_dot_novatel__gps__msgs_dot_msg_dot_novatel__psrdop2__system__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_psrdop2.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\x1aNmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_message_header.proto\x1aNmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_psrdop2_system.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xca\x02\n\x0eNovatelPsrdop2\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x63\n\x12novatel_msg_header\x18\x02 \x01(\x0b\x32G.make87_messages_ros2.rolling.novatel_gps_msgs.msg.NovatelMessageHeader\x12\x0c\n\x04gdop\x18\x03 \x01(\x02\x12\x0c\n\x04pdop\x18\x04 \x01(\x02\x12\x0c\n\x04hdop\x18\x05 \x01(\x02\x12\x0c\n\x04vdop\x18\x06 \x01(\x02\x12X\n\x07systems\x18\x07 \x03(\x0b\x32G.make87_messages_ros2.rolling.novatel_gps_msgs.msg.NovatelPsrdop2Systemb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.novatel_psrdop2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NOVATELPSRDOP2']._serialized_start=343
  _globals['_NOVATELPSRDOP2']._serialized_end=673
# @@protoc_insertion_point(module_scope)
