# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ur_msgs/srv/set_payload.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/ur_msgs/srv/set_payload.proto\x12(make87_messages_ros2.rolling.ur_msgs.srv\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/vector3.proto\"u\n\x11SetPayloadRequest\x12\x0c\n\x04mass\x18\x01 \x01(\x02\x12R\n\x11\x63\x65nter_of_gravity\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\"%\n\x12SetPayloadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ur_msgs.srv.set_payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETPAYLOADREQUEST']._serialized_start=166
  _globals['_SETPAYLOADREQUEST']._serialized_end=283
  _globals['_SETPAYLOADRESPONSE']._serialized_start=285
  _globals['_SETPAYLOADRESPONSE']._serialized_end=322
# @@protoc_insertion_point(module_scope)
