# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_fleet_msgs/msg/destination_request.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import location_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_fleet_msgs/msg/destination_request.proto\x12/make87_messages_ros2.rolling.rmf_fleet_msgs.msg\x1a>make87_messages_ros2/rolling/rmf_fleet_msgs/msg/location.proto\"\x9d\x01\n\x12\x44\x65stinationRequest\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12\x12\n\nrobot_name\x18\x02 \x01(\t\x12N\n\x0b\x64\x65stination\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.Location\x12\x0f\n\x07task_id\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_fleet_msgs.msg.destination_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DESTINATIONREQUEST']._serialized_start=191
  _globals['_DESTINATIONREQUEST']._serialized_end=348
# @@protoc_insertion_point(module_scope)
