# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/planning_options.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_planning__scene__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/moveit_msgs/msg/planning_options.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x41make87_messages_ros2/rolling/moveit_msgs/msg/planning_scene.proto\"\x91\x02\n\x0fPlanningOptions\x12X\n\x13planning_scene_diff\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.moveit_msgs.msg.PlanningScene\x12\x11\n\tplan_only\x18\x02 \x01(\x08\x12\x13\n\x0blook_around\x18\x03 \x01(\x08\x12\x1c\n\x14look_around_attempts\x18\x04 \x01(\x05\x12\x1f\n\x17max_safe_execution_cost\x18\x05 \x01(\x01\x12\x0e\n\x06replan\x18\x06 \x01(\x08\x12\x17\n\x0freplan_attempts\x18\x07 \x01(\x05\x12\x14\n\x0creplan_delay\x18\x08 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.planning_options_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PLANNINGOPTIONS']._serialized_start=185
  _globals['_PLANNINGOPTIONS']._serialized_end=458
# @@protoc_insertion_point(module_scope)
