# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/srv/get_robot_state_from_warehouse.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/moveit_msgs/srv/get_robot_state_from_warehouse.proto\x12,make87_messages_ros2.rolling.moveit_msgs.srv\x1a>make87_messages_ros2/rolling/moveit_msgs/msg/robot_state.proto\"@\n!GetRobotStateFromWarehouseRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05robot\x18\x02 \x01(\t\"m\n\"GetRobotStateFromWarehouseResponse\x12G\n\x05state\x18\x01 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.moveit_msgs.msg.RobotStateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.srv.get_robot_state_from_warehouse_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETROBOTSTATEFROMWAREHOUSEREQUEST']._serialized_start=195
  _globals['_GETROBOTSTATEFROMWAREHOUSEREQUEST']._serialized_end=259
  _globals['_GETROBOTSTATEFROMWAREHOUSERESPONSE']._serialized_start=261
  _globals['_GETROBOTSTATEFROMWAREHOUSERESPONSE']._serialized_end=370
# @@protoc_insertion_point(module_scope)
