# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/cartographer_ros_msgs/srv/start_trajectory.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import status_response_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_status__response__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/cartographer_ros_msgs/srv/start_trajectory.proto\x12\x34make87_messages_ros2.jazzy.cartographer_ros_msgs.srv\x1aJmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/status_response.proto\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"\xe0\x01\n\x16StartTrajectoryRequest\x12\x1f\n\x17\x63onfiguration_directory\x18\x01 \x01(\t\x12\x1e\n\x16\x63onfiguration_basename\x18\x02 \x01(\t\x12\x18\n\x10use_initial_pose\x18\x03 \x01(\x08\x12H\n\x0cinitial_pose\x18\x04 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12!\n\x19relative_to_trajectory_id\x18\x05 \x01(\x05\"\x86\x01\n\x17StartTrajectoryResponse\x12T\n\x06status\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.StatusResponse\x12\x15\n\rtrajectory_id\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.cartographer_ros_msgs.srv.start_trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_STARTTRAJECTORYREQUEST']._serialized_start=267
  _globals['_STARTTRAJECTORYREQUEST']._serialized_end=491
  _globals['_STARTTRAJECTORYRESPONSE']._serialized_start=494
  _globals['_STARTTRAJECTORYRESPONSE']._serialized_end=628
# @@protoc_insertion_point(module_scope)
