# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rc_reason_msgs/srv/detect_filling_level.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_jazzy_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import grid_size_pb2 as make87__messages__ros2_dot_jazzy_dot_rc__reason__msgs_dot_msg_dot_grid__size__pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import load_carrier_with_filling_level_pb2 as make87__messages__ros2_dot_jazzy_dot_rc__reason__msgs_dot_msg_dot_load__carrier__with__filling__level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/rc_reason_msgs/srv/detect_filling_level.proto\x12-make87_messages_ros2.jazzy.rc_reason_msgs.srv\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a?make87_messages_ros2/jazzy/rc_common_msgs/msg/return_code.proto\x1a=make87_messages_ros2/jazzy/rc_reason_msgs/msg/grid_size.proto\x1aSmake87_messages_ros2/jazzy/rc_reason_msgs/msg/load_carrier_with_filling_level.proto\"\xad\x02\n\x19\x44\x65tectFillingLevelRequest\x12\x12\n\npose_frame\x18\x01 \x01(\t\x12\x1d\n\x15region_of_interest_id\x18\x02 \x01(\t\x12 \n\x18region_of_interest_2d_id\x18\x03 \x01(\t\x12\x18\n\x10load_carrier_ids\x18\x04 \x03(\t\x12\x46\n\nrobot_pose\x18\x05 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12Y\n\x18\x66illing_level_cell_count\x18\x06 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.rc_reason_msgs.msg.GridSize\"\x9b\x02\n\x1a\x44\x65tectFillingLevelResponse\x12J\n\ttimestamp\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x61\n\rload_carriers\x18\x02 \x03(\x0b\x32J.make87_messages_ros2.jazzy.rc_reason_msgs.msg.LoadCarrierWithFillingLevel\x12N\n\x0breturn_code\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rc_reason_msgs.srv.detect_filling_level_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTFILLINGLEVELREQUEST']._serialized_start=456
  _globals['_DETECTFILLINGLEVELREQUEST']._serialized_end=757
  _globals['_DETECTFILLINGLEVELRESPONSE']._serialized_start=760
  _globals['_DETECTFILLINGLEVELRESPONSE']._serialized_end=1043
# @@protoc_insertion_point(module_scope)
