# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_perception_msgs/msg/tracked_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.autoware_perception_msgs.msg import object_classification_pb2 as make87__messages__ros2_dot_humble_dot_autoware__perception__msgs_dot_msg_dot_object__classification__pb2
from make87_messages_ros2.humble.autoware_perception_msgs.msg import shape_pb2 as make87__messages__ros2_dot_humble_dot_autoware__perception__msgs_dot_msg_dot_shape__pb2
from make87_messages_ros2.humble.autoware_perception_msgs.msg import tracked_object_kinematics_pb2 as make87__messages__ros2_dot_humble_dot_autoware__perception__msgs_dot_msg_dot_tracked__object__kinematics__pb2
from make87_messages_ros2.humble.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_humble_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/autoware_perception_msgs/msg/tracked_object.proto\x12\x38make87_messages_ros2.humble.autoware_perception_msgs.msg\x1a!make87_messages/core/header.proto\x1aTmake87_messages_ros2/humble/autoware_perception_msgs/msg/object_classification.proto\x1a\x44make87_messages_ros2/humble/autoware_perception_msgs/msg/shape.proto\x1aXmake87_messages_ros2/humble/autoware_perception_msgs/msg/tracked_object_kinematics.proto\x1a\x41make87_messages_ros2/humble/unique_identifier_msgs/msg/uuid.proto\"\xcc\x03\n\rTrackedObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\tobject_id\x18\x02 \x01(\x0b\x32<.make87_messages_ros2.humble.unique_identifier_msgs.msg.UUID\x12\x1d\n\x15\x65xistence_probability\x18\x03 \x01(\x02\x12\x66\n\x0e\x63lassification\x18\x04 \x03(\x0b\x32N.make87_messages_ros2.humble.autoware_perception_msgs.msg.ObjectClassification\x12\x65\n\nkinematics\x18\x05 \x01(\x0b\x32Q.make87_messages_ros2.humble.autoware_perception_msgs.msg.TrackedObjectKinematics\x12N\n\x05shape\x18\x06 \x01(\x0b\x32?.make87_messages_ros2.humble.autoware_perception_msgs.msg.Shapeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_perception_msgs.msg.tracked_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRACKEDOBJECT']._serialized_start=488
  _globals['_TRACKEDOBJECT']._serialized_end=948
# @@protoc_insertion_point(module_scope)
