# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_traffic_msgs/msg/itinerary_extend.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import route_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/rmf_traffic_msgs/msg/itinerary_extend.proto\x12\x30make87_messages_ros2.humble.rmf_traffic_msgs.msg\x1a!make87_messages/core/header.proto\x1a<make87_messages_ros2/humble/rmf_traffic_msgs/msg/route.proto\"\xb8\x01\n\x0fItineraryExtend\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0bparticipant\x18\x02 \x01(\x04\x12G\n\x06routes\x18\x03 \x03(\x0b\x32\x37.make87_messages_ros2.humble.rmf_traffic_msgs.msg.Route\x12\x19\n\x11itinerary_version\x18\x04 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_traffic_msgs.msg.itinerary_extend_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ITINERARYEXTEND']._serialized_start=223
  _globals['_ITINERARYEXTEND']._serialized_end=407
# @@protoc_insertion_point(module_scope)
