# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/tracked_properties.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ibeo_msgs.msg import contour_point_sigma_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_contour__point__sigma__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import point2_di_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_point2__di__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import point2_dui_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_point2__dui__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/ibeo_msgs/msg/tracked_properties.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a\x44make87_messages_ros2/rolling/ibeo_msgs/msg/contour_point_sigma.proto\x1a:make87_messages_ros2/rolling/ibeo_msgs/msg/point2_di.proto\x1a;make87_messages_ros2/rolling/ibeo_msgs/msg/point2_dui.proto\"\xe9\n\n\x11TrackedProperties\x12\x12\n\nobject_age\x18\x01 \x01(\r\x12\x19\n\x11hidden_status_age\x18\x02 \x01(\r\x12\x14\n\x0cobject_phase\x18\x03 \x01(\r\x12\x18\n\x10\x64ynamic_property\x18\x04 \x01(\r\x12 \n\x18relative_time_of_measure\x18\x05 \x01(\r\x12T\n\x16position_closest_point\x18\x06 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12O\n\x11relative_velocity\x18\x07 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12V\n\x17relative_velocity_sigma\x18\x08 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12\x16\n\x0e\x63lassification\x18\t \x01(\r\x12\x1a\n\x12\x63lassification_age\x18\n \x01(\r\x12M\n\x0fobject_box_size\x18\x0b \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12T\n\x15object_box_size_sigma\x18\x0c \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12\x1e\n\x16object_box_orientation\x18\r \x01(\x05\x12$\n\x1cobject_box_orientation_sigma\x18\x0e \x01(\r\x12\x1f\n\x17tracking_point_location\x18\x0f \x01(\r\x12W\n\x19tracking_point_coordinate\x18\x10 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12^\n\x1ftracking_point_coordinate_sigma\x18\x11 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12\x46\n\x08velocity\x18\x12 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12M\n\x0evelocity_sigma\x18\x13 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12J\n\x0c\x61\x63\x63\x65leration\x18\x14 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12Q\n\x12\x61\x63\x63\x65leration_sigma\x18\x15 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12\x10\n\x08yaw_rate\x18\x16 \x01(\x05\x12\x16\n\x0eyaw_rate_sigma\x18\x17 \x01(\r\x12 \n\x18number_of_contour_points\x18\x18 \x01(\r\x12Y\n\x12\x63ontour_point_list\x18\x19 \x03(\x0b\x32=.make87_messages_ros2.rolling.ibeo_msgs.msg.ContourPointSigmab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.tracked_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRACKEDPROPERTIES']._serialized_start=307
  _globals['_TRACKEDPROPERTIES']._serialized_end=1692
# @@protoc_insertion_point(module_scope)
