# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/traffic_dependency.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/traffic_dependency.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\"\x83\x01\n\x11TrafficDependency\x12\x1c\n\x14\x64\x65pendent_checkpoint\x18\x01 \x01(\x04\x12\x16\n\x0eon_participant\x18\x02 \x01(\x04\x12\x0f\n\x07on_plan\x18\x03 \x01(\x04\x12\x10\n\x08on_route\x18\x04 \x01(\x04\x12\x15\n\ron_checkpoint\x18\x05 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.traffic_dependency_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRAFFICDEPENDENCY']._serialized_start=130
  _globals['_TRAFFICDEPENDENCY']._serialized_end=261
# @@protoc_insertion_point(module_scope)
