# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_perception_msgs/msg/detected_object_kinematics.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/humble/autoware_perception_msgs/msg/detected_object_kinematics.proto\x12\x38make87_messages_ros2.humble.autoware_perception_msgs.msg\x1a!make87_messages/core/header.proto\x1aHmake87_messages_ros2/humble/geometry_msgs/msg/pose_with_covariance.proto\x1aImake87_messages_ros2/humble/geometry_msgs/msg/twist_with_covariance.proto\"\x80\x03\n\x18\x44\x65tectedObjectKinematics\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12_\n\x14pose_with_covariance\x18\x02 \x01(\x0b\x32\x41.make87_messages_ros2.humble.geometry_msgs.msg.PoseWithCovariance\x12\x1f\n\x17has_position_covariance\x18\x03 \x01(\x08\x12 \n\x18orientation_availability\x18\x04 \x01(\r\x12\x61\n\x15twist_with_covariance\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.humble.geometry_msgs.msg.TwistWithCovariance\x12\x11\n\thas_twist\x18\x06 \x01(\x08\x12\x1c\n\x14has_twist_covariance\x18\x07 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_perception_msgs.msg.detected_object_kinematics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTEDOBJECTKINEMATICS']._serialized_start=336
  _globals['_DETECTEDOBJECTKINEMATICS']._serialized_end=720
# @@protoc_insertion_point(module_scope)
