# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/play_motion2_msgs/srv/get_motion_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.play_motion2_msgs.msg import motion_pb2 as make87__messages__ros2_dot_humble_dot_play__motion2__msgs_dot_msg_dot_motion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/play_motion2_msgs/srv/get_motion_info.proto\x12\x31make87_messages_ros2.humble.play_motion2_msgs.srv\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/play_motion2_msgs/msg/motion.proto\"X\n\x14GetMotionInfoRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\nmotion_key\x18\x02 \x01(\t\"\x90\x01\n\x15GetMotionInfoResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12I\n\x06motion\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.humble.play_motion2_msgs.msg.Motionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.play_motion2_msgs.srv.get_motion_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETMOTIONINFOREQUEST']._serialized_start=225
  _globals['_GETMOTIONINFOREQUEST']._serialized_end=313
  _globals['_GETMOTIONINFORESPONSE']._serialized_start=316
  _globals['_GETMOTIONINFORESPONSE']._serialized_end=460
# @@protoc_insertion_point(module_scope)
