# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_sensor_msgs/srv/set_exposure.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/marti_sensor_msgs/srv/set_exposure.proto\x12\x32make87_messages_ros2.rolling.marti_sensor_msgs.srv\"9\n\x12SetExposureRequest\x12\x15\n\rauto_exposure\x18\x01 \x01(\x08\x12\x0c\n\x04time\x18\x02 \x01(\x03\":\n\x13SetExposureResponse\x12\x15\n\rauto_exposure\x18\x01 \x01(\x08\x12\x0c\n\x04time\x18\x02 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_sensor_msgs.srv.set_exposure_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETEXPOSUREREQUEST']._serialized_start=125
  _globals['_SETEXPOSUREREQUEST']._serialized_end=182
  _globals['_SETEXPOSURERESPONSE']._serialized_start=184
  _globals['_SETEXPOSURERESPONSE']._serialized_end=242
# @@protoc_insertion_point(module_scope)
