# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_msgs/msg/robot_state_rt_msg.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/ur_msgs/msg/robot_state_rt_msg.proto\x12&make87_messages_ros2.jazzy.ur_msgs.msg\"\x96\x03\n\x0fRobotStateRTMsg\x12\x0c\n\x04time\x18\x01 \x01(\x01\x12\x10\n\x08q_target\x18\x02 \x03(\x01\x12\x11\n\tqd_target\x18\x03 \x03(\x01\x12\x12\n\nqdd_target\x18\x04 \x03(\x01\x12\x10\n\x08i_target\x18\x05 \x03(\x01\x12\x10\n\x08m_target\x18\x06 \x03(\x01\x12\x10\n\x08q_actual\x18\x07 \x03(\x01\x12\x11\n\tqd_actual\x18\x08 \x03(\x01\x12\x10\n\x08i_actual\x18\t \x03(\x01\x12\x17\n\x0ftool_acc_values\x18\n \x03(\x01\x12\x11\n\ttcp_force\x18\x0b \x03(\x01\x12\x13\n\x0btool_vector\x18\x0c \x03(\x01\x12\x11\n\ttcp_speed\x18\r \x03(\x01\x12\x1a\n\x12\x64igital_input_bits\x18\x0e \x01(\x01\x12\x1a\n\x12motor_temperatures\x18\x0f \x03(\x01\x12\x18\n\x10\x63ontroller_timer\x18\x10 \x01(\x01\x12\x12\n\ntest_value\x18\x11 \x01(\x01\x12\x12\n\nrobot_mode\x18\x12 \x01(\x01\x12\x13\n\x0bjoint_modes\x18\x13 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_msgs.msg.robot_state_rt_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROBOTSTATERTMSG']._serialized_start=108
  _globals['_ROBOTSTATERTMSG']._serialized_end=514
# @@protoc_insertion_point(module_scope)
