# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/nao_lola_sensor_msgs/msg/joint_temperatures.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/nao_lola_sensor_msgs/msg/joint_temperatures.proto\x12\x35make87_messages_ros2.rolling.nao_lola_sensor_msgs.msg\")\n\x11JointTemperatures\x12\x14\n\x0ctemperatures\x18\x01 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.nao_lola_sensor_msgs.msg.joint_temperatures_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_JOINTTEMPERATURES']._serialized_start=137
  _globals['_JOINTTEMPERATURES']._serialized_end=178
# @@protoc_insertion_point(module_scope)
