# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/lifecycle_msgs/srv/get_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.lifecycle_msgs.msg import state_pb2 as make87__messages__ros2_dot_rolling_dot_lifecycle__msgs_dot_msg_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/lifecycle_msgs/srv/get_state.proto\x12/make87_messages_ros2.rolling.lifecycle_msgs.srv\x1a;make87_messages_ros2/rolling/lifecycle_msgs/msg/state.proto\"\x11\n\x0fGetStateRequest\"a\n\x10GetStateResponse\x12M\n\rcurrent_state\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.lifecycle_msgs.msg.Stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.lifecycle_msgs.srv.get_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETSTATEREQUEST']._serialized_start=177
  _globals['_GETSTATEREQUEST']._serialized_end=194
  _globals['_GETSTATERESPONSE']._serialized_start=196
  _globals['_GETSTATERESPONSE']._serialized_end=293
# @@protoc_insertion_point(module_scope)
