# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/smacc2_msgs/msg/smacc_transition.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.smacc2_msgs.msg import smacc_event_pb2 as make87__messages__ros2_dot_jazzy_dot_smacc2__msgs_dot_msg_dot_smacc__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/smacc2_msgs/msg/smacc_transition.proto\x12*make87_messages_ros2.jazzy.smacc2_msgs.msg\x1a<make87_messages_ros2/jazzy/smacc2_msgs/msg/smacc_event.proto\"\xe6\x01\n\x0fSmaccTransition\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x17\n\x0ftransition_name\x18\x02 \x01(\t\x12\x17\n\x0ftransition_type\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65stiny_state_name\x18\x04 \x01(\t\x12\x19\n\x11source_state_name\x18\x05 \x01(\t\x12\x14\n\x0chistory_node\x18\x06 \x01(\x08\x12\x45\n\x05\x65vent\x18\x07 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.smacc2_msgs.msg.SmaccEventb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.smacc2_msgs.msg.smacc_transition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SMACCTRANSITION']._serialized_start=176
  _globals['_SMACCTRANSITION']._serialized_end=406
# @@protoc_insertion_point(module_scope)
