# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/negotiation_rejection.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import itinerary_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_itinerary__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import negotiation_key_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_negotiation__key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/negotiation_rejection.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1a\x41make87_messages_ros2/rolling/rmf_traffic_msgs/msg/itinerary.proto\x1aGmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/negotiation_key.proto\"\xeb\x01\n\x14NegotiationRejection\x12\x18\n\x10\x63onflict_version\x18\x01 \x01(\x04\x12P\n\x05table\x18\x02 \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.NegotiationKey\x12\x13\n\x0brejected_by\x18\x03 \x01(\x04\x12R\n\x0c\x61lternatives\x18\x04 \x03(\x0b\x32<.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.Itineraryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.negotiation_rejection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NEGOTIATIONREJECTION']._serialized_start=273
  _globals['_NEGOTIATIONREJECTION']._serialized_end=508
# @@protoc_insertion_point(module_scope)
