# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mobileye_560_660_msgs/msg/lane.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/mobileye_560_660_msgs/msg/lane.proto\x12\x34make87_messages_ros2.jazzy.mobileye_560_660_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf7\x01\n\x04Lane\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x16\n\x0elane_curvature\x18\x02 \x01(\x01\x12\x14\n\x0clane_heading\x18\x03 \x01(\x01\x12\x19\n\x11\x63onstruction_area\x18\x04 \x01(\x08\x12\x13\n\x0bpitch_angle\x18\x05 \x01(\x01\x12\x11\n\tyaw_angle\x18\x06 \x01(\x01\x12\x1e\n\x16right_ldw_availability\x18\x07 \x01(\x08\x12\x1d\n\x15left_ldw_availability\x18\x08 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mobileye_560_660_msgs.msg.lane_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LANE']._serialized_start=176
  _globals['_LANE']._serialized_end=423
# @@protoc_insertion_point(module_scope)
