# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_event.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/sbg_driver/msg/sbg_event.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xad\x02\n\x08SbgEvent\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x12\n\ntime_stamp\x18\x02 \x01(\r\x12\x10\n\x08overflow\x18\x03 \x01(\x08\x12\x16\n\x0eoffset_0_valid\x18\x04 \x01(\x08\x12\x16\n\x0eoffset_1_valid\x18\x05 \x01(\x08\x12\x16\n\x0eoffset_2_valid\x18\x06 \x01(\x08\x12\x16\n\x0eoffset_3_valid\x18\x07 \x01(\x08\x12\x15\n\rtime_offset_0\x18\x08 \x01(\r\x12\x15\n\rtime_offset_1\x18\t \x01(\r\x12\x15\n\rtime_offset_2\x18\n \x01(\r\x12\x15\n\rtime_offset_3\x18\x0b \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SBGEVENT']._serialized_start=159
  _globals['_SBGEVENT']._serialized_end=460
# @@protoc_insertion_point(module_scope)
