# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/geographic_msgs/srv/get_route_plan.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geographic_msgs.msg import route_path_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_route__path__pb2
from make87_messages_ros2.rolling.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_rolling_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/geographic_msgs/srv/get_route_plan.proto\x12\x30make87_messages_ros2.rolling.geographic_msgs.srv\x1a\x41make87_messages_ros2/rolling/geographic_msgs/msg/route_path.proto\x1a\x42make87_messages_ros2/rolling/unique_identifier_msgs/msg/uuid.proto\"\x80\x02\n\x13GetRoutePlanRequest\x12N\n\x07network\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12L\n\x05start\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12K\n\x04goal\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\"\x82\x01\n\x14GetRoutePlanResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\t\x12I\n\x04plan\x18\x03 \x01(\x0b\x32;.make87_messages_ros2.rolling.geographic_msgs.msg.RoutePathb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.geographic_msgs.srv.get_route_plan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETROUTEPLANREQUEST']._serialized_start=259
  _globals['_GETROUTEPLANREQUEST']._serialized_end=515
  _globals['_GETROUTEPLANRESPONSE']._serialized_start=518
  _globals['_GETROUTEPLANRESPONSE']._serialized_end=648
# @@protoc_insertion_point(module_scope)
