# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mavros_msgs/srv/gimbal_manager_configure.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/humble/mavros_msgs/srv/gimbal_manager_configure.proto\x12+make87_messages_ros2.humble.mavros_msgs.srv\x1a!make87_messages/core/header.proto\"\xc9\x01\n\x1dGimbalManagerConfigureRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x15\n\rsysid_primary\x18\x02 \x01(\x05\x12\x16\n\x0e\x63ompid_primary\x18\x03 \x01(\x05\x12\x17\n\x0fsysid_secondary\x18\x04 \x01(\x05\x12\x18\n\x10\x63ompid_secondary\x18\x05 \x01(\x05\x12\x18\n\x10gimbal_device_id\x18\x06 \x01(\r\"o\n\x1eGimbalManagerConfigureResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0e\n\x06result\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mavros_msgs.srv.gimbal_manager_configure_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERCONFIGUREREQUEST']._serialized_start=159
  _globals['_GIMBALMANAGERCONFIGUREREQUEST']._serialized_end=360
  _globals['_GIMBALMANAGERCONFIGURERESPONSE']._serialized_start=362
  _globals['_GIMBALMANAGERCONFIGURERESPONSE']._serialized_end=473
# @@protoc_insertion_point(module_scope)
