# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/gpsrtk.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/mavros_msgs/msg/gpsrtk.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\x9c\x02\n\x06GPSRTK\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x17\n\x0frtk_receiver_id\x18\x02 \x01(\r\x12\n\n\x02wn\x18\x03 \x01(\x05\x12\x0b\n\x03tow\x18\x04 \x01(\r\x12\x12\n\nrtk_health\x18\x05 \x01(\r\x12\x10\n\x08rtk_rate\x18\x06 \x01(\r\x12\r\n\x05nsats\x18\x07 \x01(\r\x12\x12\n\nbaseline_a\x18\x08 \x01(\x05\x12\x12\n\nbaseline_b\x18\t \x01(\x05\x12\x12\n\nbaseline_c\x18\n \x01(\x05\x12\x10\n\x08\x61\x63\x63uracy\x18\x0b \x01(\r\x12\x1a\n\x12iar_num_hypotheses\x18\x0c \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.gpsrtk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GPSRTK']._serialized_start=164
  _globals['_GPSRTK']._serialized_end=448
# @@protoc_insertion_point(module_scope)
