# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/planning_scene_world.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.rolling.octomap_msgs.msg import octomap_with_pose_pb2 as make87__messages__ros2_dot_rolling_dot_octomap__msgs_dot_msg_dot_octomap__with__pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/moveit_msgs/msg/planning_scene_world.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x43make87_messages_ros2/rolling/moveit_msgs/msg/collision_object.proto\x1a\x45make87_messages_ros2/rolling/octomap_msgs/msg/octomap_with_pose.proto\"\xbf\x01\n\x12PlanningSceneWorld\x12X\n\x11\x63ollision_objects\x18\x01 \x03(\x0b\x32=.make87_messages_ros2.rolling.moveit_msgs.msg.CollisionObject\x12O\n\x07octomap\x18\x02 \x01(\x0b\x32>.make87_messages_ros2.rolling.octomap_msgs.msg.OctomapWithPoseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.planning_scene_world_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PLANNINGSCENEWORLD']._serialized_start=262
  _globals['_PLANNINGSCENEWORLD']._serialized_end=453
# @@protoc_insertion_point(module_scope)
