# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/detect_tags.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import detected_tag_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_detected__tag__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import tag_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_tag__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rc_reason_msgs/srv/detect_tags.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\x1a\x42make87_messages_ros2/rolling/rc_reason_msgs/msg/detected_tag.proto\x1a\x39make87_messages_ros2/rolling/rc_reason_msgs/msg/tag.proto\"\xb5\x01\n\x11\x44\x65tectTagsRequest\x12\x42\n\x04tags\x18\x01 \x03(\x0b\x32\x34.make87_messages_ros2.rolling.rc_reason_msgs.msg.Tag\x12\x12\n\npose_frame\x18\x02 \x01(\t\x12H\n\nrobot_pose\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\"\x80\x02\n\x12\x44\x65tectTagsResponse\x12J\n\x04tags\x18\x01 \x03(\x0b\x32<.make87_messages_ros2.rolling.rc_reason_msgs.msg.DetectedTag\x12L\n\ttimestamp\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12P\n\x0breturn_code\x18\x03 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.detect_tags_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTTAGSREQUEST']._serialized_start=436
  _globals['_DETECTTAGSREQUEST']._serialized_end=617
  _globals['_DETECTTAGSRESPONSE']._serialized_start=620
  _globals['_DETECTTAGSRESPONSE']._serialized_end=876
# @@protoc_insertion_point(module_scope)
