# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcl_interfaces/srv/get_parameters.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rcl_interfaces.msg import parameter_value_pb2 as make87__messages__ros2_dot_rolling_dot_rcl__interfaces_dot_msg_dot_parameter__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/rcl_interfaces/srv/get_parameters.proto\x12/make87_messages_ros2.rolling.rcl_interfaces.srv\x1a\x45make87_messages_ros2/rolling/rcl_interfaces/msg/parameter_value.proto\"%\n\x14GetParametersRequest\x12\r\n\x05names\x18\x01 \x03(\t\"h\n\x15GetParametersResponse\x12O\n\x06values\x18\x01 \x03(\x0b\x32?.make87_messages_ros2.rolling.rcl_interfaces.msg.ParameterValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcl_interfaces.srv.get_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPARAMETERSREQUEST']._serialized_start=192
  _globals['_GETPARAMETERSREQUEST']._serialized_end=229
  _globals['_GETPARAMETERSRESPONSE']._serialized_start=231
  _globals['_GETPARAMETERSRESPONSE']._serialized_end=335
# @@protoc_insertion_point(module_scope)
