# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/hand_eye_calibration_trigger.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/rc_reason_msgs/srv/hand_eye_calibration_trigger.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\"\"\n HandEyeCalibrationTriggerRequest\"U\n!HandEyeCalibrationTriggerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.hand_eye_calibration_trigger_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HANDEYECALIBRATIONTRIGGERREQUEST']._serialized_start=135
  _globals['_HANDEYECALIBRATIONTRIGGERREQUEST']._serialized_end=169
  _globals['_HANDEYECALIBRATIONTRIGGERRESPONSE']._serialized_start=171
  _globals['_HANDEYECALIBRATIONTRIGGERRESPONSE']._serialized_end=256
# @@protoc_insertion_point(module_scope)
