# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_area_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_area_status.proto\x12\x30make87_messages_ros2.jazzy.autoware_v2x_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\"\xff\x01\n\x15VirtualGateAreaStatus\x12\x46\n\x05stamp\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\x13\n\x0bsequence_id\x18\x03 \x01(\r\x12\x0f\n\x07\x61rea_id\x18\x04 \x01(\t\x12\x10\n\x08gate_ids\x18\x05 \x03(\t\x12V\n\x15\x65xpected_time_arrival\x18\x06 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_v2x_msgs.msg.virtual_gate_area_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VIRTUALGATEAREASTATUS']._serialized_start=196
  _globals['_VIRTUALGATEAREASTATUS']._serialized_end=451
# @@protoc_insertion_point(module_scope)
